@@ -11,7 +11,11 @@
  * @author Matthias Biggeleben <matthias.biggeleben@open-xchange.com>
  */
 
-define('io.ox/backbone/mini-views/common', ['io.ox/backbone/mini-views/abstract'], function (AbstractView) {
+define('io.ox/backbone/mini-views/common', [
+    'io.ox/backbone/mini-views/abstract',
+    'io.ox/backbone/mini-views/dropdown',
+    'gettext!io.ox/core'
+], function (AbstractView, Dropdown, gt) {
 
     'use strict';
 
@@ -46,11 +50,15 @@ define('io.ox/backbone/mini-views/common', ['io.ox/backbone/mini-views/abstract'
             // update model too or the the left spaces are still in the model data. They would be saved when the model is saved, creating inconsistent data
             // infinite loops are not possible because the change event is only triggered if the new value is different
             this.model.set(this.name, val);
+            // trigger extra update event on view
+            this.trigger('update', this.$el);
         },
         render: function () {
             this.$el.attr({ name: this.name });
             if (this.id) this.$el.attr('id', this.id);
             if (this.options.maxlength) this.$el.attr('maxlength', this.options.maxlength);
+            if (this.options.mandatory) this.$el.attr('aria-required', true);
+            if (_.isBoolean(this.options.autocomplete) && !this.options.autocomplete) this.$el.attr('autocomplete', 'off');
             this.update();
             return this;
         }
@@ -75,6 +83,10 @@ define('io.ox/backbone/mini-views/common', ['io.ox/backbone/mini-views/abstract'
             var value = this.model.get(this.name);
             this.$el.val(value !== null ? $.trim(value) : '********');
         },
+        toggle: function (state) {
+            state = _.isBoolean(state) ? state : this.$el.attr('type') === 'password';
+            this.$el.attr('type', state ? 'text' : 'password');
+        },
         render: function () {
             this.$el.attr({
                 autocomplete: 'off',
@@ -84,11 +96,61 @@ define('io.ox/backbone/mini-views/common', ['io.ox/backbone/mini-views/abstract'
             });
             if (this.id) this.$el.attr('id', this.id);
             if (this.options.maxlength) this.$el.attr('maxlength', this.options.maxlength);
+            if (this.options.mandatory) this.$el.attr('aria-required', true);
+            // see bug 49639, 51204
+            if (_.isBoolean(this.options.autocomplete) && !this.options.autocomplete) this.$el.attr('autocomplete', 'new-password').removeAttr('name');
             this.update();
             return this;
         }
     });
 
+    //
+    // wraps PasswordView and adds toggle button
+    // <span>
+    //    <input type="password">
+    //    <button class="toggle-asterisks">
+    //
+
+    var PasswordViewToggle = AbstractView.extend({
+        el: '<div class="password-container has-feedback">',
+        events: {
+            'click .toggle-asterisks': 'toggle',
+            'keydown': 'onKeyPress',
+            'keyup': 'onKeyPress',
+            'focusin': 'onFocusChange',
+            'focusout': 'onFocusChange'
+        },
+        icons: { 'password': 'fa-eye', 'text': 'fa-eye-slash' },
+        initialize: function (opt) {
+            this.passwordView = new PasswordView(opt);
+        },
+        onFocusChange: _.debounce(function () {
+            this.$el.toggleClass('has-focus', $(document.activeElement).closest('.password-container').length > 0);
+        }, 20),
+        onKeyPress: function (e) {
+            // Windows Key / Left ⌘ / Chromebook Search key
+            if (e.which !== 91) return;
+            this.toggle(e, e.type === 'keydown');
+        },
+        toggle: function (state) {
+            state = _.isBoolean(state) ? state : undefined;
+            this.passwordView.toggle(state);
+            this.$el.find('i.fa').removeClass('fa-eye fa-eye-slash').addClass(this.icons[this.passwordView.$el.attr('type')]);
+        },
+        render: function () {
+            this.$el.empty().append(
+                this.passwordView.render().$el,
+                $('<button href="#" class="btn form-control-feedback toggle-asterisks center-childs">')
+                    //#. title of toggle button within password field
+                    .attr({ title: gt('toggle password visibility') })
+                    .append(
+                        $('<i class="fa" aria-hidden="true">').addClass(this.icons.password)
+                    )
+            );
+            return this;
+        }
+    });
+
     //
     // <textarea>
     //
@@ -140,10 +202,11 @@ define('io.ox/backbone/mini-views/common', ['io.ox/backbone/mini-views/abstract'
             this.listenTo(this.model, 'change:' + this.name, this.update);
         },
         update: function () {
-            this.$el.prop('checked', !!this.model.get(this.name));
+            this.$el.prop('checked', !!this.model.get(this.name, this.options.defaultVal));
         },
         render: function () {
             this.$el.attr({ name: this.name });
+            if (this.options.id) this.$el.attr('id', this.options.id);
             this.update();
             return this;
         }
@@ -214,6 +277,9 @@ define('io.ox/backbone/mini-views/common', ['io.ox/backbone/mini-views/abstract'
     var ErrorView =  AbstractView.extend({
         tagName: 'span',
         className: 'help-block',
+        setup: function (opt) {
+            this.focusSelector = opt.focusSelector || 'input';
+        },
         getContainer: function () {
             if (this.options.selector) {
                 if (_.isString(this.options.selector)) return this.$el.closest(this.options.selector);
@@ -241,7 +307,7 @@ define('io.ox/backbone/mini-views/common', ['io.ox/backbone/mini-views/abstract'
                             'aria-describedby': errorId
                         });
                         _.defer(function () {
-                            $(container).find('input').focus();
+                            $(container).find(self.focusSelector).focus();
                         });
                     },
                     valid: function () {
@@ -268,33 +334,24 @@ define('io.ox/backbone/mini-views/common', ['io.ox/backbone/mini-views/abstract'
         }
     });
 
-    var DropdownLinkView = AbstractView.extend({
+    var DropdownLinkView = Dropdown.extend({
         tagName: 'div',
         className: 'dropdownlink',
-        events: { 'click [data-action="change-value"]': 'onClick' },
-        onClick: function (e) {
-            e.preventDefault();
-            this.model.set(this.name, $(e.target).attr('data-value'));
-        },
-        setup: function () {
-            this.listenTo(this.model, 'change:' + this.name, this.update);
-        },
         update: function () {
-            this.$el.find('.dropdown-toggle').text(this.options.values[this.model.get(this.name)]);
+            this.updateLabel();
+            Dropdown.prototype.update.apply(this, arguments);
+        },
+        updateLabel: function () {
+            this.$el.find('.dropdown-label').text(this.options.values[this.model.get(this.name)]);
         },
         render: function () {
-            this.$el.append(
-                $('<a href="#" class="dropdown-toggle" data-toggle="dropdown" role="menuitem" aria-haspopup="true">').text(this.options.values[this.model.get(this.name)]),
-                $('<ul class="dropdown-menu" role="menu">').append(
-                    _(this.options.values).map(function (name, value) {
-                        return $('<li>').append(
-                            $('<a href="#" data-action="change-value">').attr('data-value', value).text(name)
-                        );
-                    })
-                )
-            );
-
-            this.update();
+            var self = this;
+            Dropdown.prototype.render.apply(this, arguments);
+            _(this.options.values).each(function (name, value) {
+                var tooltip = self.options.tooltips && self.options.tooltips[value] ? self.options.tooltips[value] : name;
+                self.option(self.name, value, name, { radio: true, title: tooltip });
+            });
+            this.updateLabel();
             return this;
         }
     });
@@ -303,6 +360,7 @@ define('io.ox/backbone/mini-views/common', ['io.ox/backbone/mini-views/abstract'
         AbstractView: AbstractView,
         InputView: InputView,
         PasswordView: PasswordView,
+        PasswordViewToggle: PasswordViewToggle,
         TextView: TextView,
         CheckboxView: CheckboxView,
         RadioView: RadioView,
