@@ -18,8 +18,9 @@ define('io.ox/calendar/actions', [
     'io.ox/calendar/util',
     'io.ox/core/extPatterns/actions',
     'io.ox/core/print',
-    'gettext!io.ox/calendar'
-], function (ext, links, api, util, actions, print, gt) {
+    'gettext!io.ox/calendar',
+    'io.ox/core/capabilities'
+], function (ext, links, api, util, actions, print, gt, capabilities) {
 
     'use strict';
 
@@ -71,8 +72,13 @@ define('io.ox/calendar/actions', [
         capabilities: 'webmail',
         action: function (baton) {
             util.resolveParticipants(baton.data).done(function (recipients) {
+                var hash = {};
                 recipients = _(recipients)
                     .chain()
+                    .filter(function (rec) {
+                        // don't add duplicates
+                        return rec.mail in hash ? false : (hash[rec.mail] = true);
+                    })
                     .filter(function (rec) {
                         // don't add myself
                         // don't add if mail address is missing (yep, edge-case)
@@ -176,6 +182,11 @@ define('io.ox/calendar/actions', [
             }
 
             var app = e.baton.data;
+
+            // cannot confirm appointments without proper id (happens when detail view was opened from mail invitation from external calendar)
+            // must use buttons in invitation mail instead
+            if (!app.id) return false;
+
             // incomplete
             if (app.id && !app.users) {
                 return api.get(app).then(cont);
@@ -403,9 +414,10 @@ define('io.ox/calendar/actions', [
     });
 
     new Action('io.ox/calendar/premium/actions/share', {
-        capabilities: 'caldav client-onboarding',
+        capabilities: 'caldav',
         requires: function () {
-            return _.device('!smartphone');
+            // use client onboarding here, since it is a setting and not a capability
+            return capabilities.has('client-onboarding');
         },
         action: function () {
             require(['io.ox/onboarding/clients/wizard'], function (wizard) {
