@@ -22,7 +22,7 @@ define('io.ox/calendar/edit/extensions', [
     'io.ox/backbone/mini-views',
     'io.ox/backbone/mini-views/datepicker',
     'io.ox/core/tk/attachments',
-    'io.ox/calendar/edit/recurrence-view',
+    'io.ox/backbone/views/recurrence-view',
     'io.ox/calendar/api',
     'io.ox/participants/add',
     'io.ox/participants/views',
@@ -127,7 +127,7 @@ define('io.ox/calendar/edit/extensions', [
             var self = this;
             require(['io.ox/metrics/main'], function (metrics) {
                 if (!metrics.isEnabled()) return;
-                self.delegate('[data-action]', 'mousedown', function (e) {
+                self.on('mousedown', '[data-action]', function (e) {
                     var node =  $(e.target);
                     metrics.trackEvent({
                         app: 'calendar',
@@ -209,11 +209,11 @@ define('io.ox/calendar/edit/extensions', [
         id: 'title',
         index: 200,
         render: function () {
-            var self = this, input;
+            var self = this, input, guid = _.uniqueId('form-control-label-');
             this.$el.append(
-                $('<label class="control-label col-xs-12">').append(
+                $('<label class="control-label col-xs-12">').attr('for', guid).append(
                     $.txt(gt('Subject')),
-                    input = new mini.InputView({ name: 'title', model: self.model }).render().$el,
+                    input = new mini.InputView({ id: guid, name: 'title', model: self.model }).render().$el,
                     new mini.ErrorView({ name: 'title', model: self.model }).render().$el
                 )
             );
@@ -229,11 +229,12 @@ define('io.ox/calendar/edit/extensions', [
         id: 'location',
         index: 300,
         render: function () {
+            var guid = _.uniqueId('form-control-label-');
             this.$el.append(
-                $('<label class="control-label col-xs-12">').append(
+                $('<label class="control-label col-xs-12">').attr('for', guid).append(
                     $.txt(gt('Location')),
                     // only trim on save
-                    new mini.InputView({ name: 'location', model: this.model }).render().$el
+                    new mini.InputView({ id: guid, name: 'location', model: this.model }).render().$el
                 )
             );
         }
@@ -260,7 +261,11 @@ define('io.ox/calendar/edit/extensions', [
                     attribute: 'start_date',
                     label: gt('Starts on'),
                     timezoneButton: true,
-                    timezoneAttribute: 'timezone'
+                    timezoneAttribute: 'timezone',
+                    closeOnScroll: true,
+                    a11y: {
+                        timeLabel: gt('Start time')
+                    }
                 }).listenTo(baton.model, 'change:full_time', function (model, fulltime) {
                     this.toggleTimeInput(!fulltime);
                 }).on('click:timezone', openTimezoneDialog, baton)
@@ -293,7 +298,11 @@ define('io.ox/calendar/edit/extensions', [
                     attribute: 'end_date',
                     label: gt('Ends on'),
                     timezoneButton: true,
-                    timezoneAttribute: 'endTimezone'
+                    timezoneAttribute: 'endTimezone',
+                    closeOnScroll: true,
+                    a11y: {
+                        timeLabel: gt('End time')
+                    }
                 }).listenTo(baton.model, 'change:full_time', function (model, fulltime) {
                     this.toggleTimeInput(!fulltime);
                 }).on('click:timezone', openTimezoneDialog, baton)
@@ -335,12 +344,13 @@ define('io.ox/calendar/edit/extensions', [
     point.extend({
         id: 'full_time',
         index: 600,
-        className: 'col-md-6',
+        className: 'col-sm-6',
         render: function () {
+            var guid = _.uniqueId('form-control-label-');
             this.$el.append(
-                $('<div>').addClass('checkbox').append(
-                    $('<label class="control-label">').append(
-                        new mini.CheckboxView({ name: 'full_time', model: this.model }).render().$el,
+                $('<div class="checkbox">').append(
+                    $('<label class="control-label">').attr('for', guid).append(
+                        new mini.CheckboxView({ id: guid, name: 'full_time', model: this.model }).render().$el,
                         $.txt(gt('All day'))
                     )
                 )
@@ -363,11 +373,16 @@ define('io.ox/calendar/edit/extensions', [
     // move recurrence view to collapsible area on mobile devices
     var recurrenceIndex = _.device('smartphone') ? 950 : 650;
     // recurrence
-    point.extend(new RecurrenceView({
+    point.extend({
         id: 'recurrence',
-        className: 'col-xs-12 recurrenceview',
-        index: recurrenceIndex
-    }), {
+        className: 'col-xs-12',
+        index: recurrenceIndex,
+        render: function () {
+            this.$el.append(new RecurrenceView({
+                model: this.model
+            }).render().$el);
+        }
+    }, {
         rowClass: 'collapsed'
     });
 
@@ -417,10 +432,7 @@ define('io.ox/calendar/edit/extensions', [
         render: function () {
             var guid = _.uniqueId('form-control-label-');
             this.$el.append(
-                $('<label>').attr({
-                    class: 'control-label',
-                    for: guid
-                }).text(gt('Reminder')), //#. Describes how a appointment is shown in the calendar, values can be "reserved", "temporary", "absent" and "free"
+                $('<label class="control-label">').attr('for', guid).text(gt('Reminder')), //#. Describes how a appointment is shown in the calendar, values can be "reserved", "temporary", "absent" and "free"
                 $('<div>').append(
                     new mini.SelectView({
                         list: _.map(calendarUtil.getReminderOptions(), function (key, val) { return { label: key, value: val }; }),
@@ -450,10 +462,7 @@ define('io.ox/calendar/edit/extensions', [
                     { label: gt('Free'), value: 4 }
                 ];
             this.$el.append(
-                $('<label>').attr({
-                    class: 'control-label',
-                    for: guid
-                }).text(gt('Shown as')), //#. Describes how a appointment is shown in the calendar, values can be "reserved", "temporary", "absent" and "free"
+                $('<label class="control-label">').attr('for', guid).text(gt('Shown as')), //#. Describes how a appointment is shown in the calendar, values can be "reserved", "temporary", "absent" and "free"
                 $('<div>').append(
                     new mini.SelectView({
                         list: options,
@@ -527,11 +536,12 @@ define('io.ox/calendar/edit/extensions', [
             var folder_id = this.model.get('folder_id');
             if (!folderAPI.pool.getModel(folder_id).is('private')) return;
 
+            var guid = _.uniqueId('form-control-label-');
             this.$el.append(
                 $('<fieldset>').append(
-                    $('<legend>').addClass('simple').text(gt('Type')),
-                    $('<label class="checkbox-inline control-label">').append(
-                        new mini.CheckboxView({ name: 'private_flag', model: this.model }).render().$el,
+                    $('<legend class="simple">').text(gt('Type')),
+                    $('<label class="checkbox-inline control-label">').attr('for', guid).append(
+                        new mini.CheckboxView({ id: guid, name: 'private_flag', model: this.model }).render().$el,
                         $.txt(gt('Private'))
                     )
                 )
@@ -586,9 +596,10 @@ define('io.ox/calendar/edit/extensions', [
         index: 1510,
         className: 'col-md-6',
         render: function () {
+            var guid = _.uniqueId('form-control-label-');
             this.$el.append(
-                $('<label class="checkbox-inline control-label">').append(
-                    new mini.CheckboxView({ name: 'notification', model: this.model }).render().$el,
+                $('<label class="checkbox-inline control-label">').attr('for', guid).append(
+                    new mini.CheckboxView({ id: guid, name: 'notification', model: this.model }).render().$el,
                     $.txt(gt('Notify all participants by email.'))
                 )
             );
