@@ -21,7 +21,7 @@ define('io.ox/calendar/freetime/main', [
     'settings!io.ox/core',
     'less!io.ox/calendar/freetime/style',
     'less!io.ox/calendar/style'
-], function (DisposableView, FreetimeModel, ParticipantsView, TimeView, gt, settings, settingsCore) {
+], function (DisposableView, FreetimeModel, ParticipantsView, TimeView, gt, settings, coreSettings) {
 
     'use strict';
 
@@ -142,7 +142,7 @@ define('io.ox/calendar/freetime/main', [
                 var appointment = this.createAppointment();
 
                 if (appointment) {
-                    appointment.folder = settingsCore.get('folder/calendar');
+                    appointment.folder = coreSettings.get('folder/calendar');
                     ox.load(['io.ox/calendar/edit/main']).done(function (edit) {
                         edit.getApp().launch().done(function () {
                             this.create(appointment);
@@ -262,14 +262,25 @@ define('io.ox/calendar/freetime/main', [
         };
 
         app.failRestore = function (point) {
-            this.view.model.get('participants').add(point.participants);
-            this.view.timeSubview.setDate(point.currentWeek);
+
             this.view.timeSubview.lassoStart = point.lassoStart;
             this.view.timeSubview.lassoEnd = point.lassoEnd;
+            this.view.timeSubview.setDate(point.currentWeek);
             this.view.timeSubview.updateLasso(true);
+            if (!point.lassoStart) {
+                this.view.timeSubview.keepScrollpos = 'today';
+            } else {
+                this.view.timeSubview.keepScrollpos = this.view.timeSubview.lassoStartTime;
+            }
+            this.view.model.get('participants').add(point.participants);
+
             return $.when();
         };
 
+        app.getContextualHelp = function () {
+            return 'ox.appsuite.user.sect.calendar.add.scheduling.html';
+        };
+
         return app;
     }
 
