@@ -12,7 +12,6 @@
  */
 
 define('io.ox/calendar/main', [
-    'settings!io.ox/core',
     'io.ox/core/commons',
     'io.ox/core/extensions',
     'io.ox/core/capabilities',
@@ -31,7 +30,7 @@ define('io.ox/calendar/main', [
     'io.ox/calendar/actions',
     'less!io.ox/calendar/style',
     'io.ox/calendar/week/view'
-], function (coreConfig, commons, ext, capabilities, folderAPI, TreeView, FolderView, settings, gt, VGrid, Bars, PageController, api) {
+], function (commons, ext, capabilities, folderAPI, TreeView, FolderView, settings, gt, VGrid, Bars, PageController, api) {
 
     'use strict';
 
@@ -265,13 +264,20 @@ define('io.ox/calendar/main', [
         'vgrid': function (app) {
 
             var gridOptions = {
-                settings: settings,
-                showToggle: _.device('smartphone'),
-                hideTopbar: _.device('smartphone'),
-                hideToolbar: _.device('smartphone'),
-                // if it's shown, it should be on the top
-                toolbarPlacement: 'top'
-            };
+                    settings: settings,
+                    showToggle: _.device('smartphone'),
+                    hideTopbar: _.device('smartphone'),
+                    hideToolbar: _.device('smartphone'),
+                    // if it's shown, it should be on the top
+                    toolbarPlacement: 'top'
+                },
+                savedWidth = app.settings.get('vgrid/width/' + _.display());
+
+            // do not apply on touch devices. it's not possible to change the width there
+            if (!_.device('touch') && savedWidth) {
+                app.right.css('left', savedWidth + 'px');
+                app.left.css('width', savedWidth + 'px');
+            }
 
             // show "load more" link
             gridOptions.tail = function () {
@@ -313,6 +319,70 @@ define('io.ox/calendar/main', [
             app.folderView.tree.$el.attr('aria-label', gt('Calendars'));
         },
 
+        'folderview-toolbar': function (app) {
+            if (_.device('smartphone')) return;
+
+            app.toggleFolderView = function (e) {
+                e.preventDefault();
+                app.folderView.toggle(e.data.state);
+            };
+
+            function onFolderViewOpen(app) {
+                app.getWindow().nodes.sidepanel.show();
+                app.left.removeClass('bottom-toolbar');
+                // for perspectives other than list
+                app.getWindow().nodes.body.removeClass('bottom-toolbar-visible');
+            }
+
+            function onFolderViewClose(app) {
+                // hide sidepanel so invisible objects are not tabbable
+                app.getWindow().nodes.sidepanel.hide();
+                app.left.addClass('bottom-toolbar');
+                // for perspectives other than list
+                app.getWindow().nodes.body.addClass('bottom-toolbar-visible');
+            }
+
+            // create extension point for second toolbar
+            ext.point('io.ox/calendar/vgrid/second-toolbar').extend({
+                id: 'default',
+                index: 100,
+                draw: function () {
+                    this.addClass('visual-focus').append(
+                        $('<a href="#" class="toolbar-item" data-action="open-folder-view">')
+                        .attr('aria-label', gt('Open folder view'))
+                        .append($('<i class="fa fa-angle-double-right" aria-hidden="true">').attr('title', gt('Open folder view')))
+                        .on('click', { state: true }, app.toggleFolderView)
+                    );
+                }
+            });
+
+            ext.point('io.ox/calendar/sidepanel').extend({
+                id: 'toggle-folderview',
+                index: 1000,
+                draw: function () {
+                    this.addClass('bottom-toolbar').append(
+                        $('<div class="generic-toolbar bottom visual-focus">').append(
+                            $('<a href="#" class="toolbar-item" role="button" data-action="close-folder-view">').attr('aria-label', gt('Close folder view'))
+                            .append(
+                                $('<i class="fa fa-angle-double-left" aria-hidden="true">').attr('title', gt('Close folder view'))
+                            )
+                            .on('click', { app: app, state: false }, app.toggleFolderView)
+                        )
+                    );
+                }
+            });
+
+            app.on({
+                'folderview:open': onFolderViewOpen.bind(null, app),
+                'folderview:close': onFolderViewClose.bind(null, app)
+            });
+
+            var grid = app.getGrid(), topbar = grid.getTopbar();
+            ext.point(app.get('name') + '/vgrid/second-toolbar').invoke('draw', topbar, ext.Baton({ grid: grid }));
+            onFolderViewClose(app);
+            if (app.folderViewIsVisible()) _.defer(onFolderViewOpen, app);
+        },
+
         'premium-area': function (app) {
 
             ext.point('io.ox/calendar/sidepanel').extend({
@@ -382,7 +452,7 @@ define('io.ox/calendar/main', [
          * Default application properties
          */
         'props': function (app) {
-            var view = settings.get('viewView', 'week:week');
+            var view = settings.get('viewView') || 'week:week';
             // introduce shared properties
             app.props = new Backbone.Model({
                 'layout': view,
@@ -524,9 +594,18 @@ define('io.ox/calendar/main', [
 
             var lastPerspective,
                 SEARCH_PERSPECTIVE = 'list',
-                find = app.get('find');
-            // additional handler: switch to list perspective (and back)
+                find = app.get('find'),
+                emptyMessage = function findResultEmptyMessage() { return gt('No matching items found.'); };
+
             if (find) {
+                // WORKAROUND: no suitable way other of wrapping getEmptyMessage
+                app.grid.getEmptyMessage = _.wrap(app.grid.getEmptyMessage, function (fn) {
+                    if (app.grid.getMode() === 'search') return emptyMessage;
+                    // return function set by grid.setEmptyMessage
+                    return fn.apply(fn);
+                });
+
+                // additional handler: switch to list perspective (and back)
                 find.on({
                     'find:query': function () {
                         // hide sort options
@@ -622,34 +701,26 @@ define('io.ox/calendar/main', [
 
         'metrics': function (app) {
 
+            // hint: toolbar metrics are registery by extension 'metrics-toolbar'
             require(['io.ox/metrics/main'], function (metrics) {
                 if (!metrics.isEnabled()) return;
 
                 var nodes = app.getWindow().nodes,
-                    toolbar = nodes.body.find('.classic-toolbar-container'),
                     sidepanel = nodes.sidepanel;
-                // toolbar actions
-                toolbar.delegate('.io-ox-action-link:not(.dropdown-toggle)', 'mousedown', function (e) {
+                // vgrid toolbar
+                nodes.main.on('mousedown', '.vgrid-toolbar a[data-name], .vgrid-toolbar a[data-action]', function (e) {
+                    var node = $(e.currentTarget);
+                    var action = node.attr('data-name') || node.attr('data-action');
+                    if (!action) return;
                     metrics.trackEvent({
                         app: 'calendar',
-                        target: 'toolbar',
+                        target: 'list/toolbar',
                         type: 'click',
-                        action: $(e.currentTarget).attr('data-action')
-                    });
-                });
-                // toolbar options dropfdown
-                toolbar.delegate('.dropdown-menu a:not(.io-ox-action-link)', 'mousedown', function (e) {
-                    var node =  $(e.target).closest('a');
-                    metrics.trackEvent({
-                        app: 'calendar',
-                        target: 'toolbar',
-                        type: 'click',
-                        action: node.attr('data-action') || node.attr('data-name'),
-                        detail: node.attr('data-value')
+                        action: action
                     });
                 });
                 // detail view
-                nodes.outer.delegate('.participants-view .io-ox-action-link', 'mousedown', function (e) {
+                nodes.outer.on('mousedown', '.participants-view .io-ox-action-link', function (e) {
                     metrics.trackEvent({
                         app: 'calendar',
                         target: 'detail/toolbar',
@@ -658,7 +729,7 @@ define('io.ox/calendar/main', [
                     });
                 });
                 // detail view as sidepopup
-                nodes.outer.delegate('.io-ox-sidepopup .io-ox-action-link', 'mousedown', function (e) {
+                nodes.outer.on('mousedown', '.io-ox-sidepopup .io-ox-action-link', function (e) {
                     metrics.trackEvent({
                         app: 'calendar',
                         target: 'detail/toolbar',
@@ -667,7 +738,7 @@ define('io.ox/calendar/main', [
                     });
                 });
                 // folder tree action
-                sidepanel.find('.context-dropdown').delegate('li>a', 'mousedown', function (e) {
+                sidepanel.find('.context-dropdown').on('mousedown', 'a', function (e) {
                     metrics.trackEvent({
                         app: 'calendar',
                         target: 'folder/context-menu',
@@ -675,8 +746,18 @@ define('io.ox/calendar/main', [
                         action: $(e.currentTarget).attr('data-action')
                     });
                 });
+                sidepanel.find('.bottom').on('mousedown', 'a[data-action]', function (e) {
+                    var node = $(e.currentTarget);
+                    if (!node.attr('data-action')) return;
+                    metrics.trackEvent({
+                        app: 'calendar',
+                        target: 'folder/toolbar',
+                        type: 'click',
+                        action: $(e.currentTarget).attr('data-action')
+                    });
+                });
                 // folder permissions action
-                sidepanel.find('.folder-tree').delegate('.folder-shared', 'mousedown', function () {
+                sidepanel.find('.folder-tree').on('mousedown', '.folder-shared, .fa.folder-sub', function () {
                     metrics.trackEvent({
                         app: 'calendar',
                         target: 'folder',
@@ -700,6 +781,7 @@ define('io.ox/calendar/main', [
                 // selection in listview
                 app.grid.selection.on({
                     'change': function (event, list) {
+                        if (!list.length) return;
                         metrics.trackEvent({
                             app: 'calendar',
                             target: 'list',
