@@ -16,14 +16,15 @@ define('io.ox/calendar/month/perspective', [
     'io.ox/calendar/api',
     'io.ox/core/extensions',
     'io.ox/core/tk/dialogs',
+    'io.ox/core/notifications',
     'io.ox/calendar/view-detail',
     'io.ox/calendar/conflicts/conflictList',
     'io.ox/core/print',
     'io.ox/core/folder/api',
-    'settings!io.ox/calendar',
+    'io.ox/calendar/util',
     'gettext!io.ox/calendar',
     'less!io.ox/calendar/print-style'
-], function (View, api, ext, dialogs, detailView, conflictView, print, folderAPI, settings, gt, printStyle) {
+], function (View, api, ext, dialogs, notifications, detailView, conflictView, print, folderAPI, util, gt, printStyle) {
 
     'use strict';
 
@@ -49,7 +50,7 @@ define('io.ox/calendar/month/perspective', [
         tops:           {},     // scrollTop positions of the shown weeks
         firstWeek:      0,      // moment of the first week
         lastWeek:       0,      // moment of the last week
-        updateLoad:     8,      // amount of weeks to be loaded on scroll events
+        updateLoad:     2,      // amount of months to be loaded on scroll events
         initLoad:       2,      // amount of initial called updates
         scrollOffset:   _.device('smartphone') ? 130 : 250,  // offset space to trigger update event on scroll stop
         collections:    {},     // all week collections of appointments
@@ -114,37 +115,22 @@ define('io.ox/calendar/month/perspective', [
             });
 
             var apiUpdate = function (obj) {
-                api.update(obj).fail(function (con) {
-                    if (con.conflicts) {
-                        var dialog = new dialogs.ModalDialog({
-                            top: '20%',
-                            center: false,
-                            container: self.main
-                        });
+                api.update(obj).fail(function (error) {
+                    if (!error.conflicts) return notifications.yell(error);
 
-                        dialog.append(conflictView.drawList(con.conflicts, dialog))
-                            .addDangerButton('ignore', gt('Ignore conflicts'), 'ignore')
-                            .addButton('cancel', gt('Cancel'), 'cancel')
-                            .show()
-                            .done(function (action) {
-                                if (action === 'cancel') {
-                                    self.update();
-                                    return;
-                                }
-                                if (action === 'ignore') {
-                                    obj.ignore_conflicts = true;
-                                    apiUpdate(obj);
-                                }
+                    ox.load(['io.ox/calendar/conflicts/conflictList']).done(function (conflictView) {
+                        conflictView.dialog(error.conflicts)
+                            .on('cancel', function () { self.update(); })
+                            .on('ignore', function () {
+                                obj.ignore_conflicts = true;
+                                apiUpdate(obj);
                             });
-                    }
+                    });
                 });
             };
 
             if (obj.recurrence_type > 0) {
-                new dialogs.ModalDialog()
-                    .text(gt('By changing the date of this appointment you are creating an appointment exception to the series. Do you want to continue?'))
-                    .addButton('appointment', gt('Yes'), 'appointment')
-                    .addButton('cancel', gt('No'), 'cancel')
+                util.getRecurrenceChangeDialog()
                     .show()
                     .done(function (action) {
                         if (action === 'appointment') {
@@ -164,7 +150,7 @@ define('io.ox/calendar/month/perspective', [
                 weeks = opt.weeks || this.updateLoad,
                 apiData = {
                     start: opt.start,
-                    end: moment(opt.start).add(weeks, 'weeks').valueOf()
+                    end: moment(opt.start).add(weeks, 'weeks').endOf('week').valueOf()
                 };
             // do folder magic
             if (this.folder.id !== 'virtual/all-my-appointments') {
@@ -206,10 +192,17 @@ define('io.ox/calendar/month/perspective', [
                     up: false,
                     multi: 1
                 }, opt),
-                views = [],
-                weeks = param.multi * self.updateLoad,
-                curWeek = param.up ? self.firstWeek.subtract(weeks, 'weeks').clone() : self.lastWeek.clone(),
-                start = curWeek.valueOf();
+                months = param.multi * self.updateLoad,
+                currMonth = [],
+                renderedElements = [],
+                weeks = 1, curWeek, start;
+
+            if (param.up) {
+                curWeek = self.firstWeek.subtract(months, 'months').startOf('month').clone();
+            } else {
+                curWeek = self.lastWeek.clone();
+            }
+            start = curWeek.valueOf();
 
             function createView(options) {
                 return new View(options)
@@ -222,53 +215,70 @@ define('io.ox/calendar/month/perspective', [
             }
 
             // draw all weeks
-            for (var i = 0; i < weeks; i++, curWeek.add(8, 'd').startOf('week')) {
-                var day = curWeek.valueOf(),
-                    endDate = curWeek.clone().endOf('week'),
-                    monthDelimiter = curWeek.clone().endOf('month').isSameOrBefore(endDate);
+            for (var i = 0; i < months; i++) {
+                var day, endOfMonth = curWeek.clone().endOf('month'),
+                    isFirstWeek = true;
+                curWeek = curWeek.startOf('month');
 
-                // add collection for week
-                self.collections[day] = new MonthAppointmentCollection([]);
-                // new view
-                var view = createView({
-                    collection: self.collections[day],
-                    day: day,
-                    folder: self.folder,
-                    pane: this.pane,
-                    app: this.app,
-                    weekType: monthDelimiter ? 'last' : ''
-                });
-                views.push(view.render().el);
+                renderedElements.push($('<div class="week month-name">').attr('id', curWeek.format('YYYY-MM')).append($('<h1 class="unstyled">').text(curWeek.format('MMMM YYYY'))));
 
-                // seperate last days if month before and first days of next month
-                if (monthDelimiter) {
-                    endDate.add(1, 'd').startOf('month');
-                    // add an
-                    views.push($('<div class="week month-name">').attr('id', endDate.format('YYYY-MM')).append($('<div>').text(gt.noI18n(endDate.format('MMMM YYYY')))));
-                    view.$el.addClass('no-border');
+                while (curWeek.clone().endOf('month').isSame(endOfMonth)) {
+                    var endOfWeek = curWeek.clone().endOf('week');
 
-                    if (!endDate.clone().startOf('week').isSame(endDate)) {
-                        // do not render this, if start of current week is the same as start of current month
-                        views.push(createView({
-                            collection: self.collections[day],
-                            day: day,
-                            folder: self.folder,
-                            pane: this.pane,
-                            app: this.app,
-                            weekType: 'first'
-                        }).render().el);
+                    day = curWeek.clone().startOf('week').valueOf();
+
+                    var weekType = '';
+                    if (isFirstWeek) {
+                        weekType = 'first';
+                        isFirstWeek = false;
+                    } else if (curWeek.clone().startOf('month').isBefore(endOfWeek.clone().startOf('month'))) {
+                        weekType = 'last';
                     }
+
+                    // reuse collection (week started in previous month, there is no need to double that collection) or create a new one
+                    self.collections[day] = self.collections[day] || new MonthAppointmentCollection([]);
+
+                    // new view
+                    currMonth.push(createView({
+                        collection: self.collections[day],
+                        day: day,
+                        folder: self.folder,
+                        pane: this.pane,
+                        app: this.app,
+                        perspective: this,
+                        weekType: weekType
+                    }).render().el);
+
+                    curWeek.add(1, 'week').startOf('week');
                 }
+
+                // add an
+                //if (view) view.$el.addClass('no-border');
+
+                renderedElements.push(
+                    $('<table class="month" aria-readonly="true">').append(
+                        $('<tbody>').append(currMonth)
+                    ).css('height', 100 / 7 * currMonth.length + '%')
+                );
+                weeks += currMonth.length + 1;
+                currMonth = [];
+            }
+            if (!param.up) {
+                this.lastWeek = curWeek;
             }
 
             // add and render view
             if (param.up) {
                 var firstWeek = $('.week:first', this.pane),
                     curOffset = firstWeek.offset().top - this.scrollTop();
-                this.pane.prepend(views).scrollTop(firstWeek.offset().top - curOffset);
+
+                // don't scroll under the scrollOffset, as this will cause infine scrolling
+                this.pane.prepend(renderedElements).scrollTop(Math.max(-renderedElements[0].offset().top - curOffset, this.scrollOffset + 1));
             } else {
-                this.lastWeek.add(weeks, 'weeks');
-                this.pane.append(views);
+                this.pane.append(renderedElements);
+            }
+            if (_.device('ie && ie <= 11')) {
+                this.calculateHeights();
             }
 
             // update first positions
@@ -280,6 +290,14 @@ define('io.ox/calendar/month/perspective', [
             return $.when();
         },
 
+        // IE 11 needs a fixed height or appointments are not displayed
+        calculateHeights: _.debounce(function () {
+            // no calculation if invisible(all lists get 0 height)
+            if (this.pane.filter(':visible').length === 0) return;
+            var height = (this.pane.height() * (1 / 7) - 26) + 'px';
+            this.pane.find('.list').css('height', height);
+        }, 100),
+
         /**
          * wrapper for scrollTop funciton
          * @param  {number} top scrollposition
@@ -291,8 +309,9 @@ define('io.ox/calendar/month/perspective', [
         },
 
         updateColor: function (model) {
+            if (!model) return;
             $('[data-folder="' + model.get('id') + '"]', this.pane).each(function () {
-                this.className = this.className.replace(/color-label-\d{1,2}/, 'color-label-' + model.get('meta').color_label);
+                this.className = this.className.replace(/color-label-\d{1,2}/, 'color-label-' + (model.get('meta') ? model.get('meta').color_label || '1' : '1'));
             });
         },
 
@@ -320,15 +339,16 @@ define('io.ox/calendar/month/perspective', [
          * update global 'tops' object with current positions of all first days of all months
          */
         getFirsts: function () {
-            this.tops = {};
+            if (!this.pane) return;
+
             var self = this;
-            if (this.pane) {
-                $('.day.first', this.pane).each(function (i, el) {
-                    var elem = $(el);
-                    // >> 0 parses a floating point number to an integer
-                    self.tops[($(el).position().top - elem.height() / 2 + self.pane.scrollTop()) >> 0] = elem;
-                });
-            }
+            this.tops = {};
+
+            $('.day.first', this.pane).each(function (i, el) {
+                var elem = $(el);
+                // >> 0 parses a floating point number to an integer
+                self.tops[($(el).position().top - elem.height() / 2 + self.pane.scrollTop()) >> 0] = elem;
+            });
         },
 
         /**
@@ -338,9 +358,7 @@ define('io.ox/calendar/month/perspective', [
             // See Bug 36417 - calendar jumps to wrong month with IE10
             // If month perspectice is rendered the first time after another perspective was already rendered, the tops will all be 0.
             // That happens, because the perspective is made visible after rendering but only when there was already another calendar perspective rendered;
-            if (_.keys(this.tops).length <= 1) {
-                this.getFirsts();
-            }
+            if (_.keys(this.tops).length <= 1) this.getFirsts();
         },
 
         /**
@@ -422,8 +440,7 @@ define('io.ox/calendar/month/perspective', [
          */
         print: function () {
             var win, data = null,
-                folderID = this.folder.id || this.folder.folder,
-                styleNode = $('<style type="text/css">').text(printStyle);
+                folderID = this.folder.id || this.folder.folder;
 
             if (folderID && folderID !== 'virtual/all-my-appointments') {
                 data = { folder_id: folderID };
@@ -434,17 +451,29 @@ define('io.ox/calendar/month/perspective', [
                 end: moment(this.current).add(1, 'month').utc(true).valueOf()
             });
 
+            function applyCustomColors() {
+                // Edge does not like to append untrimmed html with jquery in new windows
+                // see https://stackoverflow.com/questions/38591575/jquery-append-into-new-window-not-working-with-microsoft-edge
+                $(win.document.head).append('<style type="text/css">' + printStyle + '</style>');
+                // apply folder color to appointments that don't have their own
+                $(win.document.body).addClass('print-view-custom-colors');
+            }
+
             if (this.app.props.get('colorScheme') === 'custom') {
                 // apply custom colors
-                win.onload = function () {
-                    $(win.document.head).append(styleNode);
-                    $(win.document.body).addClass('print-view-custom-colors');
-                    win.onload = null;
-                };
+                // IE only accepts attachEvent for "onload" (see bug 59367)
+                if (_.browser.edge) {
+                    win.addEventListener('load', applyCustomColors, false);
+                } else if (_.browser.ie) {
+                    win.attachEvent('onload', applyCustomColors);
+                } else {
+                    $(win).on('load', applyCustomColors);
+                }
             }
 
             // firefox opens every window with about:blank, then loads the url. If we are to fast we will just print a blank page(see bug 33415)
-            if (_.browser.firefox) {
+            // added Safari because it showed the same behavior
+            if (_.browser.firefox || _.browser.safari) {
                 var limit = 50,
                     counter = 0,
                     interval;
@@ -473,8 +502,8 @@ define('io.ox/calendar/month/perspective', [
             var self = this;
             this.app = app;
             this.current = moment(app.refDate || moment()).startOf('month');
-            this.previous = moment(this.current).subtract(1, 'month');
-            this.firstWeek = moment(this.previous).startOf('week');
+            this.previous = this.current.clone().subtract(1, 'month');
+            this.firstWeek = this.previous.clone().startOf('week');
             this.lastWeek = this.firstWeek.clone();
 
             this.main
@@ -565,6 +594,10 @@ define('io.ox/calendar/month/perspective', [
 
             $(window).on('resize', this.getFirsts);
 
+            if (_.device('ie && ie <= 11')) {
+                $(window).on('resize', _(this.calculateHeights).bind(this));
+            }
+
             self.getFolder().done(function () {
                 self.folderModel = folderAPI.pool.getModel(self.folder.id);
                 self.folderModel.on('change:meta', self.updateColor, self);
@@ -597,8 +630,12 @@ define('io.ox/calendar/month/perspective', [
                             // enter
                             $(e.target).click();
                             break;
-                        default:
+                        case 32:
+                            // space
+                            e.preventDefault();
+                            $(e.target).click();
                             break;
+                        // no default
                     }
                 });
 
