@@ -247,4 +247,62 @@ define('io.ox/calendar/toolbar', [
             });
         }
     });
+
+    // bottom toolbar
+    ext.point('io.ox/calendar/mediator').extend({
+        id: 'bottom-toolbar',
+        index: 10300,
+        setup: function (app) {
+            if (_.device('smartphone')) return;
+            var toolbar = $('<div class="generic-toolbar calendar bottom visual-focus">').append(
+                $('<a href="#" class="toolbar-item" role="button" data-action="close-folder-view">').attr('aria-label', gt('Close folder view')).append(
+                    $('<i class="fa fa-angle-double-right" aria-hidden="true">').attr('title', gt('Close folder view'))
+                ).on('click', { state: true }, app.toggleFolderView)
+            );
+            app.getWindow().nodes.body.toggleClass('bottom-toolbar', app.props.get('layout') !== 'list').append(toolbar);
+            toolbar.toggle(app.props.get('layout') !== 'list');
+
+            app.getWindow().on('change:perspective', function (e, value) {
+                app.getWindow().nodes.body.toggleClass('bottom-toolbar', value !== 'list');
+                toolbar.toggle(value !== 'list');
+            });
+        }
+    });
+
+    ext.point('io.ox/calendar/mediator').extend({
+        id: 'metrics-toolbar',
+        index: 10300,
+        setup: function (app) {
+
+            require(['io.ox/metrics/main'], function (metrics) {
+                if (!metrics.isEnabled()) return;
+
+                var nodes = app.getWindow().nodes,
+                    toolbar = nodes.body.find('.classic-toolbar-container');
+
+                // toolbar actions
+                toolbar.on('mousedown', '.io-ox-action-link:not(.dropdown-toggle)', function (e) {
+                    metrics.trackEvent({
+                        app: 'calendar',
+                        target: 'toolbar',
+                        type: 'click',
+                        action: $(e.currentTarget).attr('data-action')
+                    });
+                });
+                // toolbar options dropdown
+                toolbar.on('mousedown', '.dropdown a:not(.io-ox-action-link)', function (e) {
+                    var node =  $(e.target).closest('a'),
+                        isToggle = node.attr('data-toggle') === 'true';
+                    if (!node.attr('data-name')) return;
+                    metrics.trackEvent({
+                        app: 'calendar',
+                        target: 'toolbar',
+                        type: 'click',
+                        action: node.attr('data-action') || node.attr('data-name'),
+                        detail: isToggle ? !node.find('.fa-check').length : node.attr('data-value')
+                    });
+                });
+            });
+        }
+    });
 });
