@@ -20,15 +20,16 @@ define('io.ox/contacts/addressbook/popup', [
     'io.ox/contacts/util',
     'io.ox/contacts/api',
     'gettext!io.ox/contacts',
+    'gettext!io.ox/core',
     'settings!io.ox/contacts',
     'settings!io.ox/mail',
     'l10n/ja_JP/io.ox/collation',
     'less!io.ox/contacts/addressbook/style'
-], function (http, folderAPI, ModalDialog, ListView, ext, util, api, gt, settings, mailSettings, collation) {
+], function (http, folderAPI, ModalDialog, ListView, ext, util, api, gt, gtCore, settings, mailSettings, collation) {
 
     'use strict';
 
-    var names = 'last_name first_name display_name'.split(' '),
+    var names = 'yomiLastName yomiFirstName last_name first_name display_name'.split(' '),
         addresses = 'email1 email2 email3'.split(' ');
 
     // limits
@@ -152,7 +153,7 @@ define('io.ox/contacts/addressbook/popup', [
             )
             .then(function (contacts, labels) {
                 var result = [], hash = {};
-                processAddresses(contacts[0], result, hash);
+                processAddresses(contacts[0], result, hash, options);
                 if (useLabels) processLabels(labels[0], result, hash);
                 return { items: result, hash: hash, index: buildIndex(result) };
             });
@@ -162,13 +163,18 @@ define('io.ox/contacts/addressbook/popup', [
 
             options = _.extend({
                 // keep this list really small for good performance!
-                columns: '1,20,500,501,502,505,519,555,556,557,592,602,606',
+                columns: '1,20,500,501,502,505,519,555,556,557,592,602,606,610,611',
                 exclude: useGlobalAddressBook ? [] : ['6'],
                 limit: LIMITS.fetch
             }, options);
 
-            if (options.folder === 'all') delete options.folder;
+            var data = {
+                exclude_folders: options.exclude,
+                last_name: '*'
+            };
 
+            if (options.folder === 'all') delete options.folder;
+            if (options.useGABOnly) data.folder = ['6'];
             return http.PUT({
                 module: 'contacts',
                 params: {
@@ -179,10 +185,7 @@ define('io.ox/contacts/addressbook/popup', [
                     sort: 609
                 },
                 // emailAutoComplete doesn't work; need to clean up client-side anyway
-                data: {
-                    exclude_folders: options.exclude,
-                    last_name: '*'
-                }
+                data: data
             });
         }
 
@@ -199,20 +202,21 @@ define('io.ox/contacts/addressbook/popup', [
             });
         }
 
-        function processAddresses(list, result, hash) {
+        function processAddresses(list, result, hash, opt) {
 
-            list.forEach(function (item) {
+            list.forEach(function (item, rank) {
                 // remove quotes from display name (common in collected addresses)
                 item.display_name = getDisplayName(item.display_name);
-                // get sort name
                 var sort_name = [], address;
-                names.forEach(function (name) {
-                    if (item[name]) sort_name.push(item[name]);
-                });
                 // distribution list?
                 if (item.mark_as_distributionlist) {
+                    // get sort name
+                    sort_name = [item.display_name];
                     // get a match for the entire list
                     address = _(item.distribution_list)
+                        .filter(function (obj) {
+                            return obj.mail;
+                        })
                         .map(function (obj) {
                             // mail address only
                             return $.trim(obj.mail).toLowerCase();
@@ -220,15 +224,20 @@ define('io.ox/contacts/addressbook/popup', [
                         .join(', ');
                     // overwrite last name to get a nicer full name
                     item.last_name = item.display_name;
-                    var obj = process(item, sort_name, address, 0);
+                    var obj = process(item, sort_name, address, 0, rank);
                     if (obj) {
                         obj.full_name_html += ' <span class="gray">' + gt('Distribution list') + '</span>';
                         result.push((hash[obj.cid] = obj));
                     }
                 } else {
+                    // get sort name
+                    names.forEach(function (name) {
+                        if (item[name]) sort_name.push(item[name]);
+                    });
+                    if (opt.useGABOnly) addresses = ['email1'];
                     // get a match for each address
-                    addresses.forEach(function (address, i) {
-                        var obj = process(item, sort_name, (item[address] || '').toLowerCase(), i);
+                    addresses.forEach(function (field, i) {
+                        var obj = process(item, sort_name, (item[field] || '').toLowerCase(), rank, i, field);
                         if (obj) result.push((hash[obj.cid] = obj));
                     });
                 }
@@ -236,7 +245,7 @@ define('io.ox/contacts/addressbook/popup', [
             return { items: result, hash: hash, index: buildIndex(result) };
         }
 
-        function process(item, sort_name, address, i) {
+        function process(item, sort_name, address, rank, i, field) {
             // skip if empty
             address = $.trim(address);
             if (!address) return;
@@ -256,6 +265,7 @@ define('io.ox/contacts/addressbook/popup', [
                 department: department,
                 display_name: item.display_name,
                 email: address,
+                field: field,
                 first_name: item.first_name,
                 folder_id: folder_id,
                 full_name: full_name,
@@ -376,7 +386,7 @@ define('io.ox/contacts/addressbook/popup', [
     var isOpen = false, cachedResponse = null, folder = 'all', appeared = {};
 
     // clear cache on address book changes
-    api.on('create update delete', function () {
+    api.on('create update delete import', function () {
         cachedResponse = null;
     });
 
@@ -386,7 +396,9 @@ define('io.ox/contacts/addressbook/popup', [
         'shared':  gt('Shared address books')
     };
 
-    function open(callback) {
+    function open(callback, useGABOnly) {
+
+        if (useGABOnly) folder = 'folder/6';
 
         // avoid parallel popups
         if (isOpen) return;
@@ -397,16 +409,21 @@ define('io.ox/contacts/addressbook/popup', [
             focus: '.search-field',
             maximize: 600,
             point: 'io.ox/contacts/addressbook-popup',
-            title: gt('Select contacts')
+            help: 'ox.appsuite.user.sect.email.send.addressbook.html',
+            title: gt('Select contacts'),
+            useGABOnly: useGABOnly
         })
         .inject({
             renderFolders: function (folders) {
                 var $dropdown = this.$('.folder-dropdown'),
-                    count = 0;
+                    count = 0, self = this;
                 // remove global address book?
                 if (!useGlobalAddressBook && folders['public']) {
                     folders['public'] = _(folders['public']).reject({ id: '6' });
                 }
+                if (this.options.useGABOnly) {
+                    folders = _.pick(folders, 'public');
+                }
                 $dropdown.append(
                     _(folders).map(function (section, id) {
                         // skip empty and (strange) almost empty folders
@@ -415,6 +432,7 @@ define('io.ox/contacts/addressbook/popup', [
                         return $('<optgroup>').attr('label', sections[id]).append(
                             _(section).map(function (folder) {
                                 count++;
+                                if (self.options.useGABOnly && folder.id !== '6') return;
                                 return $('<option>').val('folder/' + folder.id).text(folder.title);
                             })
                         );
@@ -470,8 +488,8 @@ define('io.ox/contacts/addressbook/popup', [
                         ),
                         $('<div class="col-xs-6">').append(
                             $('<select class="form-control folder-dropdown invisible">').append(
-                                $('<option value="all">').text(gt('All folders')),
-                                useLabels ? $() : $('<option value="all_lists">').text(gt('All distribution lists')),
+                                this.options.useGABOnly ? $() : $('<option value="all">').text(gt('All folders')),
+                                this.options.useGABOnly || useLabels ? $() : $('<option value="all_lists">').text(gt('All distribution lists')),
                                 useLabels ? $('<option value="all_labels">').text(gt('All groups')) : $()
                             )
                         )
@@ -498,11 +516,6 @@ define('io.ox/contacts/addressbook/popup', [
                 });
                 this.$body.append(this.listView.render().$el);
             },
-            footer: function () {
-                this.$('.modal-footer').prepend(
-                    $('<div class="selection-summary">').hide()
-                );
-            },
             onOpen: function () {
 
                 // hide body initially / add busy animation
@@ -512,7 +525,7 @@ define('io.ox/contacts/addressbook/popup', [
                     if (this.disposed) return;
                     cachedResponse = response;
                     this.items = response.items.sort(sorter);
-                    this.hash = response.hash;
+                    this.store.setHash(response.hash);
                     this.index = response.index;
                     this.search('');
                     this.idle();
@@ -528,8 +541,8 @@ define('io.ox/contacts/addressbook/popup', [
 
                 this.on('open', function () {
                     _.defer(function () {
-                        if (cachedResponse) return success.call(this, cachedResponse);
-                        getAllMailAddresses().then(success.bind(this), fail.bind(this));
+                        if (cachedResponse && !this.options.useGABOnly) return success.call(this, cachedResponse);
+                        getAllMailAddresses({ useGABOnly: this.options.useGABOnly }).then(success.bind(this), fail.bind(this));
                     }.bind(this));
                 });
             },
@@ -568,6 +581,72 @@ define('io.ox/contacts/addressbook/popup', [
                     this.renderItems(result, { isSearch: isSearch });
                 };
             },
+            tokenview: function () {
+                this.tokenview = new TokenView({ useLabels: useLabels });
+                // handle remove
+                this.tokenview.on('remove', function (cid) {
+                    // remove selected (non-visible)
+                    // TODO: use custom global events
+                    this.store.remove(cid);
+                    // remove selected (visible)
+                    var selection = this.listView.selection;
+                    selection.uncheck(selection.getNode(cid));
+                    selection.triggerChange();
+                }.bind(this));
+                // handle clear
+                this.tokenview.on('clear', function () {
+                    this.store.clear();
+                    this.listView.selection.clear();
+                    this.listView.selection.triggerChange();
+                }.bind(this));
+            },
+            store: function () {
+                this.store = createStore();
+                this.listenTo(this.listView, 'selection:clear', this.store.clear);
+                this.listenTo(this.listView, 'selection:add', this.store.add);
+                this.listenTo(this.listView, 'selection:remove', this.store.remove);
+
+                function createStore() {
+                    var hash = {}, selection = {};
+                    return {
+                        setHash: function (data) {
+                            // full data
+                            hash = data;
+                        },
+                        add: function (list) {
+                            _(list).each(function (id) { selection[id] = true; });
+                        },
+                        remove: function (list) {
+                            list = [].concat(list);
+                            _(list).each(function (id) {
+                                delete selection[id];
+                            });
+                        },
+                        clear: function () {
+                            selection = {};
+                        },
+                        getIds: function () {
+                            return _(selection).keys();
+                        },
+                        get: function () {
+                            return _(selection)
+                                .chain()
+                                .keys()
+                                .map(function (cid) { return hash[cid]; }, this)
+                                .compact()
+                                .value();
+                        },
+                        resolve: function (cid) {
+                            return hash[cid];
+                        }
+                    };
+                }
+            },
+            footer: function () {
+                this.$('.modal-footer').prepend(
+                    this.tokenview.$el
+                );
+            },
             onInput: function () {
                 var view = this;
                 var onInput = _.debounce(function () {
@@ -600,42 +679,17 @@ define('io.ox/contacts/addressbook/popup', [
             },
             onSelectionChange: function () {
 
-                var selection = this.selection = {};
-
-                function clearSelection(e) {
-                    e.preventDefault();
-                    selection = this.selection = {};
-                    this.listView.selection.clear();
-                    this.listView.selection.triggerChange();
-                }
+                if (!this.tokenview) return;
 
                 this.listenTo(this.listView, 'selection:change', function () {
 
-                    var array = this.flattenItems(_(selection).keys()),
-                        summary = this.$('.selection-summary').empty(),
-                        n = array.length,
-                        hasItems = !!n;
+                    var list = this.store.get();
+                    // pick relavant values
+                    this.tokenview.render(_.map(list, function (obj) {
+                        return { title: obj.email, cid: obj.cid };
+                    }));
 
-                    if (!hasItems) return summary.hide();
-
-                    var addresses = _(array).pluck('email').join(', ');
-                    summary.append(
-                        $('<div>').append(
-                            $('<span class="count pull-left">').text(
-                                useLabels ?
-                                //#. %1$d is number of selected items (addresses/groups) in the list
-                                gt.format(gt.ngettext('%1$d item selected', '%1$d items selected', n), n) :
-                                //#. %1$d is number of selected addresses
-                                gt.format(gt.ngettext('%1$d address selected', '%1$d addresses selected', n), n)
-                            ),
-                            $('<a href="#" class="pull-right" role="button">')
-                            .text(gt('Clear selection'))
-                            .on('click', $.proxy(clearSelection, this))
-                        ),
-                        $('<div class="addresses">').attr('title', addresses).text(addresses)
-                    );
-
-                    summary.show();
+                    if (!list.length) return;
 
                     // adjust scrollTop to avoid overlapping of last item (bug 49035)
                     var focus = this.listView.$('.list-item:focus');
@@ -646,18 +700,11 @@ define('io.ox/contacts/addressbook/popup', [
                         height = this.listView.$el.outerHeight();
 
                     if (bottom > height) this.listView.el.scrollTop += bottom - height;
-                });
-
-                this.listenTo(this.listView, 'selection:add', function (array) {
-                    _(array).each(function (id) { selection[id] = true; });
-                });
-
-                this.listenTo(this.listView, 'selection:remove', function (array) {
-                    _(array).each(function (id) { delete selection[id]; });
-                });
+                }.bind(this));
             }
         })
         .build(function () {
+            var self = this;
 
             // use a template for maximum performance
             // yep, no extensions here; too slow for find-as-you-type
@@ -667,13 +714,13 @@ define('io.ox/contacts/addressbook/popup', [
                 '  <div class="list-item-checkmark"><i class="fa fa-checkmark" aria-hidden="true"></i></div>' +
                 '  <div class="list-item-content">' +
                 '    <% if (item.list) { %>' +
-                '      <div class="contact-picture distribution-list" aria-label="hidden"><i class="fa fa-align-justify"></i></div>' +
+                '      <div class="contact-picture distribution-list" aria-hidden="true"><i class="fa fa-align-justify"></i></div>' +
                 '    <% } else if (item.label) { %>' +
-                '      <div class="contact-picture label" aria-label="hidden"><i class="fa fa-users"></i></div>' +
+                '      <div class="contact-picture label" aria-hidden="true"><i class="fa fa-users"></i></div>' +
                 '    <% } else if (item.image) { %>' +
-                '      <div class="contact-picture image" data-original="<%= item.image %>" aria-label="hidden"></div>' +
+                '      <div class="contact-picture image" data-original="<%= item.image %>" aria-hidden="true"></div>' +
                 '    <% } else { %>' +
-                '      <div class="contact-picture initials <%= item.initial_color %>" aria-label="hidden"><%- item.initials %></div>' +
+                '      <div class="contact-picture initials <%= item.initial_color %>" aria-hidden="true"><%- item.initials %></div>' +
                 '    <% } %>' +
                 '    <div class="name">' +
                 '       <%= item.full_name_html || item.email || "\u00A0" %>' +
@@ -718,7 +765,7 @@ define('io.ox/contacts/addressbook/popup', [
                     if (appeared[url]) node.css('background-image', 'url(' + url + ')'); else node.lazyload();
                 });
                 // restore selection
-                var ids = _(this.selection).keys();
+                var ids = this.store.getIds();
                 this.listView.selection.set(ids);
             };
 
@@ -726,10 +773,8 @@ define('io.ox/contacts/addressbook/popup', [
                 var $el = this.$('.list-view');
                 $el[0].innerHTML = '';
                 $el.append(
-                    $('<div class="message-empty-container">').append(
-                        $('<div class="message-empty">').text(
-                            options.isSearch ? gt('No matching items found.') : gt('Empty')
-                        )
+                    $('<div class="notification">').text(
+                        options.isSearch ? gt('No matching items found.') : gt('Empty')
                     )
                 );
             };
@@ -766,18 +811,31 @@ define('io.ox/contacts/addressbook/popup', [
             this.resolveItems = function (ids) {
                 return _(ids)
                     .chain()
-                    .map(function (cid) { return this.hash[cid]; }, this)
+                    .map(function (cid) { return this.store.resolve(cid); }, this)
                     .compact()
                     .value();
             };
 
-            this.flattenItems = function (ids) {
+            this.flattenItems = function (ids, options) {
+                options = options || {};
+                if (options.yellOmitted) {
+                    self.omittedContacts = [];
+                    var items = flatten(this.resolveItems(ids));
+                    util.validateDistributionList(self.omittedContacts);
+                    delete self.omittedContacts;
+                    return items;
+                }
                 return flatten(this.resolveItems(ids));
             };
 
             function flatten(list) {
                 return _(list)
                     .chain()
+                    .filter(function (item) {
+                        if (self.omittedContacts !== undefined && !item.list && !(item.mail || item.email)) self.omittedContacts.push(item);
+                        // only distribution lists and items with a mail address
+                        return (item.list || item.label) || (item.mail || item.email);
+                    })
                     .map(function (item) {
                         if (item.list || item.label) return flatten(item.list || item.label);
                         var name = item.mail_full_name, mail = item.mail || item.email;
@@ -786,7 +844,8 @@ define('io.ox/contacts/addressbook/popup', [
                             display_name: name,
                             id: item.id,
                             folder_id: item.folder_id,
-                            email: mail
+                            email: mail,
+                            field: item.field
                         };
                     }, this)
                     .flatten()
@@ -802,9 +861,9 @@ define('io.ox/contacts/addressbook/popup', [
                 this.$body.empty().addClass('error').text(e.error || e);
             },
             'select': function () {
-                var ids = _(this.selection).keys();
+                var ids = this.store.getIds();
                 if (ox.debug) console.log('select', ids, this.flattenItems(ids));
-                if (_.isFunction(callback)) callback(this.flattenItems(ids));
+                if (_.isFunction(callback)) callback(this.flattenItems(ids, { yellOmitted: true }));
             }
         })
         .addCancelButton()
@@ -821,10 +880,184 @@ define('io.ox/contacts/addressbook/popup', [
     void require(['io.ox/contacts/addressbook/popup'], function (popup) { popup.open(_.inspect); });
     */
 
+    function addToken(item, index) {
+        return $('<li class="list-item selectable removable token" role="option">').attr({
+            'id': _.uniqueId('token'),
+            'data-cid': item.cid,
+            'data-index': index
+        }).append(
+            $('<span class="token-label">').text(item.title),
+            $('<a href="#" class="token-action remove" tabindex="-1" aria-hidden="true">').attr('title', gt('Remove')).append(
+                // TODO: title=remove
+                $('<i class="fa fa-times" aria-hidden="true">')
+            )
+        );
+    }
+
+    // TODO: core a11y
+    function Iterator(context) {
+        function get(index) {
+            return context.$list.get(index);
+        }
+        return {
+            first: function () {
+                return get(0);
+            },
+            last: function () {
+                return get(context.$list.length - 1);
+            },
+            next: function () {
+                if (context.$selected.is(':last-child')) return this.first();
+                var index = this.current();
+                return index < 0 ? this.first() : get(index + 1);
+            },
+            prev: function () {
+                if (context.$selected.is(':first-child')) return this.last();
+                var index = this.current();
+                return index < 0 ? this.last() : get(index - 1);
+            },
+            current: function () {
+                return context.$list.index(context.$selected);
+            }
+        };
+    }
+
+    /**
+    * - summary of an externally managed selection
+    * - minimal set of actions (remove single item, clear whole selection)
+    * - external logic has to trigger render() on selection change
+    * - external logic has to process triggered events: 'remove' and 'clear'
+    */
+
+    var TokenView = Backbone.DisposableView.extend({
+
+        className: 'selection-summary',
+
+        attributes: { role: 'region' },
+
+        initialize: function (opt) {
+            this.opt = _.extend({
+                selector: '.addresses',
+                useLabels: false
+            }, opt);
+            // references
+            this.$list = $();
+            this.$selected = $();
+            // listen
+            this.$el
+                // a11y.js
+                .on('remove', this.opt.selector, this.onRemove.bind(this))
+                .on('click', '.token', this.onClick.bind(this))
+                .on('click', '.remove', this.onRemove.bind(this))
+                .on('click', '.clear', this.onClear.bind(this));
+            // iterator
+            this.iterator = Iterator(this);
+        },
+
+        getContainer: function () {
+            return this.$(this.opt.selector);
+        },
+
+        // param: index or node
+        select: function (node) {
+            // reset old
+            this.$selected
+                .attr('aria-checked', false)
+                .removeClass('selected');
+            // set new
+            this.$selected = $(node)
+                .attr('aria-checked', true)
+                .addClass('selected');
+            // update container
+            this.getContainer().attr('aria-activedescendant', this.$selected.attr('id'));
+        },
+
+        render: function (list) {
+            var length = list.length,
+                selectionLabel, description;
+
+            this.$el.empty();
+
+            if (!length) {
+                this.$el.hide();
+                return this;
+            }
+
+            // TODO: gt comment
+            if (this.opt.useLabels) {
+                //#. %1$d is number of selected items (addresses/groups) in the list
+                selectionLabel = gt.format(gt.ngettext('%1$d item selected', '%1$d items selected', length), length);
+                description = gt('The selected items. Press Backspace or Delete to remove.');
+            } else {
+                //#. %1$d is number of selected addresses
+                selectionLabel = gt.format(gt.ngettext('%1$d address selected', '%1$d addresses selected', length), length);
+                description = gt('The selected addresses. Press Backspace or Delete to remove.');
+            }
+
+            this.$el.append(
+                // toolbar
+                $('<div class="toolbar">').append(
+                    $('<span role="header" aria-live="polite" class="count pull-left">').text(selectionLabel),
+                    $('<a href="#" class="pull-right clear" role="button">').text(gt('Clear selection'))
+                ),
+                // list
+                $('<div aria-live="polite" aria-relevant="removals" aria-hidden="false">').attr('aria-label', description).append(
+                    $('<ul class="addresses unstyled listbox" tabindex="0" role="listbox">')
+                        .append(_(list).map(addToken))
+                )
+            );
+
+            // update references
+            this.$list = this.getContainer().children();
+            // restore selection
+            this.restore();
+            this.$el.show();
+
+            return this;
+        },
+
+        restore: function () {
+            var node;
+            if (!this.$list.length || this.$list.index(this.$selected) > -1) return;
+            // redraw of previously selected
+            if (this.$selected.attr('data-cid')) {
+                node = this.$list.filter('[data-cid="' + this.$selected.attr('data-cid') + '"]');
+                if (node.length) return this.select(node);
+            }
+            // TODO: use memory instead of dom
+            // restore index of removed token
+            if (this.$selected.attr('data-index')) {
+                node = this.$list.get(parseInt(this.$selected.attr('data-index'), 10));
+                if (node) return this.select(node);
+                return this.select(this.iterator.last());
+            }
+            this.select(this.iterator.first());
+        },
+
+        onClick: function (e) {
+            this.select($(e.target).closest('.token'));
+        },
+
+        onRemove: function (e) {
+            var node = $(e.target).closest('.token');
+            if (!node || !node.length) node = this.$selected;
+            // propagate
+            this.trigger('remove', node.attr('data-cid'));
+            // restore focus after remove/render was triggered
+            if (this.$list.length) this.getContainer().focus();
+        },
+
+        onClear: function (e) {
+            e.preventDefault();
+            this.trigger('clear');
+        }
+    });
+
     return {
         buildIndex: buildIndex,
         searchIndex: searchIndex,
         getAllMailAddresses: getAllMailAddresses,
+        TokenView: TokenView,
         open: open
     };
 });
