@@ -18,11 +18,11 @@ define('io.ox/contacts/api', [
     'io.ox/core/notifications',
     'io.ox/core/cache',
     'io.ox/contacts/util',
+    'io.ox/core/util',
     'l10n/ja_JP/io.ox/collation',
     'settings!io.ox/contacts',
-    'io.ox/core/util',
     'io.ox/core/capabilities'
-], function (ext, http, apiFactory, notifications, cache, util, collation, settings, coreUtil, capabilities) {
+], function (ext, http, apiFactory, notifications, cache, util, coreUtil, collation, settings, capabilities) {
 
     'use strict';
 
@@ -76,7 +76,7 @@ define('io.ox/contacts/api', [
             all: {
                 action: 'all',
                 folder: '6',
-                columns: '20,1,101,607',
+                columns:  ox.language === 'ja_JP' ? '20,1,101,555,556,557,607' : '20,1,101,607',
                 extendColumns: 'io.ox/contacts/api/all',
                 // 607 = magic field
                 sort: '607',
@@ -87,7 +87,7 @@ define('io.ox/contacts/api', [
             },
             list: {
                 action: 'list',
-                columns: '20,1,101,500,501,502,505,520,524,555,556,557,569,592,602,606,607,5,2',
+                columns: '20,1,101,500,501,502,505,520,524,555,556,557,569,592,602,606,607,616,617,5,2',
                 extendColumns: 'io.ox/contacts/api/list'
             },
             get: {
@@ -95,7 +95,7 @@ define('io.ox/contacts/api', [
             },
             search: {
                 action: 'search',
-                columns: '20,1,101,500,501,502,505,520,524,555,556,557,569,592,602,606,607,5,2',
+                columns: '20,1,101,500,501,502,505,520,524,555,556,557,569,592,602,606,607,616,617,5,2',
                 extendColumns: 'io.ox/contacts/api/list',
                 // magic sort field: ignores asc/desc
                 sort: '609',
@@ -175,7 +175,7 @@ define('io.ox/contacts/api', [
             },
             advancedsearch: {
                 action: 'advancedSearch',
-                columns: '20,1,101,500,501,502,505,520,524,555,556,557,569,592,602,606,607',
+                columns: '20,1,101,500,501,502,505,520,524,555,556,557,569,592,602,606,607,616,617',
                 extendColumns: 'io.ox/contacts/api/list',
                 // magic sort field: ignores asc/desc
                 sort: '607',
@@ -231,7 +231,20 @@ define('io.ox/contacts/api', [
             all: function (response) {
                 // japanese sorting
                 if (ox.language === 'ja_JP') {
-                    response.sort(collation.sorter);
+
+                    // add som additional info for sorting
+                    _(response).each(function (obj) {
+                        obj.email = obj.email1 || obj.email2 || obj.email3 || '';
+                        obj.sort_name_without_mail = obj.sort_name;
+                    });
+
+                    response.sort(collation.sorterWithMail);
+
+                    // remove info
+                    _(response).each(function (obj) {
+                        _(obj).omit('email', 'sort_name_without_mail');
+                    });
+
                     //console.debug('Japanese order', _(response).pluck('sort_name'));
                     return response;
                 }
@@ -571,6 +584,7 @@ define('io.ox/contacts/api', [
         fetchCache.clear();
         api.caches.get.clear();
         api.trigger('import');
+        api.trigger('refresh.all');
     });
 
     /** @define {object} simple contact cache */
@@ -637,7 +651,8 @@ define('io.ox/contacts/api', [
                     if (data.image1_url) {
                         data.image1_url = data.image1_url
                             .replace(/^https?\:\/\/[^\/]+/i, '');
-                        data.image1_url = coreUtil.replacePrefix(data.image1_url, ox.apiRoot);
+                        data.image1_url = coreUtil.replacePrefix(data.image1_url);
+                        data.image1_url = coreUtil.getShardingRoot(data.image1_url);
                     }
                     // use first contact
                     return fetchCache.add(address, data);
@@ -708,6 +723,7 @@ define('io.ox/contacts/api', [
         return function (node, data, options) {
 
             var params,
+                useApi = options.api || 'contact',
                 url,
                 opt = _.extend({
                     width: 48,
@@ -718,7 +734,7 @@ define('io.ox/contacts/api', [
                     effect: 'show',
                     urlOnly: false
                 }, options);
-
+            delete opt.api;
             // use copy of data object because of delete-statements
             data = _.clone(data);
 
@@ -754,7 +770,8 @@ define('io.ox/contacts/api', [
                     context: ox.context_id,
                     sequence: data.last_modified
                 });
-                url = data.image1_url = coreUtil.replacePrefix(data.image1_url, ox.apiRoot) + '&' + $.param(params);
+                url = data.image1_url = coreUtil.replacePrefix(data.image1_url) + '&' + $.param(params);
+                url = coreUtil.getShardingRoot(url);
 
             } else if (!data.email && !data.email1 && !data.mail && !data.contact_id && !data.id && !data.internal_userid) {
                 url = fallback;
@@ -802,7 +819,7 @@ define('io.ox/contacts/api', [
                 }
             }
 
-            url = ox.apiRoot + '/halo/contact/picture?' + $.param(params);
+            url = coreUtil.getShardingRoot((useApi === 'user' ? '/image/user/picture?' : '/halo/contact/picture?') + $.param(params));
 
             // cached?
             if (cachesURLs[url]) {
