@@ -45,7 +45,7 @@ define('io.ox/contacts/detail/main', [
                     });
 
                     app.getWindowNode().addClass('detail-view-app').append(
-                        $('<div class="f6-target detail-view-container" role="complementary" tabindex="0">').attr('aria-label', label).append(
+                        $('<div class="f6-target detail-view-container" role="complementary" tabindex="-1">').attr('aria-label', label).append(
                             detailView.draw(baton)
                         )
                     );
