@@ -263,13 +263,10 @@ define('io.ox/contacts/edit/view-form', [
             index: 300,
             id: 'showall',
             draw: function (baton) {
+                var guid = _.uniqueId('form-control-label-');
                 this.append(
-                    $('<label class="checkbox-inline">').append(
-                        $('<input>')
-                            .addClass('toggle-check')
-                            .attr({
-                                type: 'checkbox'
-                            })
+                    $('<label class="checkbox-inline">').attr('for', guid).append(
+                        $('<input type="checkbox" class="toggle-check">').attr('id', guid)
                             .on('change', function (e) {
                                 e.preventDefault();
                                 toggle.call(baton.parentView.$el);
@@ -288,10 +285,10 @@ define('io.ox/contacts/edit/view-form', [
                 require(['io.ox/metrics/main'], function (metrics) {
                     if (!metrics.isEnabled()) return;
                     // buttons
-                    self.delegate('[data-action]', 'mousedown', function (e) {
+                    self.on('mousedown', '[data-action]', function (e) {
                         var node =  $(e.target);
                         metrics.trackEvent({
-                            app: 'calendar',
+                            app: 'contacts',
                             target: 'edit/contact/toolbar',
                             type: 'click',
                             action: node.attr('data-action') || node.attr('data-name'),
@@ -299,9 +296,9 @@ define('io.ox/contacts/edit/view-form', [
                         });
                     });
                     // toggle
-                    self.delegate('.checkbox-inline', 'mousedown', function () {
+                    self.on('mousedown', '.checkbox-inline', function () {
                         metrics.trackEvent({
-                            app: 'calendar',
+                            app: 'contacts',
                             target: 'edit/contact/toolbar',
                             type: 'click',
                             action: 'show-all-fields'
@@ -542,10 +539,11 @@ define('io.ox/contacts/edit/view-form', [
         }
 
         function drawCheckbox(options, model) {
+            var guid = _.uniqueId('form-control-label-');
             this.append(
                 $('<div class="col-lg-12 checkbox">').append(
-                    $('<label>').append(
-                        new mini.CheckboxView({ name: options.field, model: model }).render().$el,
+                    $('<label>').attr('for', guid).append(
+                        new mini.CheckboxView({ id: guid, name: options.field, model: model }).render().$el,
                         $.txt(' '),
                         $.txt(options.label)
                     )
@@ -625,9 +623,9 @@ define('io.ox/contacts/edit/view-form', [
                         block = $('<fieldset class="block" role="group">')
                             .attr({ 'data-id': id, 'aria-labelledby': guid })
                             .append(
-                                $('<legend class="group">')
-                                .attr('id', guid)
-                                .text(meta.i18n[id])
+                                $('<legend class="group">').append(
+                                    $('<h2>').attr('id', guid).text(meta.i18n[id])
+                                )
                             );
 
                     if (id === 'attachments') {
