@@ -23,14 +23,16 @@ define('io.ox/contacts/view-detail', [
     'io.ox/core/folder/breadcrumb',
     'io.ox/core/extPatterns/links',
     'io.ox/core/util',
+    'io.ox/core/locale/postal-address',
     'io.ox/core/capabilities',
     'gettext!io.ox/contacts',
     'settings!io.ox/contacts',
+    'settings!io.ox/core',
     'io.ox/core/tk/attachments',
     'io.ox/core/http',
     'static/3rd.party/purify.min.js',
     'less!io.ox/contacts/style'
-], function (ext, util, api, actions, model, pViews, pModel, BreadcrumbView, links, coreUtil, capabilities, gt, settings, attachments, http, DOMPurify) {
+], function (ext, util, api, actions, model, pViews, pModel, BreadcrumbView, links, coreUtil, postalAddress, capabilities, gt, settings, coreSettings, attachments, http, DOMPurify) {
 
     'use strict';
 
@@ -107,9 +109,9 @@ define('io.ox/contacts/view-detail', [
         index: (INDEX += 100),
         id: 'inline-actions',
         draw: function (baton) {
-            if (!api.looksLikeResource(baton.data)) {
-                ext.point('io.ox/contacts/detail/actions').invoke('draw', this, baton);
-            }
+            if (api.looksLikeResource(baton.data)) return;
+            if (coreSettings.get('features/hideAddressBook')) return;
+            ext.point('io.ox/contacts/detail/actions').invoke('draw', this, baton);
         }
     });
 
@@ -257,7 +259,7 @@ define('io.ox/contacts/view-detail', [
                 hash = {}, $list;
 
             this.append(
-                count === 0 ? $('<div class="list-count">').text(gt('This list has no contacts yet')) : $(),
+                count === 0 ? $('<div class="list-count">').text(gt('This list has no members yet')) : $(),
                 $list = $('<ul class="member-list list-unstyled">')
             );
 
@@ -289,7 +291,7 @@ define('io.ox/contacts/view-detail', [
         var args = _(arguments).toArray(),
             rows = _(args.slice(1)).compact(),
             noDl = _.isBoolean(args.slice(-1)[0]) ? removeAndSplice() : false,
-            block = $('<fieldset class="block">'),
+            block = $('<section class="block">'),
             dl = $('<dl class="dl-horizontal">'),
             self = noDl ? block : dl.appendTo(block);
 
@@ -301,7 +303,7 @@ define('io.ox/contacts/view-detail', [
         });
 
         return block.prepend(
-            $('<legend>').text(args[0])
+            $('<h2>').text(args[0])
         );
     }
 
@@ -328,9 +330,11 @@ define('io.ox/contacts/view-detail', [
     }
 
     function clickMail(e) {
-        e.preventDefault();
-        // set recipient and open compose
-        ox.registry.call('mail-compose', 'compose', { to: [[e.data.display_name, e.data.email]] });
+        if (capabilities.has('webmail')) {
+            e.preventDefault();
+            // set recipient and open compose
+            ox.registry.call('mail-compose', 'compose', { to: [[e.data.display_name, e.data.email]] });
+        }
     }
 
     function mail(address, name, id) {
@@ -401,21 +405,9 @@ define('io.ox/contacts/view-detail', [
     // type is 'business' or 'home' or 'other'
     function address(data, type) {
 
-        data = _(['street', 'postal_code', 'city', 'state', 'country']).map(function (field) {
-            return data[field + '_' + type] || '';
-        });
-
-        if (!_.some(data)) return null;
-
-        var text =
-            //#. Format of addresses
-            //#. %1$s is the street
-            //#. %2$s is the postal code
-            //#. %3$s is the city
-            //#. %4$s is the state
-            //#. %5$s is the country
-            gt('%1$s\n%2$s %3$s\n%4$s\n%5$s', data[0], data[1], data[2], data[3], data[4]);
+        var text = postalAddress.format(data, type);
 
+        if (!text) return null;
         var services = {
             google: { label: gt('Google Maps'), url: 'https://www.google.com/maps?q=' },
             osm: { label: gt('Open Street Map'), url: 'https://www.openstreetmap.org/search?query=' },
@@ -462,8 +454,8 @@ define('io.ox/contacts/view-detail', [
                 var comment = $.trim(baton.data.note || '');
                 if (comment !== '') {
                     this.append(
-                        $('<fieldset>').append(
-                            $('<legend class="sr-only">').text(gt('Comment')),
+                        $('<section>').append(
+                            $('<h2 class="sr-only">').text(gt('Comment')),
                             _.nltobr(comment, $('<div class="comment">'))
                         )
                     );
@@ -751,6 +743,7 @@ define('io.ox/contacts/view-detail', [
 
             // this is also used by halo, so we might miss a folder id
             if (!id) return;
+            if (coreSettings.get('features/hideAddressBook')) return;
 
             // don't show folders path for folder 6 if global address book is disabled
             if (String(id) === '6' && !capabilities.has('gab')) return;
