@@ -189,7 +189,6 @@ define('io.ox/core/api/account', [
     api.hasDSCAccount = function () {
         return !_.isEmpty(dscHash);
     };
-
     /**
      * get unified mailbox name
      * @return { deferred} returns array or null
@@ -287,6 +286,15 @@ define('io.ox/core/api/account', [
         return typeHash[id] !== undefined;
     };
 
+    api.isMalicious = function (id, blacklist) {
+        // includes simple subfolder checks
+        if (api.is('spam', id)) return true;
+        if (api.is('confirmed_spam', id)) return true;
+        return _(blacklist).some(function (folder) {
+            return folder === id || (id).indexOf(folder + separator) === 0;
+        });
+    };
+
     api.getType = function (id) {
         if (id === 'virtual/all-unseen') return 'unseen';
         return typeHash[id];
@@ -358,11 +366,9 @@ define('io.ox/core/api/account', [
     };
 
     api.getDefaultAddress = function () {
-        return require(['settings!io.ox/mail']).then(function (settings) {
-            return api.get(0).then(ensureDisplayName).then(function (account) {
-                var defaultSendAddress = $.trim(settings.get('defaultSendAddress', ''));
-                return [account.personal, defaultSendAddress || account.primary_address];
-            });
+        return api.get(0).then(ensureDisplayName).then(function (account) {
+            var defaultSendAddress = $.trim(settings.get('defaultSendAddress', ''));
+            return [account.personal, defaultSendAddress || account.primary_address];
         });
     };
 
@@ -372,15 +378,17 @@ define('io.ox/core/api/account', [
     api.getValidAddress = function (data) {
         return api.getAllSenderAddresses().then(function (a) {
             if (_.isEmpty(a)) return;
-            // Find correct display name
-            if (!_.isEmpty(data.from)) data.from = a.filter(function (from) { return from[1] === data.from[0][1]; });
-            // Set default sender if data from is empty
-            if (_.isEmpty(data.from)) {
-                api.getPrimaryAddress().then(function (defaultAddress) {
-                    data.from = [defaultAddress];
+            // set correct display name
+            if (!_.isEmpty(data.from)) {
+                data.from = a.filter(function (from) {
+                    return from[1] === data.from[0][1].toLowerCase();
                 });
             }
-            return data;
+            if (!_.isEmpty(data.from)) return data;
+            // use primary account as fallback
+            return api.getPrimaryAddress().then(function (defaultAddress) {
+                return _.extend(data, { from: [defaultAddress] });
+            });
         });
     };
 
@@ -561,10 +569,11 @@ define('io.ox/core/api/account', [
                 // add inbox first
                 typeHash['default' + account.id + '/INBOX'] = 'inbox';
                 // remember types (explicit order!)
-                _('sent drafts trash spam archive'.split(' ')).each(function (type) {
+                _('drafts sent spam trash archive confirmed_spam'.split(' ')).each(function (type) {
                     // fullname is favored over short name
-                    var short_name = account[type], full_name = account[type + '_fullname'];
-                    typeHash[full_name || short_name] = type;
+                    var short_name = account[type], full_name = account[type + '_fullname'], name = full_name || short_name;
+                    // check to avoid unwanted overrides
+                    if (!typeHash[name]) typeHash[name] = type;
                 });
             });
         });
@@ -712,6 +721,8 @@ define('io.ox/core/api/account', [
             }
 
             return reload().done(function (result) {
+                // add folder type full names
+                result = process(result);
                 // update call returned the new account (this is the case for mail)
                 api.cache[id] = result;
             })
