@@ -103,7 +103,7 @@ define('io.ox/core/api/collection-pool', ['io.ox/core/api/backbone'], function (
             // ignore detail collection and those with gc=false, e.g. all-visible
             if (id === 'detail' || entry.collection.gc === false) return;
             // mark as expired
-            entry.collection.expired = true;
+            entry.collection.expire();
         });
     }
 
@@ -137,6 +137,11 @@ define('io.ox/core/api/collection-pool', ['io.ox/core/api/backbone'], function (
             collection.complete = false;
             collection.sorted = true;
 
+            collection.expire = function () {
+                this.expired = true;
+                this.trigger('expire');
+            };
+
             // to simplify debugging
             collection.cid = cid;
 
@@ -279,7 +284,7 @@ define('io.ox/core/api/collection-pool', ['io.ox/core/api/backbone'], function (
 
         resetFolder: function (ids) {
             var list = _(this.getByFolder(ids));
-            list.each(function (collection) { collection.expired = true; });
+            list.invoke('expire');
             return list;
         }
     });
