@@ -209,8 +209,8 @@ define('io.ox/core/boot/form', [
         language.render();
 
         // update header
-        $('#io-ox-login-header-prefix').text((sc.pageHeaderPrefix || '\u00A0') + ' ');
-        $('#io-ox-login-header-label').text(sc.pageHeader || '\u00A0');
+        $('#io-ox-login-header-prefix').text((sc.pageHeaderPrefix || '\u00A0') + ' ').attr('aria-hidden', false);
+        $('#io-ox-login-header-label').text(sc.pageHeader || '\u00A0').attr('aria-hidden', false);
 
         // update footer
         var footer = sc.copyright ? sc.copyright + ' ' : '';
@@ -248,13 +248,12 @@ define('io.ox/core/boot/form', [
             gt('Please enter your email address associated with %1$s. You will receive an email that contains a link to reset your password.', sc.productName)
         );
 
-        util.debug('Load "signin" plugins & set default language');
+        util.debug('Set default language');
 
         // make sure we get 'signin' plugins
         manifests.reset();
 
         return $.when(
-            // load extensions
             manifests.manager.loadPluginsFor('signin'),
             // use browser language
             language.setDefaultLanguage()
