@@ -19,8 +19,9 @@ define('io.ox/core/boot/load', [
     'settings!io.ox/mail',
     'io.ox/core/capabilities',
     'io.ox/core/manifests',
+    'io.ox/core/sockets',
     'io.ox/core/moment'
-], function (themes, util, http, coreSettings, mailSettings, capabilities, manifests) {
+], function (themes, util, http, coreSettings, mailSettings, capabilities, manifests, socket) {
 
     'use strict';
 
@@ -30,6 +31,7 @@ define('io.ox/core/boot/load', [
         util.cleanUp();
 
         prefetch();
+        setupSockets();
         applyHighContrast();
         loadUserTheme();
 
@@ -43,8 +45,9 @@ define('io.ox/core/boot/load', [
     };
 
     function loadUserTheme() {
-
-        var theme = _.url.hash('theme') || coreSettings.get('theme') || 'default',
+        // we have to clear the device function cache or there might be invalid return values, like for example wrong language data.(see Bug 51405)
+        _.device.cache = {};
+        var theme = _.sanitize.option(_.url.hash('theme')) || coreSettings.get('theme') || 'default',
             loadTheme = themes.set(theme),
             //"core" namespace has now a very similar timing to "io.ox/core/main" namespace
             //the only difference is, "core" plugins are loaded completely before
@@ -103,19 +106,25 @@ define('io.ox/core/boot/load', [
         if (coreSettings.get('autoStart') === 'io.ox/mail/main' && capabilities.has('webmail')) {
 
             var folder = 'default0/INBOX',
-                thread = mailSettings.get(['viewOptions', folder, 'thread'], true),
+                thread = mailSettings.get('threadSupport', true) ? mailSettings.get(['viewOptions', folder, 'thread'], true) : false,
                 sort = mailSettings.get(['viewOptions', folder, 'sort'], 610),
                 action = thread ? 'threadedAll' : 'all',
                 params = {
                     action: action,
                     folder: folder,
-                    columns: '102,600,601,602,603,604,605,606,607,608,610,611,614,652',
+                    columns: '102,600,601,602,603,604,605,606,607,608,610,611,614,652,656,X-Open-Xchange-Share-URL',
                     sort: sort,
                     order: mailSettings.get(['viewOptions', folder, 'order'], 'desc'),
+                    categoryid: 'general',
                     timezone: 'utc',
-                    limit: '0,30'
+                    limit: '0,' + mailSettings.get('listview/primaryPageSize', 50)
                 };
 
+            // mail categories (aka tabbed inbox)
+            if (_.device('smartphone') || !capabilities.has('mail_categories') || !mailSettings.get('categories/enabled')) {
+                delete params.categoryid;
+            }
+
             // edge case: no prefetch if sorting is 'from-to' (need to many data we don't have yet)
             if (sort === 'from-to') return;
 
@@ -129,6 +138,18 @@ define('io.ox/core/boot/load', [
         }
     }
 
+    function setupSockets() {
+        // get connected socket
+        socket.getSocket().done(function (socket) {
+            if (capabilities.has('webmail')) {
+                socket.on('ox:mail:new', function (data) {
+                    // simple event forwarding
+                    ox.trigger('socket:mail:new', data);
+                });
+            }
+        });
+    }
+
     function applyHighContrast() {
         $('html').toggleClass('high-contrast', coreSettings.get('highcontrast', false));
     }
