@@ -14,15 +14,31 @@
 define('io.ox/core/boot/login/token', [
     'io.ox/core/boot/util',
     'io.ox/core/boot/config',
+    'io.ox/core/extensions',
     'io.ox/core/session',
     'io.ox/core/http'
-], function (util, config, session, http) {
+], function (util, config, ext, session, http) {
 
     'use strict';
 
+    ext.point('io.ox/core/boot/login').extend({
+        id: 'token',
+        index: 200,
+        login: function (baton) {
+            if (!baton.hash.tokenSession && !baton.hash.session) return;
+            return tokenLogin().then(function () {
+                baton.stopPropagation();
+                ox.trigger('login:success');
+            }, function () {
+                util.debug('Session-based login FAILED', hash.session);
+                ox.trigger('login:fail:session-based');
+            });
+        }
+    });
+
     var hash = {};
 
-    return function tokenLogin() {
+    function tokenLogin() {
 
         hash = _.url.hash();
 
@@ -30,34 +46,44 @@ define('io.ox/core/boot/login/token', [
 
             util.debug('Token-based login ...', hash.tokenSession);
 
-            session.redeemToken(hash.tokenSession).then(
+            return session.redeemToken(hash.tokenSession).then(
                 success,
                 function fail(e) {
                     util.debug('Token-based FAIL', e);
                 }
             );
 
-        } else {
-
-            util.debug('Session-based login ...', hash.session);
-            success({ session: hash.session });
         }
-    };
+
+        util.debug('Session-based login ...', hash.session);
+        return success({ session: hash.session });
+    }
 
     function success(data) {
+        // we use a new deferred here instead of returning $.when
+        // see bug 58910 !
+
+        var def = $.Deferred();
 
         ox.session = data.session;
         ox.secretCookie = hash.secretCookie === 'true';
 
-        // set store cookie?
+        // both, ramup and store are uncritical, they may
+        // fail but will not block the UI. So we use always
+        // The important call is the userconfig and whoami
+        // which will finally resolve the returned deferred
         $.when(
             session.rampup(),
             hash.store === 'true' ? session.store() : $.when()
         )
         .always(function () {
             // fetch user config
-            config.user().done(whoami);
+            config.user()
+                .then(whoami)
+                .then(def.resolve, def.reject);
         });
+
+        return def;
     }
 
     function whoami() {
@@ -66,16 +92,11 @@ define('io.ox/core/boot/login/token', [
             hash.locale = hash.language;
             finalize(hash);
         } else {
-            http.GET({
+            return http.GET({
                 module: 'system',
                 params: { action: 'whoami' }
             })
-            .then(
-                finalize,
-                function fail() {
-                    ox.trigger('login:fail');
-                }
-            );
+            .then(finalize);
         }
     }
 
@@ -105,7 +126,7 @@ define('io.ox/core/boot/login/token', [
             user: null,
             user_id: null
         });
-
-        ox.trigger('login:success');
     }
+
+    return tokenLogin;
 });
