@@ -35,6 +35,7 @@ define('io.ox/core/dropzone', [], function () {
 
         onDrag: function (e) {
             if (!this.$el.parent().is(':visible')) return;
+            if (!this.isSupported()) return;
             switch (e.type) {
                 case 'dragenter':
                 case 'dragover':
@@ -57,6 +58,8 @@ define('io.ox/core/dropzone', [], function () {
             }
         },
 
+        isSupported: _.constant(true),
+
         stop: function (e) {
             e.preventDefault();
             e.stopPropagation();
