@@ -24,18 +24,10 @@ define('io.ox/core/extensions', ['io.ox/core/event'], function (Events) {
 
         // sort by index
         indexSorter = function (a, b) {
-            if (a.index === 'first') {
-                return -1;
-            }
-            if (b.index === 'first') {
-                return 1;
-            }
-            if (a.index === 'last') {
-                return 1;
-            }
-            if (b.index === 'last') {
-                return -1;
-            }
+            if (a.index === 'first') return -1;
+            if (b.index === 'first') return 1;
+            if (a.index === 'last') return 1;
+            if (b.index === 'last') return -1;
             return a.index - b.index;
         };
 
@@ -373,6 +365,19 @@ define('io.ox/core/extensions', ['io.ox/core/event'], function (Events) {
             console.debug('Extension point', this.id, JSON.stringify(this.all()));
         };
 
+        // invoke extensions 'perform' as a waterfall
+        this.cascade = function (baton) {
+            var point = this;
+            return point.reduce(function (def, ext) {
+                if (!def || !def.then) def = $.when(def);
+                return def.then(function () {
+                    if (baton.isPropagationStopped()) return;
+                    if (baton.isDisabled(point.id, ext.id)) return;
+                    return ext.perform.apply(undefined, [baton]);
+                });
+            }, $.when());
+        };
+
         /**
          * get number of enabled extensions
          * @return { integer }
@@ -453,6 +458,10 @@ define('io.ox/core/extensions', ['io.ox/core/event'], function (Events) {
             this.isPropagationStopped = returnTrue;
         },
 
+        resumePropagation: function () {
+            this.isPropagationStopped = returnFalse;
+        },
+
         first: function () {
             return _.isArray(this.data) ? this.data[0] : this.data;
         },
