@@ -20,13 +20,14 @@ define('io.ox/core/folder/api', [
     'io.ox/core/folder/bitmask',
     'io.ox/core/api/account',
     'io.ox/core/api/user',
+    'io.ox/core/api/jobs',
     'io.ox/core/capabilities',
     'io.ox/contacts/util',
     'settings!io.ox/core',
     'settings!io.ox/mail',
     'io.ox/core/api/filestorage',
     'gettext!io.ox/core'
-], function (http, util, sort, blacklist, getFolderTitle, Bitmask, account, userAPI, capabilities, contactUtil, settings, mailSettings, filestorageApi, gt) {
+], function (http, util, sort, blacklist, getFolderTitle, Bitmask, account, userAPI, jobsAPI, capabilities, contactUtil, settings, mailSettings, filestorageApi, gt) {
 
     'use strict';
 
@@ -124,9 +125,7 @@ define('io.ox/core/folder/api', [
             // use account API so it works with non standard accounts as well
             var type = account.getType(model.get('id'));
             // don't count trash or spam root folders
-            if (type === 'trash' || type === 'spam') {
-                return total;
-            }
+            if (type === 'trash' || type === 'spam' || type === 'confirmed_spam') return total;
             return total + (model.get('subtotal') || 0) + (model.get('unread') || 0);
         }, 0);
     }
@@ -199,8 +198,8 @@ define('io.ox/core/folder/api', [
         supportsInternalSharing: function () {
             // drive: always enabled
             if (this.is('drive')) return true;
-            // mail: check gab (webmail, PIM, PIM+infostore)
-            if (this.is('mail')) return capabilities.has('gab');
+            // mail: check gab (webmail, PIM, PIM+infostore) and folder capability (bit 0), see Bug 47229
+            if (this.is('mail')) return capabilities.has('gab') && this.supportsShares();
             // contacts, calendar, tasks
             if (this.is('public')) return capabilities.has('edit_public_folders');
             // non-public foldes
@@ -333,7 +332,7 @@ define('io.ox/core/folder/api', [
                 for (var i = 0; i < models.length; i++) {
                     // use account API so it works with non standard accounts as well
                     var ctype = account.getType(models[i].get('id'));
-                    if (ctype !== 'trash' && ctype !== 'spam') {
+                    if (ctype !== 'trash' && ctype !== 'spam' && ctype !== 'confirmed_spam') {
                         subtotal += (models[i].get('subtotal') || 0) + (models[i].get('unread') || 0);
                         // add virtual parent references
                         if (isVirtual(id)) {
@@ -460,7 +459,7 @@ define('io.ox/core/folder/api', [
         // only define if the user actually has mail
         // otherwise the folder refresh tries to fetch 'default0'
         pool.addModel({
-            folder_id: 'default0',
+            folder_id: 'default0/INBOX',
             id: 'virtual/all-unseen',
             module: 'mail',
             title: gt('Unread messages')
@@ -532,7 +531,11 @@ define('io.ox/core/folder/api', [
     VirtualFolder.prototype.list = function () {
         var id = this.id;
         return this.getter().done(function (array) {
-            _(array).each(injectIndex.bind(null, id));
+            _(array).chain().map(function (folder) {
+                // use current data of virtual folders (for example, unread count could be updated in the meantime)
+                if (isVirtual(folder.id)) return _.extend(folder, pool.getModel(folder.id).toJSON());
+                return folder;
+            }).each(injectIndex.bind(null, id)).value();
             pool.addCollection(getCollectionId(id), array);
             pool.getModel(id).set('subscr_subflds', array.length > 0);
         });
@@ -942,32 +945,11 @@ define('io.ox/core/folder/api', [
         options = _.extend({ silent: false }, options);
         var model = pool.getModel(id).set(changes, { silent: options.silent });
 
+        if (isVirtual(id)) return $.when();
+
         // build data object
-        var data = { folder: changes };
-
-        if (options.notification && !_.isEmpty(options.notification)) {
-            data.notification = options.notification;
-        }
-
-        return http.PUT({
-            module: 'folders',
-            params: {
-                action: 'update',
-                id: id,
-                timezone: 'UTC',
-                tree: tree(id),
-                cascadePermissions: options.cascadePermissions,
-                ignoreWarnings: options.ignoreWarnings
-            },
-            data: data,
-            appendColumns: false
-        })
-        .done(function () {
-            var data = model.toJSON();
-            if (!blacklist.visible(data)) api.trigger('warn:hidden', data);
-        })
-        .then(
-            function success(newId) {
+        var data = { folder: changes },
+            successCallback = function (newId) {
                 // id change? (caused by rename or move)
                 if (id !== newId) model.set('id', newId);
                 if (options.cascadePermissions) refresh();
@@ -988,7 +970,7 @@ define('io.ox/core/folder/api', [
                             });
                 }
             },
-            function fail(error) {
+            failCallback = function (error) {
                 //get fresh data for the model (the current ones are wrong since we applied the changes early to be responsive)
                 api.get(id, { cache: false });
                 if (error && error.code && error.code === 'FLD-0018') {
@@ -998,7 +980,48 @@ define('io.ox/core/folder/api', [
                     api.trigger('update:fail', error, id);
                 }
                 return error;
-            }
+            };
+
+        if (options.notification && !_.isEmpty(options.notification)) {
+            data.notification = options.notification;
+        }
+
+        return http.PUT({
+            module: 'folders',
+            params: {
+                action: 'update',
+                id: id,
+                timezone: 'UTC',
+                tree: tree(id),
+                cascadePermissions: options.cascadePermissions,
+                ignoreWarnings: options.ignoreWarnings,
+                // special parameter for long running operations (drive folder move/copy)
+                allow_enqueue: options.enqueue
+            },
+            data: data,
+            appendColumns: false
+        })
+        .done(function () {
+            var data = model.toJSON();
+            if (!blacklist.visible(data)) api.trigger('warn:hidden', data);
+        })
+        .then(
+            function success(result) {
+                if (result && options.enqueue && (result.code === 'JOB-0003' || result.job)) {
+                    // long running job. Add to jobs list and return here
+                    //#. %1$s: Folder name
+                    jobsAPI.addJob({
+                        module: 'folders',
+                        action: 'update',
+                        done: false,
+                        showIn: model.get('module'),
+                        id: result.job || result.data.job,
+                        successCallback: successCallback,
+                        failCallback: failCallback });
+                    return result;
+                }
+                return successCallback(result);
+            }, failCallback
         );
     }
 
@@ -1006,11 +1029,12 @@ define('io.ox/core/folder/api', [
     // Move folder
     //
 
-    function move(id, target, ignoreWarnings) {
-
+    function move(id, target, options) {
         // doesn't make sense but let's silently finish
         if (id === target) return $.when();
 
+        options = options || {};
+
         // prepare move
         var model = pool.getModel(id),
             folderId = model.get('folder_id');
@@ -1023,16 +1047,33 @@ define('io.ox/core/folder/api', [
         //set unread to 0 to update subtotal attributes of parent folders (bubbles through the tree)
         model.set('unread', 0);
 
-        return update(id, { folder_id: target }, { ignoreWarnings: ignoreWarnings }).then(
+        return update(id, { folder_id: target }, options).then(
             function success(newId) {
-                // update new parent folder
-                pool.getModel(target).set('subscr_subflds', true);
-                // update all virtual folders
-                virtual.refresh();
-                // add folder to collection
-                pool.getCollection(target).add(model);
-                // trigger event
-                api.trigger('move', id, newId);
+                var cont = function (data) {
+                    if (data.error) {
+                        // re-add folder
+                        pool.getModel(folderId).set('subscr_subflds', true);
+                        virtual.refresh();
+                        pool.getCollection(folderId).add(model);
+                        throw data;
+                    }
+                    // update new parent folder
+                    pool.getModel(target).set('subscr_subflds', true);
+                    // update all virtual folders
+                    virtual.refresh();
+                    // add folder to collection
+                    pool.getCollection(target).add(model);
+                    // trigger event
+                    api.trigger('move', id, data);
+                };
+
+                // check if we have a long running job
+                if (newId && (newId.code === 'JOB-0003' || newId.job)) {
+                    api.trigger('new:longrunningjob');
+                    jobsAPI.on('finished:' + (newId.job || newId.data.job), cont);
+                    return;
+                }
+                cont(newId);
             },
             function fail(error) {
                 // re-add folder
@@ -1115,6 +1156,11 @@ define('io.ox/core/folder/api', [
         _(pool.collections).invoke('remove', model);
     }
 
+    var currentlyDeleted = [];
+    function isBeingDeleted(id) {
+        return _(currentlyDeleted).contains(id);
+    }
+
     function remove(ids, options) {
 
         // ensure array
@@ -1139,7 +1185,8 @@ define('io.ox/core/folder/api', [
         params = {
             action: 'delete',
             failOnError: true,
-            tree: tree(ids[0])
+            tree: tree(ids[0]),
+            extendedResponse: true
         };
 
         if (options && options.isDSC) params.hardDelete = true;
@@ -1151,12 +1198,33 @@ define('io.ox/core/folder/api', [
             data: ids,
             appendColumns: false
         })
-        .done(function () {
-            _(ids).each(function (id) {
+        .done(function (response) {
+            response = response || [];
+            _(ids).each(function (id, index) {
                 var data = hash[id];
                 api.trigger('remove', id, data);
                 api.trigger('remove:' + id, data);
                 api.trigger('remove:' + data.module, data);
+                // get refreshed the model data for folders moved to the trash folder. If they are removed completely we remove the collection
+                // flat models don't have a collection, so no need to remove here
+                if (!isFlat(data.module)) {
+                    // see if this folder was moved to trash or deleted completely
+                    if (api.is('trash', data) || (response[index] && _.isEmpty(response[index].new_path))) {
+                        api.pool.removeCollection(id, { removeModels: true });
+                    } else {
+                        currentlyDeleted.push(id);
+                        // use new path if available, else use id
+                        var pathOrId = (response[index] ? response[index].new_path : id);
+                        api.get(pathOrId, { cache: false }).fail(function (error) {
+                            // folder does not exist
+                            if (error.code === 'FLD-0008') {
+                                api.pool.removeCollection(id, { removeModels: true });
+                            }
+                        }).always(function () {
+                            currentlyDeleted = _(currentlyDeleted).without(id);
+                        });
+                    }
+                }
                 // if this is a trash folder trigger special event (quota updates)
                 if (account.is('trash', id)) api.trigger('cleared-trash');
             });
@@ -1446,6 +1514,7 @@ define('io.ox/core/folder/api', [
         move: move,
         create: create,
         remove: remove,
+        isBeingDeleted: isBeingDeleted,
         clear: clear,
         reload: reload,
         hide: hide,
