@@ -17,6 +17,7 @@ define('io.ox/core/folder/extensions', [
     'io.ox/core/api/account',
     'io.ox/core/extensions',
     'io.ox/core/capabilities',
+    'io.ox/core/upsell',
     'io.ox/contacts/util',
     'io.ox/core/api/user',
     'io.ox/mail/api',
@@ -26,8 +27,9 @@ define('io.ox/core/folder/extensions', [
     'io.ox/core/folder/blacklist',
     'settings!io.ox/core',
     'settings!io.ox/mail',
+    'io.ox/core/http',
     'io.ox/core/folder/favorites'
-], function (TreeNodeView, api, account, ext, capabilities, contactUtil, userAPI, mailAPI, gt, color, UpsellView, blacklist, settings, mailSettings) {
+], function (TreeNodeView, api, account, ext, capabilities, upsell, contactUtil, userAPI, mailAPI, gt, color, UpsellView, blacklist, settings, mailSettings, http) {
 
     'use strict';
 
@@ -36,16 +38,21 @@ define('io.ox/core/folder/extensions', [
     if (capabilities.has('webmail')) {
         // define virtual/standard
         api.virtual.add('virtual/standard', function () {
-            var list = [
-                // inbox
-                api.get(INBOX),
-                // sent, drafts, spam, trash, archive
-                // default0 is alternative for IMAP server that list standard folders below INBOX
-                api.list('default0')
-            ];
+            var defaultFolders = mailSettings.get('defaultFolder') || {},
+                list = [];
+            http.pause();
+            // collect get requests
+            list.push(api.get(INBOX));
             // append all-unssen below INBOX
             if (mailSettings.get('features/unseenFolder', false)) list.push(api.get('virtual/all-unseen'));
-            list.push(api.list(INBOX));
+            // ensure fixed order; rely on defaultFolders (see bug 56563)
+            ['drafts', 'sent', 'spam', 'trash', 'archive'].forEach(function (type) {
+                var folder = defaultFolders[type];
+                if (!folder) return;
+                if (type === 'archive' && !capabilities.has('archive_emails')) return;
+                list.push(api.get(folder));
+            });
+            http.resume();
             return this.concat.apply(this, list);
         });
 
@@ -72,11 +79,20 @@ define('io.ox/core/folder/extensions', [
             // use the setting for dsc here in if-else, also consider altnamespace
             var dsc = mailSettings.get('dsc/enabled', false),
                 id = mailSettings.get('dsc/folder');
-
             // smart cache environment
             if (dsc) {
                 if (account.hasDSCAccount()) {
-                    return api.list(id);
+                    return account.getStatus().then(function (status) {
+                        //remove main account
+                        delete status['0'];
+
+                        // only request if status is at least for one dsc account ok
+                        if (_(status).any(function (account) { return account.status === 'ok'; })) {
+                            return api.list(id);
+                        }
+                        return [];
+                    });
+
                 }
                 // no account yet, return empty array
                 return $.Deferred().resolve([]);
@@ -133,6 +149,13 @@ define('io.ox/core/folder/extensions', [
         return id ? api.get(id) : null;
     }
 
+    function openAttachmentView(e) {
+        e.preventDefault();
+        ox.launch('io.ox/files/main', { folder: attachmentView.all }).done(function () {
+            this.folder.set(attachmentView.all);
+        });
+    }
+
     function getTrashFolder() {
         return api.list('9').then(function (list) {
             return _(list).filter(function (data) {
@@ -141,6 +164,16 @@ define('io.ox/core/folder/extensions', [
         });
     }
 
+    function openMailAutoconfigDialog(e) {
+        e.preventDefault();
+        require(['io.ox/mail/accounts/settings'], function (m) { m.mailAutoconfigDialog(e); });
+    }
+
+    function openUserSettingsDialog(e) {
+        e.preventDefault();
+        require(['io.ox/core/settings/user'], function (m) { m.openModalDialog(); });
+    }
+
     if (capabilities.has('infostore')) {
         api.virtual.add('virtual/drive/private', function () {
             return this.concat(getMyFilesFolder(), getMySharesFolder(), getAllAttachmentsFolder(), getTrashFolder());
@@ -175,11 +208,38 @@ define('io.ox/core/folder/extensions', [
             return _(keychainApi.submodules).filter(function (submodule) {
                 if (services.indexOf(submodule.id) < 0) return false;
                 // we need support for both accounts, Oauth accounts and filestorage accounts.
-                return availableFilestorageServices.indexOf(submodule.id) >= 0;
+                return (!submodule.canAdd || submodule.canAdd.apply(this)) && availableFilestorageServices.indexOf(submodule.id) >= 0;
             });
         });
     }
 
+    function openAddStorageAccount(e) {
+        e.preventDefault();
+        require(['io.ox/files/actions/add-storage-account'], function (addStorageAccount) {
+            addStorageAccount();
+        });
+    }
+
+    function openSubscriptionDialog(e) {
+        e.preventDefault();
+        if (capabilities.has('subscription')) {
+            require(['io.ox/core/sub/subscriptions'], function (subscriptions) {
+                subscriptions.buildSubscribeDialog({
+                    module: e.data.baton.module,
+                    app: e.data.baton.view.app
+                });
+            });
+        } else {
+            if (!upsell.enabled(['subscription'])) return;
+
+            upsell.trigger({
+                type: 'inline-action',
+                id: 'io.ox/core/foldertree/contextmenu/default/subscribe',
+                missing: upsell.missing(['subscription'])
+            });
+        }
+    }
+
     var extensions = {
 
         unifiedFolders: function (tree) {
@@ -202,20 +262,25 @@ define('io.ox/core/folder/extensions', [
         },
 
         standardFolders: function (tree) {
+            var view = new TreeNodeView({
+                filter: function (id, model) {
+                    // do not filter unseen messages folder if enabled
+                    if (model.id === 'virtual/all-unseen' && mailSettings.get('unseenMessagesFolder')) return true;
+                    return account.isStandardFolder(model.id);
+                },
+                folder: 'virtual/standard',
+                headless: true,
+                open: true,
+                tree: tree,
+                parent: tree
+            });
             this.append(
-                // standard folders
-                new TreeNodeView({
-                    filter: function (id, model) {
-                        return account.isStandardFolder(model.id) || model.id === 'virtual/all-unseen';
-                    },
-                    folder: 'virtual/standard',
-                    headless: true,
-                    open: true,
-                    tree: tree,
-                    parent: tree
-                })
-                .render().$el.addClass('standard-folders')
+                view.render().$el.addClass('standard-folders')
             );
+            // show / hide folder on setting change
+            view.listenTo(mailSettings, 'change:unseenMessagesFolder', function () {
+                view.onReset();
+            });
         },
 
         localFolders: function (tree) {
@@ -225,9 +290,8 @@ define('io.ox/core/folder/extensions', [
             var node = new TreeNodeView({
                 filter: function (id, model) {
                     // filtering for DSC folders
-                    if (account.isDSC(model.id)) {
-                        return false;
-                    }
+                    if (account.isDSC(model.id)) return false;
+
                     return true;
                 },
                 contextmenu: 'myfolders',
@@ -300,22 +364,13 @@ define('io.ox/core/folder/extensions', [
         },
 
         addStorageAccount: (function () {
-            if (_.device('smartphone')) return $.noop;
-
-            var links = $('<div class="links">');
+            var links = $('<li class="links" role="presentation">');
 
             function draw() {
                 getAvailableServices().done(function (services) {
                     if (services.length > 0) {
                         links.empty().show().append(
-                            $('<a href="#" data-action="add-storage-account" role="button">')
-                            .text(gt('Add storage account'))
-                            .on('click', function (e) {
-                                e.preventDefault();
-                                require(['io.ox/files/actions/add-storage-account'], function (addStorageAccount) {
-                                    addStorageAccount();
-                                });
-                            })
+                            $('<a href="#" data-action="add-storage-account" role="treeitem">').text(gt('Add storage account')).on('click', openAddStorageAccount)
                         );
                     } else {
                         links.hide();
@@ -336,35 +391,48 @@ define('io.ox/core/folder/extensions', [
             };
         })(),
 
-        addRemoteAccount: function () {
-            if (!capabilities.has('multiple_mail_accounts')) return;
+        subscribe: function (baton) {
+            if (baton.extension.capabilities && !upsell.visible(baton.extension.capabilities)) return;
+            var self = this, title;
 
-            this.append(
-                $('<div class="links">').append(
-                    $('<a href="#" data-action="add-mail-account" role="button">')
-                    .text(gt('Add mail account'))
-                    .on('click', function (e) {
-                        e.preventDefault();
-                        require(['io.ox/mail/accounts/settings'], function (m) {
-                            m.mailAutoconfigDialog(e);
-                        });
-                    })
-                )
-            );
+            require(['io.ox/core/sub/subscriptions'], function (sub) {
+                // if there is nothing configured we do not show the "subscribe" button
+                if (baton.module === 'contacts' && sub.availableServices.contacts) {
+                    title = gt('Subscribe address book');
+                } else if (baton.module === 'calendar' && sub.availableServices.calendar) {
+                    title = gt('Subscribe calendar');
+                } else {
+                    return;
+                }
+
+                self.append(
+                    $('<li role="presentation">').append(
+                        $('<a href="#" data-action="subscribe-external-account" role="treeitem">').text(title).on('click', { baton: baton }, openSubscriptionDialog)
+                    )
+                );
+            });
+        },
+
+        treeLinks: function () {
+            var node = $('<ul class="list-unstyled" role="group">');
+            ext.point('io.ox/core/foldertree/mail/treelinks').invoke('draw', node);
+            this.append($('<li class="links list-unstyled" role="treeitem">').append(node));
         },
 
         allAttachments: function () {
             if (!attachmentView.all) return;
             this.append(
-                $('<div class="links">').append(
-                    $('<a href="#" data-action="all-attachments" role="button">')
-                    .text(gt('View all attachments'))
-                    .on('click', function (e) {
-                        e.preventDefault();
-                        ox.launch('io.ox/files/main', { folder: attachmentView.all }).done(function () {
-                            this.folder.set(attachmentView.all);
-                        });
-                    })
+                $('<li role="presentation">').append(
+                    $('<a href="#" data-action="all-attachments" role="treeitem">').text(gt('View all attachments')).on('click', openAttachmentView)
+                )
+            );
+        },
+
+        addRemoteAccount: function () {
+            if (!capabilities.has('multiple_mail_accounts')) return;
+            this.append(
+                $('<li role="presentation">').append(
+                    $('<a href="#" data-action="add-mail-account" role="treeitem">').text(gt('Add mail account')).on('click', openMailAutoconfigDialog)
                 )
             );
         },
@@ -401,6 +469,17 @@ define('io.ox/core/folder/extensions', [
             );
         },
 
+        myContactData: function () {
+            // check if users can edit their own data (see bug 34617)
+            if (settings.get('user/internalUserEdit', true) === false) return;
+
+            this.append(
+                $('<li role="presentation">').append(
+                    $('<a href="#" data-action="my-contact-data" role="treeitem">').text(gt('My contact data')).on('click', openUserSettingsDialog)
+                )
+            );
+        },
+
         rootFolders: function (tree) {
             var options = {
                 folder: tree.root,
@@ -506,20 +585,15 @@ define('io.ox/core/folder/extensions', [
             draw: extensions.otherFolders
         },
         {
-            id: 'all-attachments',
+            id: 'tree-links',
             index: INDEX += 100,
-            draw: extensions.allAttachments
+            draw: extensions.treeLinks
         },
         {
             id: 'remote-accounts',
             index: INDEX += 100,
             draw: extensions.remoteAccounts
         },
-        {
-            id: 'add-account',
-            index: INDEX += 100,
-            draw: extensions.addRemoteAccount
-        },
         {
             id: 'upsell-mail',
             index: INDEX += 100,
@@ -527,6 +601,19 @@ define('io.ox/core/folder/extensions', [
         }
     );
 
+    ext.point('io.ox/core/foldertree/mail/treelinks').extend(
+        {
+            id: 'all-attachments',
+            index: INDEX += 100,
+            draw: extensions.allAttachments
+        },
+        {
+            id: 'add-account',
+            index: INDEX += 100,
+            draw: extensions.addRemoteAccount
+        }
+    );
+
     ext.point('io.ox/core/foldertree/mail/popup').extend(
         {
             id: 'standard-folders',
@@ -627,6 +714,37 @@ define('io.ox/core/folder/extensions', [
         }
     );
 
+    //
+    // Contacts
+    //
+
+    ext.point('io.ox/core/foldertree/contacts/links').extend(
+        {
+            id: 'subscribe',
+            index: 300,
+            capabilities: ['subscription'],
+            draw: extensions.subscribe
+        },
+        {
+            id: 'my-contact-data',
+            index: 400,
+            draw: extensions.myContactData
+        }
+    );
+
+    //
+    // Calendar
+    //
+
+    ext.point('io.ox/core/foldertree/calendar/links').extend(
+        {
+            id: 'subscribe',
+            index: 300,
+            capabilities: ['subscription'],
+            draw: extensions.subscribe
+        }
+    );
+
     // helper
 
     function addFolder(e) {
@@ -672,16 +790,19 @@ define('io.ox/core/folder/extensions', [
             index: 100,
             draw: function (tree) {
 
-                var links = $('<div class="links">'),
+                var links = $('<ul class="list-unstyled" role="group">'),
                     baton = ext.Baton({ module: module, view: tree, context: tree.context }),
                     folder = 'virtual/flat/' + module,
                     model_id = 'flat/' + module,
                     defaults = { count: 0, empty: false, indent: false, open: false, tree: tree, parent: tree },
                     privateFolders,
                     publicFolders,
-                    placeholder = $('<div>');
+                    placeholder = $('<li role="treeitem">');
 
-                ext.point('io.ox/core/foldertree/' + module + '/links').invoke('draw', links, baton);
+                // no links. Used for example in move folder picker
+                if (!tree.options.noLinks) {
+                    ext.point('io.ox/core/foldertree/' + module + '/links').invoke('draw', links, baton);
+                }
 
                 this.append(placeholder);
 
@@ -706,7 +827,7 @@ define('io.ox/core/folder/extensions', [
                         // private folders
                         privateFolders.render().$el.addClass('section'),
                         // links
-                        links,
+                        $('<li class="links list-unstyled" role="treeitem">').append(links),
                         // public folders
                         publicFolders.render().$el.addClass('section'),
                         // shared with me
@@ -730,41 +851,52 @@ define('io.ox/core/folder/extensions', [
         // Links
         //
 
-        ext.point('io.ox/core/foldertree/' + module + '/links').extend(
-            {
-                index: 200,
-                id: 'private',
-                draw: function (baton) {
+        ext.point('io.ox/core/foldertree/' + module + '/links').extend({
+            index: 200,
+            id: 'private',
+            draw: function (baton) {
+                if (baton.context !== 'app') return;
 
-                    if (baton.context !== 'app') return;
+                var module = baton.module,
+                    folder = api.getDefaultFolder(module),
+                    title = gt('Add new folder');
 
-                    var module = baton.module,
-                        folder = api.getDefaultFolder(module),
-                        title = module === 'calendar' ? gt('Add new calendar') : gt('Add new folder');
+                if (module === 'calendar') title = gt('Add new calendar');
+                else if (module === 'contacts') title = gt('Add new address book');
 
-                    // guests might have no default folder
-                    if (!folder) return;
+                // guests might have no default folder
+                if (!folder) return;
 
-                    this.append(
-                        $('<div>').append(
-                            $('<a href="#" data-action="add-subfolder" role="button">')
-                            .text(title)
-                            .on('click', { folder: folder, module: module }, addFolder)
-                        )
-                    );
-                }
+                this.append(
+                    $('<li role="presentation">').append(
+                        $('<a href="#" data-action="add-subfolder" role="treeitem">').text(title).on('click', { folder: folder, module: module }, addFolder)
+                    )
+                );
             }
-        );
+        });
 
         //
         // Upsell
         //
 
+        ext.point('io.ox/core/foldertree/contacts/links').extend({
+            index: 1000,
+            id: 'upsell-contacts',
+            draw: function (baton) {
+                if (baton.context !== 'app') return;
+
+                this.append(new UpsellView({
+                    id: 'folderview/contacts',
+                    requires: 'carddav',
+                    title: gt('Synchronize with your tablet or smartphone')
+                }).render().$el);
+            }
+        });
+
         ext.point('io.ox/core/foldertree/calendar/links').extend({
-            index: 300,
+            index: 1000,
             id: 'upsell-calendar',
             draw: function (baton) {
-
                 if (baton.context !== 'app') return;
 
                 this.append(new UpsellView({
@@ -811,7 +943,7 @@ define('io.ox/core/folder/extensions', [
                     if (!/^(contacts|calendar|tasks)$/.test(data.module)) return;
                     if (!api.is('shared', data)) return;
 
-                    baton.view.options.a11yDescription.push(gt('Shared by other users'));
+                    baton.view.addA11yDescription(gt('Shared by other users'));
                 }
             },
             {
@@ -820,20 +952,16 @@ define('io.ox/core/folder/extensions', [
                 draw: function (baton) {
 
                     this.find('.folder-node:first .folder-shared:first').remove();
-                    baton.view.options.a11yDescription = baton.view.options.a11yDescription.filter(function (description) {
-                        return description !== gt('You share this folder with other users');
-                    });
 
                     if (_.device('smartphone')) return;
                     // drive has virtual folder 'Shared by me'
                     if (baton.data.module === 'infostore') return;
                     if (!api.is('unlocked', baton.data)) return;
 
-                    this.find('.folder-node:first').append(
-                        $('<i class="fa folder-shared">').attr('title', gt('You share this folder with other users'))
-                        .on('click', { id: baton.data.id }, openPermissions)
+                    baton.view.$.buttons.append(
+                        $('<i class="fa folder-shared">').attr('title', gt('You share this folder with other users')).on('click', { id: baton.data.id }, openPermissions)
                     );
-                    baton.view.options.a11yDescription.push(gt('You share this folder with other users'));
+                    baton.view.addA11yDescription(gt('You share this folder with other users'));
                 }
             },
             {
@@ -849,11 +977,10 @@ define('io.ox/core/folder/extensions', [
                     if (api.is('shared', baton.data)) return;
                     if (!api.is('subscribed', baton.data)) return;
 
-                    this.find('.folder-node:first').append(
-                        $('<i class="fa folder-sub">').attr('title', gt('This folder has subscriptions'))
-                        .on('click', { folder: baton.data }, openSubSettings)
+                    baton.view.$.buttons.append(
+                        $('<i class="fa folder-sub">').attr('title', gt('This folder has subscriptions')).on('click', { folder: baton.data }, openSubSettings)
                     );
-                    baton.view.options.a11yDescription.push(gt('This folder has publications and/or subscriptions'));
+                    baton.view.addA11yDescription(gt('This folder has publications and/or subscriptions'));
                 }
             },
             {
