@@ -15,14 +15,19 @@ define('io.ox/core/folder/favorites', [
     'io.ox/core/folder/node',
     'io.ox/core/folder/api',
     'io.ox/core/extensions',
+    'io.ox/core/upsell',
     'settings!io.ox/core',
     'gettext!io.ox/core'
-], function (TreeNodeView, api, ext, settings, gt) {
+], function (TreeNodeView, api, ext, upsell, settings, gt) {
 
     'use strict';
 
     _('mail contacts calendar tasks infostore'.split(' ')).each(function (module) {
 
+        // skip if no capability (use capabilities from upsell to work in demo mode)
+        if (module === 'mail' && !upsell.has('webmail')) return;
+        if (module !== 'mail' && !upsell.has(module)) return;
+
         // register collection
         var id = 'virtual/favorites/' + module,
             model = api.pool.getModel(id),
@@ -43,7 +48,8 @@ define('io.ox/core/folder/favorites', [
 
         // define virtual folder
         api.virtual.add(id, function () {
-            return api.multiple(settings.get('favorites/' + module, []), { errors: true }).then(function (response) {
+            var cache = !collection.expired && collection.fetched;
+            return api.multiple(settings.get('favorites/' + module, []), { errors: true, cache: cache }).then(function (response) {
                 // remove non-existent entries
                 var list = _(response).filter(function (item) {
                     // FLD-0008 -> not found
@@ -51,7 +57,8 @@ define('io.ox/core/folder/favorites', [
                     // ACC-0002 -> account not found (see bug 46481)
                     // FLD-1004 -> folder storage service no longer available (see bug 47089)
                     // IMAP-1002 -> mail folder "..." could not be found on mail server (see bug 47847)
-                    if (item.error && (item.code === 'FLD-0008' || item.code === 'FLD-0003' || item.code === 'ACC-0002' || item.code === 'FLD-1004' || item.code === 'IMAP-1002')) {
+                    // FILE_STORAGE-0004 -> The associated (infostore) account no longer exists
+                    if (item.error && /^(FLD-0008|FLD-0003|ACC-0002|FLD-1004|IMAP-1002|FILE_STORAGE-0004)$/.test(item.code)) {
                         invalid[item.id] = true;
                         return false;
                     }
@@ -90,6 +97,12 @@ define('io.ox/core/folder/favorites', [
                     storeCollection();
                 });
             });
+        } else if (module === 'infostore') {
+            // Add infos for the filesview
+            model.set('title', gt('Favorites'));
+            model.set('folder_id', '9');
+            model.set('own_rights', 1);
+            model.set('standard_folder', true);
         }
 
         // respond to collection remove event to sync favorites
@@ -129,6 +142,7 @@ define('io.ox/core/folder/favorites', [
     function getAffectedSubfolders(collection, id) {
         return collection.filter(function (model) {
             var modelId = model.get('id');
+            if (!modelId) return;
             return modelId.indexOf(id + api.getMailFolderSeparator(modelId)) === 0;
         });
     }
@@ -157,7 +171,7 @@ define('io.ox/core/folder/favorites', [
     }
 
     function a(action, text) {
-        return $('<a href="#" tabindex="1" role="menuitem">')
+        return $('<a href="#" role="menuitem">')
             .attr('data-action', action).text(text)
             // always prevent default
             .on('click', $.preventDefault);
