@@ -52,7 +52,8 @@ define('io.ox/core/http', ['io.ox/core/event'], function (Events) {
                 '652': 'account_name',
                 '654': 'original_id',
                 '655': 'original_folder_id',
-                '656': 'content_type'
+                '656': 'content_type',
+                '660': 'flagged'
             },
             'contacts': {
                 '500': 'display_name',
@@ -274,6 +275,7 @@ define('io.ox/core/http', ['io.ox/core/event'], function (Events) {
                 '316': 'standard_folder_type',
                 '317': 'supported_capabilities',
                 '318': 'account_id',
+                '319': 'folder_name',
                 '3010': 'com.openexchange.publish.publicationFlag',
                 '3020': 'com.openexchange.subscribe.subscriptionFlag',
                 '3030': 'com.openexchange.folderstorage.displayName',
@@ -631,7 +633,8 @@ define('io.ox/core/http', ['io.ox/core/event'], function (Events) {
             // session expired?
             var isSessionError = (/^SES\-/i).test(response.code),
                 isLogin = o.module === 'login' && o.data && /^(login|autologin|store|tokens)$/.test(o.data.action);
-            if (isSessionError && !isLogin) {
+
+            if (isSessionError && !isLogin && !o.failOnError) {
                 // login dialog
                 ox.session = '';
                 ox.trigger('relogin:required', o, deferred, response);
@@ -659,8 +662,11 @@ define('io.ox/core/http', ['io.ox/core/event'], function (Events) {
                         if (response[i]) {
                             // time
                             timestamp = response[i].timestamp !== undefined ? response[i].timestamp : _.now();
-                            // data/error
-                            if (response[i].data !== undefined) {
+                            // data/error handling
+                            if (_.isEmpty(response[i])) {
+                                // jslob case
+                                data.push({ data: response[i], timestamp: timestamp });
+                            } else if (response[i].data !== undefined) {
                                 // data
                                 var module = o.data[i].columnModule ? o.data[i].columnModule : o.data[i].module;
                                 // handling for GET requests
