@@ -20,6 +20,7 @@ define('io.ox/core/main', [
     'io.ox/core/extPatterns/stage',
     'io.ox/core/notifications',
     'io.ox/backbone/mini-views/help',
+    'io.ox/backbone/mini-views/dropdown',
     // defines jQuery plugin
     'io.ox/core/commons',
     'io.ox/core/upsell',
@@ -36,7 +37,7 @@ define('io.ox/core/main', [
     'io.ox/core/http_errors',
     'io.ox/backbone/disposable',
     'io.ox/tours/get-started'
-], function (desktop, session, http, appAPI, ext, Stage, notifications, HelpView, commons, upsell, UpsellView, capabilities, ping, folderAPI, a11y, settings, contactsSettings, gt) {
+], function (desktop, session, http, appAPI, ext, Stage, notifications, HelpView, Dropdown, commons, upsell, UpsellView, capabilities, ping, folderAPI, a11y, settings, contactsSettings, gt) {
 
     'use strict';
 
@@ -85,6 +86,15 @@ define('io.ox/core/main', [
         return done.promise();
     };
 
+    function needsReload(target) {
+        // see bug 56170 and 61385
+        if (!/#autologout=true/.test(target)) return;
+        var parser = document.createElement('a');
+        parser.href = target;
+        return (location.host === parser.host) &&
+               (location.pathname === parser.pathname);
+    }
+
     var logout = function (opt) {
 
         opt = _.extend({
@@ -94,13 +104,15 @@ define('io.ox/core/main', [
         function sessionLogout() {
             session.logout().always(function () {
                 // get logout locations
-                var location = (capabilities.has('guest') && ox.serverConfig.guestLogoutLocation) ? ox.serverConfig.guestLogoutLocation : settings.get('customLocations/logout'),
+                var targetLocation = (capabilities.has('guest') && ox.serverConfig.guestLogoutLocation) ? ox.serverConfig.guestLogoutLocation : settings.get('customLocations/logout'),
                     fallback = ox.serverConfig.logoutLocation || ox.logoutLocation,
-                    logoutLocation = location || (fallback + (opt.autologout ? '#autologout=true' : ''));
+                    logoutLocation = targetLocation || (fallback + (opt.autologout ? '#autologout=true' : ''));
                 // Substitute some variables
                 _.url.redirect(_.url.vars(logoutLocation));
-                // prevent empty white pane (see bug 56170)
-                if (/#autologout=true/.test(logoutLocation)) _.defer(window.location.reload.bind(window.location, true));
+                if (needsReload(logoutLocation)) {
+                    // location.reload will cause an IE error
+                    _.defer(function () { location.reload(true); });
+                }
             });
         }
 
@@ -592,13 +604,17 @@ define('io.ox/core/main', [
                             // the error is part of the dialog here
                             ox.handleLogoutError = true;
 
+                            // work with strings or error objects
+                            var errorText = error[0] && error[0].error ? error[0].error : error[0];
+
                             dialog.idle();
                             dialog.$el.toggleClass('logout-failed', true);
                             dialog.$el.find('[data-action="force"]').text(gt('Force sign out'));
                             dialog.$body.empty().append(
                                 $('<div class="alert alert-danger">').append(
                                     $('<div>').text(gt('Logout failed.')),
-                                    $('<div>').text(error[0])
+                                    (_.isString(errorText) ? $('<div>').text(errorText) : '')
+
                                 )
                             );
                         };
@@ -920,12 +936,13 @@ define('io.ox/core/main', [
             index: 300,
             draw: function () {
                 if (_.device('smartphone')) return;
-
+                var helpView = new HelpView({
+                    iconClass: 'launcher-icon',
+                    href: getHelp
+                });
+                if (helpView.$el.hasClass('hidden')) return;
                 this.append(
-                    addLauncher('right', new HelpView({
-                        iconClass: 'launcher-icon',
-                        href: getHelp
-                    }).render().$el)
+                    addLauncher('right', helpView.render().$el)
                 );
             }
         });
@@ -973,7 +990,6 @@ define('io.ox/core/main', [
             id: 'onboarding',
             index: 120,
             draw: function () {
-                if (_.device('smartphone')) return;
                 if (capabilities.has('!client-onboarding')) return;
 
                 this.append(
@@ -1044,14 +1060,18 @@ define('io.ox/core/main', [
             index: 200,
             draw: function () {
                 //replaced by module
-                var node = this;
+                var node = this,
+                    helpView = new HelpView({
+                        content: gt('Help'),
+                        href: getHelp
+                    });
+                node.append(
+                    $('<li class="divider" role="separator"></li>')
+                );
+                if (helpView.$el.hasClass('hidden')) return;
                 node.append(
-                    $('<li class="divider" role="separator"></li>'),
                     $('<li class="io-ox-specificHelp" role="presentation">').append(
-                        new HelpView({
-                            content: gt('Help'),
-                            href: getHelp
-                        }).render().$el.attr('role', 'menuitem')
+                        helpView.render().$el.attr('role', 'menuitem')
                     )
                 );
             }
@@ -1106,17 +1126,20 @@ define('io.ox/core/main', [
             id: 'dropdown',
             index: 1000,
             draw: function () {
-                var ul, a;
+                var ul = $('<ul id="topbar-settings-dropdown" class="dropdown-menu" role="menu">'),
+                    a = $('<a href="#" role="button" class="dropdown-toggle f6-target" data-toggle="dropdown">').attr('aria-label', gt('Settings')).append(
+                        $('<i class="fa fa-bars launcher-icon" aria-hidden="true">').attr('title', gt('Settings'))
+                    );
                 this.append(
-                    $('<li id="io-ox-topbar-dropdown-icon" class="launcher dropdown" role="presentation">').append(
-                        a = $('<a href="#" role="button" class="dropdown-toggle f6-target" data-toggle="dropdown">').attr('aria-label', gt('Settings')).append(
-                            $('<i class="fa fa-bars launcher-icon" aria-hidden="true">').attr('title', gt('Settings'))
-                        ),
-                        ul = $('<ul id="topbar-settings-dropdown" class="dropdown-menu" role="menu">')
-                    )
+                    new Dropdown({
+                        tagName: 'li',
+                        id: 'io-ox-topbar-dropdown-icon',
+                        className: 'launcher dropdown',
+                        $ul: ul,
+                        $toggle: a
+                    }).render().$el
                 );
                 ext.point('io.ox/core/topbar/right/dropdown').invoke('draw', ul);
-                a.dropdown();
             }
         });
 
@@ -1192,6 +1215,40 @@ define('io.ox/core/main', [
             });
         })();
 
+        ext.point('io.ox/core/topbar/right').extend({
+            id: 'client-onboarding-hint',
+            index: 2200,
+            draw: function () {
+                if (capabilities.has('!client-onboarding')) return;
+                if (!_.device('smartphone')) return;
+                // exit: tab reload with autologin
+                if (_.device('reload') && session.isAutoLogin()) return;
+
+                var conf = _.extend({ enabled: true, remaining: 2 }, settings.get('features/clientOnboardingHint', {}));
+                // server prop
+                if (!conf.enabled || !conf.remaining) return;
+                // banner action, topbar action, dropdown action
+                var link = this.find('#io-ox-topbar-dropdown-icon > a');
+                // popover
+                link.popover({
+                    //#. %1$s is the product name
+                    //#, c-format
+                    content: gt("Did you know that you can take %1$s with you? Just click this icon and choose 'Connect your device' from the menu.", ox.serverConfig.productName),
+                    template: '<div class="popover popover-onboarding" role="tooltip"><div class="arrow"></div><div class="popover-content popover-content-onboarding"></div></div>',
+                    placement: 'bottom'
+                });
+                // show
+                _.defer(link.popover.bind(link, 'show'));
+                // close on any click
+                document.body.addEventListener('click', close, true);
+                function close() {
+                    settings.set('features/clientOnboardingHint/remaining', Math.max(0, conf.remaining - 1)).save();
+                    link.popover('destroy');
+                    document.body.removeEventListener('click', close, true);
+                }
+            }
+        });
+
         ext.point('io.ox/core/topbar/right').extend({
             id: 'logo',
             index: 10000,
@@ -1368,6 +1425,16 @@ define('io.ox/core/main', [
                         type: 'click',
                         action: 'noop'
                     });
+
+                    $(document.documentElement).on('mousedown', '.halo-link', function () {
+                        var app = ox.ui.App.getCurrentApp() || new Backbone.Model({ name: 'unknown' });
+                        metrics.trackEvent({
+                            app: 'core',
+                            type: 'click',
+                            action: 'halo',
+                            detail: _.last(app.get('name').split('/'))
+                        });
+                    });
                 });
             }
         });
@@ -1625,20 +1692,27 @@ define('io.ox/core/main', [
                             dialog.remove();
                             dialog = null;
                         }),
+                        // get number of items (canRestore is false or number of items (due to return list && list.length)
+                        n = baton.canRestore || 0,
                         btn1, btn2;
 
                     $('#io-ox-core').append(
-                        dialog = $('<div class="io-ox-restore-dialog" tabindex="0" role="dialog">').append(
-                            $('<div class="header">').append(
-                                $('<h1>').text(gt('Restore applications')),
-                                $('<div>').text(
-                                    gt('The following applications can be restored. Just remove the restore point if you don\'t want it to be restored.')
+                        dialog = $('<div class="io-ox-restore-dialog" tabindex="-1" role="dialog" aria-labelledby="restore-heading" aria-describedby="restore-description">').append(
+                            $('<div role="document">').append(
+                                $('<div class="header">').append(
+                                    $('<h1 id="restore-heading">').text(gt('Restore applications')),
+                                    $('<div id="restore-description">').text(
+                                        //#. %1$s is placeholder for the product name like "App Suite"
+                                        gt.ngettext('The below item was open last time you exited %1$s.', 'The below items were open last time you exited %1$s.', n, ox.serverConfig.productName) + ' ' +
+                                        gt('Please click "Continue" if you\'d like to continue editing.') + ' ' +
+                                        gt.ngettext('If you do not wish to keep the item, please click on the trash icon.', 'If you do not wish to keep an item, please click on the trash icon.', n)
+                                    )
+                                ),
+                                $('<ul class="list-unstyled content">'),
+                                $('<div class="footer">').append(
+                                    btn1 = $('<button type="button" class="cancel btn btn-default">').text(gt('Cancel')),
+                                    btn2 = $('<button type="button" class="continue btn btn-primary">').text(gt('Continue'))
                                 )
-                            ),
-                            $('<ul class="list-unstyled content">'),
-                            $('<div class="footer">').append(
-                                btn1 = $('<button type="button" class="cancel btn btn-default">').text(gt('Cancel')),
-                                btn2 = $('<button type="button" class="continue btn btn-primary">').text(gt('Continue'))
                             )
                         )
                     );
@@ -1650,6 +1724,7 @@ define('io.ox/core/main', [
 
                     // draw savepoints to allow the user removing them
                     ox.ui.App.getSavePoints().done(function (list) {
+
                         _(list).each(function (item) {
                             var info = item.description || item.module,
                                 versionInfo = $();
@@ -1665,7 +1740,7 @@ define('io.ox/core/main', [
                                     $('<a href="#" role="button" class="remove">').data(item).append(
                                         $('<i class="fa fa-trash-o" aria-hidden="true">')
                                     ),
-                                    item.icon ? $('<i>').addClass(item.icon) : $(),
+                                    item.icon ? $('<i aria-hidden="true">').addClass(item.icon) : $(),
                                     $('<span>').text(gt.noI18n(info)),
                                     versionInfo
                                 )
@@ -1810,7 +1885,15 @@ define('io.ox/core/main', [
                                 });
                             }
                             // non-app deeplinks
-                            var id = _.url.hash('reg');
+                            var id = _.url.hash('reg'),
+                                // be case insensitive
+                                showFeedback = _(_.url.hash()).reduce(function (memo, value, key) {
+                                    if (key.toLowerCase() === 'showfeedbackdialog') {
+                                        return value;
+                                    }
+                                    return memo;
+                                });
+
                             if (id && ox.registry.get(id)) {
                                 // normalise args
                                 var list = (_.url.hash('regopt') || '').split(','),
@@ -1826,6 +1909,14 @@ define('io.ox/core/main', [
                                 });
                             }
 
+                            if (showFeedback === 'true' && capabilities.has('feedback')) {
+                                launch.done(function () {
+                                    require(['plugins/core/feedback/register'], function (feedback) {
+                                        feedback.show();
+                                    });
+                                });
+                            }
+
                             if (contactsSettings.get('features/furigana', false)) {
                                 require(['l10n/ja_JP/io.ox/register']);
                             }
@@ -1932,6 +2023,10 @@ define('io.ox/core/main', [
             // IMAP-specific: 'Relogin required'
             case 'MSG-1000':
             case 'MSG-1001':
+            case 'MSG-1036':
+            case 'MSG-1038':
+            case 'MSG-1039':
+            case 'MSG-1040':
             // INUSE (see bug 37218)
             // falls through
             case 'MSG-1031':
@@ -1950,7 +2045,7 @@ define('io.ox/core/main', [
         }
     });
 
-    // white list warninff codes
+    // white list warning codes
     var isValidWarning = (function () {
         var check = function (code, regex) { return regex.test(code); },
             reCodes = [
