@@ -54,7 +54,25 @@ define('io.ox/core/moment', [
         // load the file that contains the define, then load the define itself
         // we need do it this way to avoid the use of anonymous defines
         require(['static/3rd.party/moment/locale/' + langISO + '.js'], function () {
-            require(['moment/locale/' + langISO]);
+            require(['moment/locale/' + langISO]).done(function () {
+                // use custom locales for japanese
+                if (moment.locales().indexOf('ja') !== -1) {
+                    moment.updateLocale('ja', {
+                        longDateFormat: {
+                            LT: 'HH:mm',
+                            LTS: 'HH:mm:ss',
+                            L: 'YYYY/MM/DD',
+                            LL: 'YYYY年M月D日',
+                            LLL: 'YYYY年M月D日 HH:mm',
+                            LLLL: 'YYYY年M月D日 HH:mm dddd',
+                            l: 'YYYY/MM/DD',
+                            ll: 'YYYY年M月D日',
+                            lll: 'YYYY年M月D日 HH:mm',
+                            llll: 'YYYY年M月D日 HH:mm dddd'
+                        }
+                    });
+                }
+            });
         });
     }
 
