@@ -59,7 +59,7 @@ define('io.ox/core/notifications/subview', [
                         desktopNotifications.show(specific(model));
                     });
                 }
-                var node = $('<li class="item" tabindex="0" role="listitem">');
+                var node = $('<li class="item" tabindex="0">');
                 if (view.model.get('showHideSingleButton')) {
                     node.append(
                         $('<div class="notification-item-actions">').append(
@@ -400,7 +400,7 @@ define('io.ox/core/notifications/subview', [
                 return;
             }
 
-            var cid = String($(e.currentTarget).parent().data('cid')),
+            var cid = e.which === 13 ? String($(e.currentTarget).data('cid')) : String($(e.currentTarget).parent().data('cid')),
                 api = this.model.get('api'),
                 fullModel = this.model.get('fullModel'),
                 sidepopupNode = notifications.nodes.sidepopup,
