@@ -115,7 +115,7 @@ define('io.ox/core/pdf/pdfview', [
         // ---------------------------------------------------------------------
 
         function getPageViewport(pdfjsPage, pageZoom) {
-            return _.isObject(pdfjsPage) ? pdfjsPage.getViewport(PDFView.getAdjustedZoom(pageZoom)) : null;
+            return _.isObject(pdfjsPage) ? pdfjsPage.getViewport({ scale: PDFView.getAdjustedZoom(pageZoom) }) : null;
         }
 
         function intersects(aFrom, aTo, bFrom, bTo) {
@@ -659,7 +659,7 @@ define('io.ox/core/pdf/pdfview', [
                             return pdfjsPage.render({
                                 canvasContext: canvasCtx,
                                 viewport: viewport
-                            }).then(function () {
+                            }).promise.then(function () {
                                 if (pdfTextBuilder) {
                                     return pdfjsPage.getTextContent().then(function (pdfTextContent) {
                                         pdfTextBuilder.setTextContent(pdfTextContent);
