@@ -13,17 +13,19 @@
 
 /* global tinyMCE: true */
 
-define.async('io.ox/core/tk/contenteditable-editor', [
+define('io.ox/core/tk/contenteditable-editor', [
     'io.ox/core/emoji/util',
     'io.ox/core/capabilities',
     'io.ox/core/extensions',
     'io.ox/core/tk/textproc',
     'io.ox/mail/api',
+    'io.ox/mail/util',
+    'static/3rd.party/purify.min.js',
     'settings!io.ox/core',
     'settings!io.ox/mail',
     'gettext!io.ox/core',
     'less!io.ox/core/tk/contenteditable-editor'
-], function (emoji, capabilities, ext, textproc, mailAPI, settings, mailSettings, gt) {
+], function (emoji, capabilities, ext, textproc, mailAPI, mailUtil, DOMPurify, settings, mailSettings, gt) {
 
     'use strict';
 
@@ -82,27 +84,43 @@ define.async('io.ox/core/tk/contenteditable-editor', [
         draw: function (ed) {
             var sanitizeAttributes = function (e) {
                 if (!e.content) return;
-                var tmp = document.createElement('DIV');
-                tmp.innerHTML = e.content;
-                var nodes = tmp.querySelectorAll('*');
-                for (var i = 0; i < nodes.length; i++) {
-                    var node = nodes[i], ai = 0, attr;
-                    while (attr = node.attributes[ai++]) {
-                        if (/^on/i.test(attr.name)) { node.removeAttribute(attr.name); }
-                        if (attr.name === 'data-toggle') { node.removeAttribute(attr.name); }
-                    }
-                }
-                e.content = tmp.innerHTML;
-                tmp = null;
+                e.content = DOMPurify.sanitize(e.content);
             };
-            if (ed.oxContext && ed.oxContext.signature) {
-                ed.on('BeforeSetContent', sanitizeAttributes);
-            }
-
-            ed.on('BeforePastePreProcess', sanitizeAttributes);
+            // see bug 48231 and 50849
+            ed.on('PastePreProcess', sanitizeAttributes);
         }
     });
 
+    ext.point(POINT + '/setup').extend({
+        id: 'image-remove',
+        index: INDEX += 100,
+        draw: (function () {
+            function getImageIds(content) {
+                // content can be just a string when e.g. pasting
+                var images = $('<div>' + content + '</div>').find('img');
+                return _(images.toArray()).chain().map(function (img) {
+                    return $(img).attr('id');
+                }).compact().value();
+            }
+            return function (ed) {
+                // disable for signature editor (bugs 66594, 67650)
+                if (ed.oxContext && ed.oxContext.signature) return;
+
+                var oldsIds = [];
+                ed.on('BeforeSetContent change Focus Blur', function (e) {
+                    // use e.content for BeforeSetContent events
+                    var ids = getImageIds(e.content || ed.getContent()),
+                        removed = _.difference(oldsIds, ids);
+                    removed.forEach(function (id) {
+                        var editorElement = $(ed.getElement());
+                        editorElement.trigger('removeInlineImage', id);
+                    });
+                    oldsIds = ids;
+                });
+            };
+        }())
+    });
+
     function splitContent_W3C(ed) {
         // get current range
         var range = ed.selection.getRng();
@@ -178,16 +196,7 @@ define.async('io.ox/core/tk/contenteditable-editor', [
             }
         }
         // create new elements
-        var dummySpan = ed.getDoc().createElement('span');
-        dummySpan.innerHTML = '&nbsp;';
-        var para = ed.getDoc().createElement('p');
-        // and both elements to editor
-        para.appendChild(dummySpan);
-        range.insertNode(para);
-        // select the span
-        ed.selection.select(dummySpan);
-        // and delete it
-        ed.execCommand('Delete', false, null);
+        range.insertNode(mailUtil.getDefaultStyle().node.get(0));
     }
 
     function isInsideBlockquote(range) {
@@ -206,10 +215,10 @@ define.async('io.ox/core/tk/contenteditable-editor', [
         // inside blockquote?
         if (!isInsideBlockquote(range)) return;
         if (!range.startContainer) return;
-        if (_.device('IE')) return;
-        // split; W3C-compliant strategy; older IEs needed a different strategy
         splitContent_W3C(ed);
         ed.dom.events.cancel(e);
+        //focus is lost after content has been split, at least starting with tinyMCE 4.6.6 (4.6.5 didn't)
+        ed.focus();
     }
 
     function lookupTinyMCELanguage() {
@@ -231,6 +240,7 @@ define.async('io.ox/core/tk/contenteditable-editor', [
 
         var rendered = $.Deferred(), initialized = $.Deferred(), ed;
         var toolbar, editor, editorId = el.data('editorId');
+        var defaultStyle = mailUtil.getDefaultStyle();
 
         el.append(
             el = $('<div class="contenteditable-editor">').attr({
@@ -285,7 +295,7 @@ define.async('io.ox/core/tk/contenteditable-editor', [
             script_url: (window.cordova ? ox.localFileRoot : ox.base) + '/apps/3rd.party/tinymce/tinymce.min.js',
 
             extended_valid_elements: 'blockquote[type]',
-            invalid_elements: 'object,iframe,script',
+            invalid_elements: 'object,iframe,script,embed',
 
             inline: true,
 
@@ -305,11 +315,16 @@ define.async('io.ox/core/tk/contenteditable-editor', [
 
             entity_encoding: 'raw',
 
+            font_formats: mailUtil.getFontFormats(),
+            fontsize_formats: '8pt 10pt 11pt 12pt 13pt 14pt 16pt 18pt 24pt 36pt',
+
             // simpleLineBreaks = true -> false -> enter insert <br>
             // simpleLineBreaks = false -> 'p' -> enter inserts new paragraph
             // this one is stored in mail settings
             forced_root_block: mailSettings.get('simpleLineBreaks', true) ? /* false */ 'p' : 'p',
 
+            forced_root_block_attrs: { 'style': defaultStyle.string, 'class': 'default-style' },
+
             browser_spellcheck: true,
 
             plugins: opt.plugins,
@@ -351,13 +366,20 @@ define.async('io.ox/core/tk/contenteditable-editor', [
                 ext.point(POINT + '/setup').invoke('draw', this, ed);
                 ed.on('BeforeRenderUI', function () {
                     rendered.resolve();
+                    // toolbar is rendere immediatly after the BeforeRenderUI event. So defer should be invoked after the toolbar is rendered
+                    _.defer(function () {
+                        // Somehow, this span (without a tabindex) is focussable in firefox (see Bug 53258)
+                        toolbar.find('span.mce-txt').attr('tabindex', -1);
+                    });
                 });
             }
         };
 
         ext.point(POINT + '/options').invoke('config', options, opt.oxContext);
 
-        editor.tinymce(options);
+        require(['3rd.party/tinymce/jquery.tinymce.min']).then(function () {
+            editor.tinymce(options);
+        });
 
         function trimEnd(str) {
             return String(str || '').replace(/[\s\xA0]+$/g, '');
@@ -380,11 +402,8 @@ define.async('io.ox/core/tk/contenteditable-editor', [
                     editor.css('min-height', containerHeight - composeFieldsHeight - 32);
                     return;
                 } else if (_.device('smartphone')) {
-                    composeFieldsHeight = el.parent().find('.mail-compose-fields').height();
-                    var topBarHeight = $('#io-ox-topbar').height(),
-                        windowHeaderHeight = el.parents().find('.window-header').height(),
-                        editorPadding = 30;
-                    editor.css('min-height', window.innerHeight - (composeFieldsHeight + topBarHeight + windowHeaderHeight + editorPadding));
+
+                    editor.css('min-height', window.innerHeight - 232); // sum of standard toolbars etc. calculating this does not work here as most elements are not yet drawn and return falsy values
                     return;
                 }
 
@@ -496,11 +515,8 @@ define.async('io.ox/core/tk/contenteditable-editor', [
             // clean up
             str = trimEnd(str);
             if (!str) return;
-            return textproc.texttohtml(str).then(function (content) {
-                if (/^<blockquote\>/.test(content)) {
-                    content = '<p><br></p>' + content;
-                }
-                set(content);
+            require(['io.ox/mail/detail/content'], function (proc) {
+                set(proc.text2html(str));
                 ed.undoManager.clear();
             });
         };
@@ -684,18 +700,16 @@ define.async('io.ox/core/tk/contenteditable-editor', [
                     editor.css('margin-top', 0);
                 }
             });
+            scrollPane.on('scroll', _.debounce(function () { $('body').click(); }, 1000, true));
         }());
 
         this.destroy = function () {
             this.hide();
             clearKeepalive();
-            if (editor.tinymce()) {
-                //empty node before removing because tiny saves the contents before.
-                //this might cause server errors if there were inline images (those only exist temporarily and are already removed)
-                editor.empty();
-                editor.tinymce().remove();
-            }
-            el = editor = editor.tinymce = initialized = rendered = ed = null;
+            // have to unset active editor manually. may be removed for future versions of tinyMCE
+            delete tinyMCE.EditorManager.activeEditor;
+            tinyMCE.EditorManager.remove(ed);
+            ed = undefined;
         };
 
         var intervals = [];
@@ -712,9 +726,5 @@ define.async('io.ox/core/tk/contenteditable-editor', [
         editor.on('addInlineImage', function (e, id) { addKeepalive(id); });
     }
 
-    if (!window.tinyMCE) {
-        return require(['3rd.party/tinymce/jquery.tinymce.min'])
-            .then(function () { return Editor; });
-    }
-    return $.Deferred().resolve(Editor);
+    return Editor;
 });
