@@ -122,7 +122,7 @@ define('io.ox/core/tk/text-editor', [
             var el = textarea.get(0);
             function fnSetCaretPosition() {
                 // Prevent NS_ERROR_FAILURE in Firefox
-                if (document.activeElement && document.activeElement.nodeName.toLowerCase() !== 'textarea') return;
+                if (!textarea || !textarea.is(':visible')) return;
                 if (el.setSelectionRange) {
                     el.setSelectionRange(0, 0);
                 } else if (el.createTextRange) {
