@@ -12,7 +12,10 @@
  */
 'use strict';
 
-define('io.ox/core/tk/textproc', ['io.ox/core/emoji/util'], function (emoji) {
+define('io.ox/core/tk/textproc', [
+    'io.ox/core/emoji/util',
+    'settings!io.ox/mail'
+], function (emoji, mailSettings) {
 
     return {
 
@@ -194,7 +197,16 @@ define('io.ox/core/tk/textproc', ['io.ox/core/emoji/util'], function (emoji) {
                 'iframe, object, applet, input, textarea, button, select, ' +
                 'canvas, script, noscript, audio, video, img'
                 )
-                .filter(':not(img.emoji,img[src*="' + ox.abs + ox.root + '/api/file"],img[data-pending="true"])').remove();
+                .filter(':not(' +
+                    [
+                        'img.emoji',
+                        'img[src*="' + ox.abs + ox.root + '/api/file"]',
+                        'img[src*="' + ox.root + '/api/file"]',
+                        'img[src*="' + ox.abs + ox.root + '/api/image"]',
+                        'img[src*="' + ox.root + '/api/image"]',
+                        'img[data-pending="true"]'
+                    ].join(', ') + ')'
+                ).remove();
             // beautify SUP tags
             node.find('sup').css('lineHeight', '0');
             // unwrap
@@ -309,21 +321,22 @@ define('io.ox/core/tk/textproc', ['io.ox/core/emoji/util'], function (emoji) {
             function replaceLists(html) {
 
                 html = html.replace(/<(ul|ol)\b[^>]*>([\s\S]*?)<\/\1>/gi, function (str, listType, innerHTML) {
+
                     var lis = innerHTML.split('</li>');
                     lis.splice(lis.length - 1, 1);
 
                     function fixupList(str, innerHTML) {
                         innerHTML = innerHTML
-                            .replace(/^\s+/, '')
-                            .replace(/\n\n/g, '\n\n    ')
+                            .replace(/(^\s+|\n$)/g, '')
+                            .replace(/\n\n/g, '\n ')
                             // indent nested lists
-                            .replace(/\n([ ]*)+(\*|\d+\.) /g, '\n$1    $2 ');
+                            .replace(/\n([ ]*)+(\*|\d+\.) /g, '\n$1  $2 ');
                         return innerHTML;
                     }
 
                     for (var i = 0, len = lis.length; i < len; i++) {
                         if (lis[i]) {
-                            var prefix = (listType === 'ol') ? (i + 1) + '.  ' : '*   ';
+                            var prefix = (listType === 'ol') ? (i + 1) + '. ' : '* ';
                             lis[i] = prefix + lis[i].replace(/\s*<li[^>]*>([\s\S]*)/i, fixupList);
                         }
                         lis[i] = lis[i].replace(/(.) +$/m, '$1');
@@ -352,14 +365,21 @@ define('io.ox/core/tk/textproc', ['io.ox/core/emoji/util'], function (emoji) {
             }
 
             function cleanUp(string) {
-                return string
+                string = string
                     .replace(/<!--(.*?)-->/g, '')             // Remove comments
                     .replace(/<img[^>]* data-emoji-unicode=\"([^\"]*)\"[^>]*>/gi, '$1')
                     .replace(/(<\/?\w+(\s[^<>]*)?\/?>)/g, '') // Remove all remaining tags except mail addresses
-                    .replace(/^[\t\r\n]+|[\t\r\n]+$/g, '')    // Trim leading/trailing whitespace
-                    .replace(/\n\s+\n/g, '\n\n')
-                    .replace(/\n{3,}/g, '\n\n')              // limit consecutive linebreaks to 2
-                    //replace html entities last, because things like &gt; and &lt; might get removed otherwise
+                    .replace(/^[\t\r\n]+|[\t\r\n]+$/g, '');    // Trim leading/trailing whitespace
+
+                // limit consecutive linebreaks to 2
+                if (mailSettings.get('transform/emptyLines', true)) {
+                    string = string
+                        .replace(/\n\s+\n\s+\n/g, '\n\n\n')
+                        .replace(/\n{3,}/g, '\n\n\n');
+                }
+
+                //replace html entities last, because things like &gt; and &lt; might get removed otherwise
+                return string
                     .replace(/&nbsp;/g, ' ')
                     .replace(/&gt;/g, '>')
                     .replace(/&lt;/g, '<')
