@@ -122,7 +122,7 @@ define('io.ox/core/tk/wizard', [
 
         // focus trap
         $(document).on('click.wizard', '.wizard-overlay, .wizard-backdrop', function () {
-            $('.wizard-step:visible').focus();
+            $('.wizard-step:visible').find('button.btn-primary:first').focus();
         });
 
         this.container = container.clone();
@@ -259,7 +259,7 @@ define('io.ox/core/tk/wizard', [
             this.shift(0);
         },
 
-        spotlight: function (selector) {
+        spotlight: function (selector, options) {
             if (!selector) return;
             // allow dynamic selectors
             if (_.isFunction(selector)) {
@@ -267,7 +267,7 @@ define('io.ox/core/tk/wizard', [
             }
             var elem = $(selector).filter(':visible');
             if (!elem.length) return;
-            var bounds = getBounds(elem);
+            var bounds = getBounds(elem, options ? options.padding : 0);
             // apply positions (top, right, bottom, left)
             overlays[0].css({ width: bounds.left, right: 'auto' });
             overlays[1].css({ left: bounds.left, height: bounds.top, bottom: 'auto' });
@@ -308,31 +308,28 @@ define('io.ox/core/tk/wizard', [
 
             // focus trap; wizard/tour steps are generally modal (even if not visually)
             if (e.which !== 9 || !this.$el.is(':visible')) return;
-
             // get focusable items
-            var items = this.$('[tabindex][tabindex!="-1"][disabled!="disabled"]:visible').andSelf(),
+            var items = this.$('button[tabindex!="-1"][disabled!="disabled"]:visible'),
                 first = e.shiftKey && document.activeElement === items.get(0),
                 last = !e.shiftKey && document.activeElement === items.get(-1);
-
             if (first || last) {
                 e.preventDefault();
-                if (first) items.get(-1).focus(); else this.$el.focus();
+                items.get(first ? -1 : 0).focus();
             }
         },
 
         onKeyUp: function (e) {
 
             function isInput(e) {
-                return $(e.target).is(':input');
+                return $(e.target).is('input, textarea, select');
             }
-
             switch (e.which) {
                 // check if "close" button exists
-                case 27: if (this.$('.wizard-close').length) this.trigger('close'); break;
+                case 27: if (this.$el.find('.wizard-close').length) this.trigger('close'); break;
                 // check if "back" button is enabled and available
-                case 37: if (!isInput(e) && this.$('[data-action="back"]:enabled').length) this.trigger('back'); break;
+                case 37: if (!isInput(e) && this.$el.find('[data-action="back"]:enabled').length) this.trigger('back'); break;
                 // check if "next" button is enabled and available
-                case 39: if (!isInput(e) && this.$('[data-action="next"]:enabled').length) this.trigger('next'); break;
+                case 39: if (!isInput(e) && this.$el.find('[data-action="next"]:enabled').length) this.trigger('next'); break;
                 // no default
             }
         },
@@ -412,19 +409,22 @@ define('io.ox/core/tk/wizard', [
             this.$el.attr({
                 role: 'dialog',
                 // as we have a focus trap (modal dialog) we use tabindex=1 in this case
-                tabindex: 0,
+                tabindex: -1,
                 'aria-labelledby': 'dialog-title'
             })
             .append(
-                $('<div class="wizard-header">').append(
-                    $('<button class="wizard-close close pull-right" data-action="close">').append(
-                        $('<span aria-hidden="true">&times;</span>'),
-                        $('<span class="sr-only">').text(gt('Close'))
+                $('<div role="document">').append(
+                    $('<div class="wizard-header">').append(
+                        $('<h1 class="wizard-title" id="dialog-title">'),
+                        $('<button type="button" class="wizard-close close" data-action="close">')
+                            .attr('aria-label', gt('Close'))
+                            .append(
+                                $('<i class="fa fa-times" aria-hidden="true">').attr('title', gt('Close'))
+                            )
                     ),
-                    $('<h4 class="wizard-title" id="dialog-title">')
-                ),
-                $('<div class="wizard-content" id="dialog-content">'),
-                $('<div class="wizard-footer">')
+                    $('<div class="wizard-content" id="dialog-content">'),
+                    $('<div class="wizard-footer">')
+                )
             );
             return this;
         },
@@ -463,7 +463,7 @@ define('io.ox/core/tk/wizard', [
         },
 
         // internal; just add a button
-        addButton: addControl('<button class="btn">'),
+        addButton: addControl('<button type="button" class="btn">'),
 
         // internal; just add a link
         addLink: addControl('<a href="#" role="button">'),
@@ -502,10 +502,7 @@ define('io.ox/core/tk/wizard', [
         // enable/disable 'next' button
         toggleNext: function (state) {
             if (_.device('smartphone')) {
-                return this.parent.container.find('[data-action="next"]').attr({
-                    'disabled': !state,
-                    'aria-disabled': !state
-                });
+                return this.parent.container.find('[data-action="next"]').prop('disabled', !state).attr('aria-disabled', !state);
             }
             this.$('.btn[data-action="next"]').prop('disabled', !state);
             return this;
@@ -582,7 +579,7 @@ define('io.ox/core/tk/wizard', [
                 if (this.options.spotlight) {
                     // apply spotlight
                     this.parent.toggleBackdrop(false);
-                    this.parent.spotlight(this.options.spotlight.selector);
+                    this.parent.spotlight(this.options.spotlight.selector, this.options.spotlight.options);
                     // respond to window resize
                     $(window).on('resize.wizard.spotlight', _.debounce(function () {
                         this.parent.spotlight(this.options.spotlight.selector);
@@ -604,12 +601,12 @@ define('io.ox/core/tk/wizard', [
                 }
 
                 // now, show and focus popup
-                this.$el.removeClass('invisible').focus();
+                this.$el.removeClass('invisible').find('button[tabindex!="-1"][disabled!="disabled"]:visible:last').focus();
 
                 // enable focus watcher?
                 if (this.options.focusWatcher) {
                     this.focusWatcher = setInterval(function () {
-                        if (!$.contains(this.el, document.activeElement)) this.$el.focus();
+                        if (!$.contains(this.el, document.activeElement)) this.$el.find('button[tabindex!="-1"][disabled!="disabled"]:visible:last').focus();
                     }.bind(this), 100);
                 }
 
@@ -721,7 +718,7 @@ define('io.ox/core/tk/wizard', [
         align: function (selector) {
 
             // fall back to selector from referTo() or spotlight()
-            if (!selector) {
+            if (!selector && this.options) {
                 if (this.options.referTo) return this.align(this.options.referTo);
                 if (this.options.spotlight) return this.align(this.options.spotlight.selector);
                 return;
