@@ -132,12 +132,12 @@ define('io.ox/core/upsell', [
             }
 
             return function (array) {
-                if (!array) return true;
-                return _([].concat(array)).reduce(function (memo, capability) {
+                var list = _.compact([].concat(array));
+                return !list.length || _.reduce(list, function (memo, capability) {
                     // consider egde cases here
                     // for example 'active_sync clientonboarding' with cap['active_sync'] = false and cap['client-onboarding'] = true
                     // and upsell['active_sync'] = true but upsell['cient-onboarding'] = false should return true
-                    return memo || capability === undefined || isEnabledOrHas(capability);
+                    return memo || isEnabledOrHas(capability);
                 }, false);
             };
         })(),
@@ -203,10 +203,11 @@ define('io.ox/core/upsell', [
             // c.calendar = c.infostore = true;
             // c.caldav = c.carddav = c['boxcom || google || msliveconnect'] = false;
             // c.boxcom = c.google = c.msliveconnect = false;
+            // settings.set('upsell/premium/folderView/visible', true);
             settings.set('features/upsell/secondary-launcher', { icon: 'fa-star fa-star fa-star', color: '#ff0' });
             settings.set('features/upsell/portal-widget', { imageURL: 'http://lorempixel.com/400/300/' });
             settings.set('features/upsell/folderview/mail/i18n/en_US', { title: 'Custom english title for synchronizing mails.' });
-            settings.set('features/upsell/topbar-dropdown', { color: '#f00' });
+            settings.set('features/upsell/topbar-dropdown', { color: '#df0000' });
             settings.set('features/upsell/mail-folderview-quota', { upsellLimit: 10 * 1024 * 1024 });
             console.debug('Disabled inline actions regarding calendar, tasks, and files; enabled upsell instead');
             if (!debugCustomWizard) {
