@@ -11,7 +11,7 @@
  * @author Matthias Biggeleben <matthias.biggeleben@open-xchange.com>
  */
 
-define('io.ox/core/util', ['io.ox/core/extensions'], function (ext) {
+define('io.ox/core/util', ['io.ox/core/extensions', 'settings!io.ox/core'], function (ext, settings) {
 
     'use strict';
 
@@ -73,12 +73,14 @@ define('io.ox/core/util', ['io.ox/core/extensions'], function (ext) {
                 user_id: options.user_id
             };
 
+            if (data && data.nohalo) options.$el = $('<span>');
+
             var baton = new ext.Baton({ data: data || {}, halo: halo, html: options.html });
 
             // get node
             var node = options.$el || (
                 halo.email || halo.user_id ?
-                $('<a href="#" class="halo-link">').attr('title', halo.email).data(halo) :
+                $('<a href="#" role="button" class="halo-link">').attr('title', halo.email).data(halo) :
                 $('<' + options.tagName + '>')
             );
 
@@ -234,10 +236,35 @@ define('io.ox/core/util', ['io.ox/core/extensions'], function (ext) {
 
         // recognize addresses in a string
         // delimiters: comma, semi-colon, tab, newline, space; ignores delimiters in quotes
+        // display name can contain a-z plus \u00C0-\u024F, i.e. Latin supplement, Latin Extended-A, and Latin Extended-B
+        // the local part is either a quoted string or latin (see above) plus . ! # $ % & ' * + - / = ? ^ _ ` { | } ~
         // returns array of addresses
         getAddresses: function (str) {
-            return String(str).match(/((('[^']*'|"[^"]*"|\w[\w\x20]*)\s<[^>]+>)|("[^"]*"@)|[^"',;\x20\t\n]+)+/g);
-        }
+            var addresses = String(str).match(/("[^"]+"|'[^']+'|\w[\w\u00C0-\u024F.!#$%&'*+-\/=?^_`{|}~]*)@[^,;\x20\t\n]+|[\w\u00C0-\u024F][\w\u00C0-\u024F\-\x20]+\s<[^>]+>|("[^"]+"|'[^']+')\s<[^>]+>/g) || [];
+            return addresses.map(function (str) {
+                return str.replace(/^([^"]+)\s</, '"$1" <');
+            });
+        },
+
+        getShardingRoot: (function () {
+            var defaultUrl = location.host + ox.apiRoot,
+                hosts = [].concat(settings.get('shardingSubdomains', defaultUrl));
+            function sum(s) {
+                var i = s.length - 1, sum = 0;
+                for (; i; i--) sum += s.charCodeAt(i);
+                return sum;
+            }
+            return function (url) {
+                var index = 0;
+                // special case, if url already has the root and the protocol attached
+                if (url.indexOf('//' + defaultUrl) === 0) url = url.substr(defaultUrl.length + 2);
+                if (hosts.length > 1) index = sum(url) % hosts.length;
+                if (!/^\//.test(url)) url = '/' + url;
+                // do not use sharding when on development system
+                if (ox.debug) return '//' + defaultUrl + url;
+                return '//' + hosts[index] + url;
+            };
+        }())
     };
 
     return that;
