@@ -41,6 +41,22 @@ define('io.ox/core/viewer/views/sidebar/fileinfoview', [
         });
     }
 
+    function renderFileName(model, options) {
+        var name = model.getDisplayName() || '-';
+        var disableLink = options.disableLink || false;
+
+        //fix for 53324
+        if (model.get('source') !== 'drive') return $.txt(name);
+
+        // fix for 56070
+        if (disableLink) return $.txt(name);
+
+        var link =  util.getDeepLink('io.ox/files', model.isFile() ? model.pick('folder_id', 'id') : model.pick('id'));
+        return $('<a href="#" target="_blank" style="word-break: break-all">')
+            .attr('href', link)
+            .text(name);
+    }
+
     Ext.point('io.ox/core/viewer/sidebar/fileinfo').extend({
         index: 100,
         id: 'fileinfo',
@@ -49,7 +65,7 @@ define('io.ox/core/viewer/views/sidebar/fileinfoview', [
             if (!baton.model) return;
 
             var model = baton.model,
-                name = model.getDisplayName() || '-',
+                options = baton.options || {},
                 size = model.get('file_size'),
                 sizeString = (_.isNumber(size)) ? _.filesize(size) : '-',
                 modifiedBy = model.get('modified_by'),
@@ -57,14 +73,15 @@ define('io.ox/core/viewer/views/sidebar/fileinfoview', [
                 isToday = moment().isSame(moment(modified), 'day'),
                 dateString = modified ? moment(modified).format(isToday ? 'LT' : 'l LT') : '-',
                 folder_id = model.get('folder_id'),
-                link =  util.getDeepLink('io.ox/files', model.isFile() ? model.pick('folder_id', 'id') : model.pick('id')),
                 dl = $('<dl>'),
                 isAttachmentView = !_.isEmpty(model.get('com.openexchange.file.storage.mail.mailMetadata'));
 
             dl.append(
                 // filename
                 $('<dt>').text(gt('Name')),
-                $('<dd class="file-name">').text(name),
+                $('<dd class="file-name">').append(
+                    renderFileName(model, options)
+                ),
                 // size
                 $('<dt>').text(gt('Size')),
                 $('<dd class="size">').text(sizeString)
@@ -74,12 +91,13 @@ define('io.ox/core/viewer/views/sidebar/fileinfoview', [
                      // modified
                     $('<dt>').text(gt('Modified')),
                     $('<dd class="modified">').append(
-                        $.txt(dateString), $('<br>'), UserAPI.getTextNode(modifiedBy)
+                        $('<span class="modifiedAt">').text(dateString),
+                        $('<span class="modifiedBy">').append(UserAPI.getTextNode(modifiedBy))
                     )
                 );
 
                 // folder info block
-                if (!baton.options.disableFolderInfo) {
+                if (!options.disableFolderInfo) {
                     dl.append(
                         // path; using "Folder" instead of "Save in" because that one
                         // might get quite long, e.g. "Gespeichert unter"
@@ -93,28 +111,11 @@ define('io.ox/core/viewer/views/sidebar/fileinfoview', [
                     );
                 }
 
-                if (!capabilities.has('alone') && !capabilities.has('guest')) {
-                    folderAPI.get(folder_id).done(function (folderData) {
-                        // only show links to infostore files, links to mail attachments would mean broken links, see bug 39752
-                        if (folderAPI.is('infostore', folderData)) {
-                            dl.append(
-                                // deep link
-                                $('<dt>').text(gt('Link')),
-                                $('<dd class="link">').append(
-                                    $('<a href="#" target="_blank" style="word-break: break-all">')
-                                    .attr('href', link)
-                                    .text(link)
-                                )
-                            );
-                        }
-                    });
-                }
-
                 var permissions = model.isFile() ?
                     model.get('object_permissions') || [] :
                     _(model.get('permissions')).filter(function (item) { return item.entity !== ox.user_id; });
 
-                if (capabilities.has('invite_guests')) {
+                if (capabilities.has('invite_guests') && !options.disableSharesInfo) {
                     dl.append(
                         //#. "Shares" in terms of "shared with others" ("Freigaben")
                         $('<dt>').text(gt('Shares')),
@@ -218,7 +219,7 @@ define('io.ox/core/viewer/views/sidebar/fileinfoview', [
             //#. File and folder details
             this.setPanelHeader(gt('Details'));
             // attach event handlers
-            this.listenTo(this.model, 'change:cid change:filename change:file_size change:last_modified change:folder_id', this.render);
+            this.listenTo(this.model, 'change:cid change:filename change:file_size change:last_modified change:folder_id change:object_permissions change:permissions', this.render);
             this.on('dispose', this.disposeView.bind(this));
         },
 
