@@ -32,7 +32,7 @@ define('io.ox/core/viewer/views/types/baseview', [
 
         // create slide root node
         // <div class="swiper-slide" tabindex="-1" role="option" aria-selected="false">
-        className: 'swiper-slide scrollable',
+        className: 'swiper-slide scrollable focusable',
         attributes: { tabindex: -1, role: 'option', 'aria-selected': 'false' },
 
         /**
@@ -49,7 +49,7 @@ define('io.ox/core/viewer/views/types/baseview', [
             iconClass = iconClass || Util.getIconClass(this.model);
 
             return $('<div class="viewer-displayer-notification">').append(
-                $('<i class="fa">').addClass(iconClass),
+                $('<i class="fa" aria-hidden="true">').addClass(iconClass),
                 $('<p class="apology">').text(notification || '')
             );
         },
@@ -84,7 +84,7 @@ define('io.ox/core/viewer/views/types/baseview', [
                 return FilesAPI.getUrl(modelJSON, 'thumbnail', options);
 
             } else if (this.model.isMailAttachment()) {
-                return MailAPI.getUrl(this.model.get('origData'), 'view');
+                return MailAPI.getUrl(this.model.get('origData'), 'view', options);
 
             } else if (this.model.isPIMAttachment()) {
                 return AttachmentAPI.getUrl(this.model.get('origData'), 'view', options);
