@@ -476,7 +476,10 @@ define('io.ox/core/viewer/views/types/documentview', [
                     _.extend(params, { version: options.version });
                 }
 
-                $.ajax({ url: DocConverterUtils.getEncodedConverterUrl(this.model, params) });
+                $.ajax({
+                    url: DocConverterUtils.getEncodedConverterUrl(this.model, params),
+                    dataType: 'text'
+                });
                 this.isPrefetched = true;
             }
 
@@ -610,6 +613,7 @@ define('io.ox/core/viewer/views/types/documentview', [
                 var lastScrollPosition = this.getInitialScrollPosition(this.model.get('id')) || 0;
                 // the PDF link service. connects the Viewer with named actions and annotation links of the PDF
                 var pdfLinkService = new PDFViewerLinkService({
+                    externalLinkTarget: 2, // Open external links in a new window
                     pdfDocument: this.pdfDocument.getPDFJSDocument(),
                     eventHub: this.viewerEvents
                 });
