@@ -12,25 +12,27 @@
  */
 /* global blankshield */
 define('io.ox/files/actions', [
-
     'io.ox/core/folder/api',
     'io.ox/files/api',
     'io.ox/files/util',
     'io.ox/core/api/filestorage',
-
     'io.ox/core/extensions',
     'io.ox/core/extPatterns/links',
     'io.ox/core/capabilities',
-
     'settings!io.ox/files',
     'gettext!io.ox/files'
-
 ], function (folderAPI, api, util, filestorageApi, ext, links, capabilities, settings, gt) {
 
     'use strict';
 
     var Action = links.Action,
-        COMMENTS = settings.get('features/comments', true);
+        COMMENTS = settings.get('features/comments', true),
+        // used by text editor
+        allowedFileExtensions = ['csv', 'txt', 'js', 'css', 'md', 'tmpl', 'html'];
+
+    if (capabilities.has('guard-drive')) {
+        allowedFileExtensions.push('pgp');
+    }
 
     // actions
     new Action('io.ox/files/actions/upload', {
@@ -79,12 +81,19 @@ define('io.ox/files/actions', [
         new Action('io.ox/files/actions/editor', {
             requires: function (e) {
                 return api.versions.getCurrentState(e.baton.data).then(function (currentVersion) {
+                    var model = _.first(e.baton.models);
+                    var isEncrypted = model && model.isEncrypted();
+                    var encryptionPart = isEncrypted ? '\\.pgp' : '';
+                    // the pgp extension is added separately to the regex, remove it from the file extension list
+                    var fileExtensions = _.without(allowedFileExtensions, 'pgp');
+                    // build regex from list, pgp is added if guard is available
+                    var regex = new RegExp('\\.(' + fileExtensions.join('|') + '?)' + encryptionPart + '$', 'i');
+
                     return util.conditionChain(
                         currentVersion,
                         e.collection.has('one', 'modify'),
                         !util.hasStatus('lockedByOthers', e),
-                        (/\.(csv|txt|js|css|md|tmpl|html?)(\.pgp)?$/i).test(e.context.filename),
-                        (!(/\.pgp$/i).test(e.context.filename) || capabilities.has('guard-drive')),  // if has .pgp, must have Guard capability
+                        regex.test(e.context.filename),
                         (e.baton.openedBy !== 'io.ox/mail/compose'),
                         util.isFolderType('!trash', e.baton)
                     );
@@ -99,7 +108,7 @@ define('io.ox/files/actions', [
                         }
                         return;
                     }
-                    ox.launch('io.ox/editor/main', { folder: baton.data.folder_id, id: baton.data.id, params: _.extend({}, params) }).done(function () {
+                    ox.launch('io.ox/editor/main', { folder: baton.data.folder_id, id: baton.data.id, params: _.extend({ allowedFileExtensions: allowedFileExtensions }, params) }).done(function () {
                         // if this was opened from the viewer, close it now
                         if (baton.context && baton.context.viewerEvents) {
                             baton.context.viewerEvents.trigger('viewer:close');
@@ -109,7 +118,7 @@ define('io.ox/files/actions', [
 
                 // Check if Guard file.  If so, do auth then call with parameters
                 // do not use endsWith because of IE11
-                if (((baton.data.meta && baton.data.meta.Encrypted) || baton.data.filename.lastIndexOf('.pgp') === baton.data.filename.length - 4) && capabilities.has('guard-drive')) {
+                if (((baton.data.meta && baton.data.meta.Encrypted) || baton.data.filename.toLowerCase().lastIndexOf('.pgp') === baton.data.filename.length - 4) && capabilities.has('guard-drive')) {
                     require(['io.ox/guard/auth/authorizer'], function (guardAuth) {
                         guardAuth.authorize().then(function (auth) {
                             var params = {
@@ -144,7 +153,7 @@ define('io.ox/files/actions', [
             },
             action: function (baton) {
                 ox.launch('io.ox/editor/main').done(function () {
-                    this.create({ folder: baton.app.folder.get() });
+                    this.create({ folder: baton.app.folder.get(), params: { allowedFileExtensions: allowedFileExtensions } });
                 });
             }
         });
@@ -155,18 +164,25 @@ define('io.ox/files/actions', [
             // no file-system, no download
             if (_.device('ios')) return false;
 
+            function isValid(file) {
+                // locally added but not yet uploaded,   'description only' items
+                return ((file.group !== 'localFile') && (!_.isEmpty(file.filename) || file.file_size > 0));
+            }
+
             if (e.collection.has('multiple')) {
                 var result = true;
                 _.each(e.baton.data, function (obj) {
-                    if (!obj.filename || !obj.file_size) {
+                    if (!isValid(obj)) {
                         result = false;
                     }
                 });
                 return result;
+            } else if (_(e.baton.data).has('internal_userid')) {
+                // check if this is a contact not a file, happens when contact is send as vcard
+                return false;
             }
 
-            // 'description only' items
-            return !_.isEmpty(e.baton.data.filename) || e.baton.data.file_size > 0;
+            return isValid(e.baton.data);
         },
         multiple: function (list) {
             ox.load(['io.ox/files/actions/download']).done(function (action) {
@@ -180,7 +196,9 @@ define('io.ox/files/actions', [
             // no file-system, no download
             if (_.device('ios')) return false;
             // single folders only
-            return e.collection.has('one', 'folders');
+            if (!e.collection.has('one', 'folders')) return false;
+            //disable for external storages
+            return !filestorageApi.isExternal(e.baton.data);
         },
         action: function (baton) {
             require(['io.ox/files/api'], function (api) {
@@ -231,10 +249,16 @@ define('io.ox/files/actions', [
         requires: function (e) {
             if (e.collection.has('multiple')) return false;
             if (e.collection.has('folders')) return false;
-            // no 'open' menu entry for office documents, PDF and plain text
-            if (api.Model.prototype.isOffice.call(this, e.baton.data.file_mimetype)) return false;
-            if (api.Model.prototype.isPDF.call(this, e.baton.data.file_mimetype)) return false;
-            if (api.Model.prototype.isText.call(this, e.baton.data.file_mimetype)) return false;
+            // check if this is a contact not a file, happens when contact is send as vcard
+            if (_(e.baton.data).has('internal_userid')) return false;
+            // locally added but not yet uploaded
+            if (e.baton.data.group === 'localFile') { return false; }
+            if (e.baton.data.file_mimetype) {
+                // no 'open' menu entry for office documents, PDF and plain text
+                if (api.Model.prototype.isOffice.call(this, e.baton.data.file_mimetype)) return false;
+                if (api.Model.prototype.isPDF.call(this, e.baton.data.file_mimetype)) return false;
+                if (api.Model.prototype.isText.call(this, e.baton.data.file_mimetype)) return false;
+            }
             // 'description only' items
             return !_.isEmpty(e.baton.data.filename) || e.baton.data.file_size > 0;
         },
@@ -245,25 +269,6 @@ define('io.ox/files/actions', [
         }
     });
 
-    new Action('io.ox/files/actions/sendlink', {
-        capabilities: 'webmail !alone',
-        requires: function (e) {
-            return util.conditionChain(
-                _.device('!smartphone'),
-                !_.isEmpty(e.baton.data),
-                e.collection.has('some', 'items'),
-                e.baton.openedBy !== 'io.ox/mail/compose',
-                util.isFolderType('!attachmentView', e.baton),
-                util.isFolderType('!trash', e.baton)
-            );
-        },
-        multiple: function (list) {
-            ox.load(['io.ox/files/actions/sendlink']).done(function (action) {
-                action(list);
-            });
-        }
-    });
-
     new Action('io.ox/files/actions/send', {
         capabilities: 'webmail',
         requires: function (e) {
@@ -290,24 +295,6 @@ define('io.ox/files/actions', [
         }
     });
 
-    new Action('io.ox/files/actions/showlink', {
-        requires: function (e) {
-            return util.conditionChain(
-                capabilities.has('!alone !guest'),
-                _.device('!smartphone'),
-                !_.isEmpty(e.baton.data),
-                e.collection.has('some', 'items'),
-                util.isFolderType('!attachmentView', e.baton),
-                util.isFolderType('!trash', e.baton)
-            );
-        },
-        multiple: function (list) {
-            ox.load(['io.ox/files/actions/showlink']).done(function (action) {
-                action(list);
-            });
-        }
-    });
-
     new Action('io.ox/files/actions/delete', {
         requires: function (e) {
             // hide in mail compose preview
@@ -347,36 +334,6 @@ define('io.ox/files/actions', [
         }
     });
 
-    new Action('io.ox/files/actions/launchpresenter', {
-        capabilities: 'presenter document_preview',
-        requires: function (e) {
-            if (!e.collection.has('one')) {
-                return false;
-            }
-            var model = e.baton.models[0];
-            var type = model.isEncrypted() ? model.getGuardMimeType() : model.getMimeType();
-            return ((model.isPresentation(type) || model.isPDF(type)) && model.isFile(type));
-        },
-        action: function (baton) {
-            var fileModel = baton.models[0];
-            if (fileModel.isEncrypted()) {
-                require(['io.ox/guard/auth/authorizer'], function (authorizer) {
-                    authorizer.authorize().then(function (auth) {
-                        var params = {
-                            cryptoAction: 'Decrypt',
-                            cryptoAuth: auth,
-                        };
-                        fileModel.set('file_options', { params: params });
-                        ox.launch('io.ox/presenter/main', fileModel);
-                    });
-                });
-            } else {
-                ox.launch('io.ox/presenter/main', fileModel);
-            }
-
-        }
-    });
-
     //drive action for double-click or enter in files
     new Action('io.ox/files/actions/default', {
         action: function (baton) {
@@ -435,6 +392,8 @@ define('io.ox/files/actions', [
         requires: function (e) {
             return util.conditionChain(
                 e.collection.has('one', 'items'),
+                // check if this is a contact not a file, happens when contact is send as vcard
+                !_(e.baton.data).has('internal_userid'),
                 !_.isEmpty(e.baton.data),
                 util.isFolderType('!trash', e.baton)
             );
@@ -451,6 +410,14 @@ define('io.ox/files/actions', [
         if (!_.isObject(data)) return false;
         var array = data.object_permissions || data['com.openexchange.share.extendedObjectPermissions'],
             myself = _(array).findWhere({ entity: ox.user_id });
+
+        // check if there is a permission for a group, the user is a member of
+        // use max permissions available
+        if ((!myself || (myself && myself.bits < 2)) && _(array).findWhere({ group: true })) {
+            // use rampup data so this is not deferred
+            myself = _(array).findWhere({ entity: _(_.pluck(array, 'entity')).intersection(ox.rampup.user.groups)[0] });
+        }
+
         return !!(myself && (myself.bits >= 2));
     }
 
@@ -569,47 +536,67 @@ define('io.ox/files/actions', [
                         success: success,
                         successCallback: function (response, apiInput) {
                             if (!_.isString(response)) {
-                                var filesLeft = [],
-                                    conflicts = { warnings: [] };
+                                var conflicts = { warnings: [] },
+                                    itemsLeft = [];
 
                                 if (!_.isArray(response)) {
                                     response = [response];
                                 }
                                 // find possible conflicts with filestorages and offer a dialog with ignore warnings option see(Bug 39039)
-                                _(response).each(function (error) {
-                                    if (error.error) {
-                                        if (error.error.categories === 'CONFLICT' && (error.error.code.indexOf('FILE_STORAGE') === 0 || error.error.code === 'FLD-1038')) {
+                                _.each(response, function (error) {
+                                    // check the error structure to prevent a nested error object
+                                    var errorResponse = _.isString(error.error) ? error : error.error;
+
+                                    if (errorResponse) {
+
+                                        var errorCausedByFolder = errorResponse.code === 'FLD-1038';
+                                        var errorCausedByFile = errorResponse.code.indexOf('FILE_STORAGE') === 0;
+                                        var warningsInErrorResponse = _.isArray(errorResponse.warnings) ? errorResponse.warnings : [errorResponse.warnings];
+
+                                        if (errorResponse.categories === 'CONFLICT' && (errorCausedByFile || errorCausedByFolder)) {
+
+                                            // -> populate error title for the dialog
                                             if (!conflicts.title) {
-                                                conflicts.title = error.error.error;
+                                                conflicts.title = errorResponse.error;
                                             }
 
-                                            if (_.isArray(error.error.warnings)) {
-                                                _(error.error.warnings).each(function (warning) {
-                                                    conflicts.warnings.push(warning.error);
-                                                    if (type === 'move' && !_(filesLeft).findWhere({ id: warning.error_params[3] })) {
-                                                        filesLeft.push(_(list).findWhere({ id: warning.error_params[3] }));
+                                            // -> populate 'itemsLeft' for folder that will be moved after pressed on ignore conflict
+                                            if (errorCausedByFolder && type === 'move' && !_(itemsLeft).findWhere({ id: errorResponse.error_params[1] })) {
+                                                itemsLeft.push(_(list).findWhere({ id: errorResponse.error_params[1] }));
+                                            }
+
+                                            // -> populate 'itemsLeft' list for files that will be moved after pressed on ignore conflict
+                                            // note: when a folder is moved and the conflict happens for files in this folder, don't move these files but only the folder
+                                            if (!errorCausedByFolder && type === 'move' && warningsInErrorResponse) {
+                                                _.each(warningsInErrorResponse, function (warning) {
+                                                    if (!_(itemsLeft).findWhere({ id: warning.error_params[3] })) {
+                                                        itemsLeft.push(_(list).findWhere({ id: warning.error_params[3] }));
                                                     }
                                                 });
-                                            } else {
-                                                conflicts.warnings.push(error.error.warnings.error);
-                                                if (type === 'move' && !_(filesLeft).findWhere({ id: error.error.warnings.error_params[3] })) {
-                                                    filesLeft.push(_(list).findWhere({ id: error.error.warnings.error_params[3] }));
-                                                }
                                             }
+
+                                            // -> populate shown warnings for the dialog
+                                            if (warningsInErrorResponse) {
+                                                _.each(warningsInErrorResponse, function (warning) {
+                                                    conflicts.warnings.push(warning.error);
+                                                });
+                                            }
+
                                             // unfortunately move and copy responses do nt have the same structure
                                             if (type === 'copy') {
-                                                filesLeft.push(_(list).findWhere({ id: error.error.error_params[1] }));
+                                                itemsLeft.push(_(list).findWhere({ id: errorResponse.error_params[1] }));
                                             }
                                         }
                                     }
                                 });
 
-                                if (conflicts.title && filesLeft.length) {
+                                if (conflicts.title && itemsLeft.length) {
                                     require(['io.ox/core/tk/filestorageUtil'], function (filestorageUtil) {
                                         filestorageUtil.displayConflicts(conflicts, {
                                             callbackIgnoreConflicts: function () {
                                                 // if folderpicker is used baton.target is undefined (that's why the folderpicker is needed), use the previous apiInput to get the correct folder
-                                                api[type](filesLeft, baton.target || apiInput.target, true);
+                                                api[type](itemsLeft, baton.target || apiInput.target, true);
+
                                             },
                                             callbackCancel: function () {
                                                 // note: drag&drop and actions via menu use a different baton, see b53498
@@ -652,6 +639,8 @@ define('io.ox/files/actions', [
         var id, model;
         // not possible for multi-selection
         if (e.collection.has('multiple')) return false;
+        // check if this is a contact not a file, happens when contact is send as vcard
+        if (e.baton.data && _(e.baton.data).has('internal_userid')) return false;
         // get folder id
         if (e.collection.has('one')) {
             // use selected file or folders
@@ -665,6 +654,7 @@ define('io.ox/files/actions', [
         // general capability and folder check
         model = folderAPI.pool.getModel(id);
         if (!model.isShareable()) return false;
+        if (model.is('trash')) return false;
         return type === 'invite' ? model.supportsInviteGuests() : true;
     }
 
@@ -799,9 +789,10 @@ define('io.ox/files/actions', [
     });
 
     new Action('io.ox/files/premium/actions/synchronize', {
-        capabilities: 'client-onboarding (boxcom || google || msliveconnect)',
+        capabilities: 'boxcom || google || msliveconnect',
         requires: function () {
-            return _.device('!smartphone');
+            // use client onboarding here, since it is a setting and not a capability
+            return capabilities.has('client-onboarding');
         },
         action: function () {
             require(['io.ox/onboarding/clients/wizard'], function (wizard) {
@@ -848,7 +839,7 @@ define('io.ox/files/actions', [
     new links.ActionLink('io.ox/files/links/toolbar/share', {
         index: 200,
         id: 'getalink',
-        label: gt('Get link'),
+        label: gt('Create sharing link'),
         //#. sharing: a link will be created
         description: gt('Everybody gets the same link. The link just allows to view the file or folder.'),
         ref: 'io.ox/files/actions/getalink'
@@ -888,11 +879,14 @@ define('io.ox/files/actions', [
     // add another link for the viewer
     ext.point('io.ox/core/viewer/toolbar/links/drive').extend(new links.Link({
         id: 'editor',
-        index: 100,
+        index: 110,
         prio: 'hi',
         mobile: 'lo',
         label: gt('Edit'),
-        ref: 'io.ox/files/actions/editor'
+        ref: 'io.ox/files/actions/editor',
+        customize: function () {
+            this.attr('role', 'button');
+        }
     }));
 
     ext.point('io.ox/files/links/inline').extend(new links.Link({
@@ -933,26 +927,6 @@ define('io.ox/files/actions', [
         section: 'share'
     }));
 
-    ext.point('io.ox/files/links/inline').extend(new links.Link({
-        id: 'sendlink',
-        index: index += 100,
-        prio: 'lo',
-        mobile: 'lo',
-        label: gt('Send as internal link'),
-        ref: 'io.ox/files/actions/sendlink',
-        section: 'share'
-    }));
-
-    ext.point('io.ox/files/links/inline').extend(new links.Link({
-        id: 'showlink',
-        index: index += 100,
-        prio: 'lo',
-        mobile: 'lo',
-        label: gt('Show internal link'),
-        ref: 'io.ox/files/actions/showlink',
-        section: 'share'
-    }));
-
     ext.point('io.ox/files/links/inline').extend(new links.Link({
         id: 'add-to-portal',
         index: index += 100,
@@ -978,7 +952,7 @@ define('io.ox/files/actions', [
         index: index += 100,
         prio: 'lo',
         mobile: 'lo',
-        label: gt('Get link'),
+        label: gt('Create sharing link'),
         ref: 'io.ox/files/actions/getalink',
         section: 'share'
     }));
