@@ -131,6 +131,9 @@ define('io.ox/files/listview', [
             index: 200,
             draw: function (baton) {
                 var column = $('<div class="list-item-column column-2">');
+
+                this.parent().tooltip('destroy');
+
                 extensions.filename.call(column, baton);
                 this.append(column);
             }
@@ -162,7 +165,7 @@ define('io.ox/files/listview', [
             index: 300,
             draw: function (baton) {
                 if (_.device('smartphone')) return;
-                if (isAttachmentView(baton)) return;
+                if (isAttachmentView(baton) && baton.app.props.get('sort') !== 5) return;
                 var column = $('<div class="list-item-column column-3 gray">');
                 extensions.smartdate.call(column, baton);
                 this.append(column);
@@ -173,7 +176,7 @@ define('io.ox/files/listview', [
             index: 500,
             draw: function (baton) {
                 if (_.device('smartphone')) return;
-                if (isAttachmentView(baton)) return;
+                if (isAttachmentView(baton) && baton.app.props.get('sort') !== 704) return;
                 var column = $('<div class="list-item-column column-4 gray">');
                 extensions.size.call(column, baton);
                 this.append(column);
@@ -192,19 +195,37 @@ define('io.ox/files/listview', [
         {
             id: 'thumbnail',
             index: 100,
-            draw: extensions.thumbnail
+            draw: function () {
+                extensions.thumbnail.apply(this, arguments);
+
+              //this.prepend($('<div class="thumbnail-effects-box"></div>')); // please do not remove.
+                this.prepend($('<div class="thumbnail-masking-box"></div>'));
+            }
         },
         {
             id: 'locked',
             index: 200,
             draw: extensions.locked
         },
+
         {
-            id: 'filename',
+            id: 'file-icon',
             index: 300,
+            draw: function (baton) {
+                var icon = $('<div class="filename-file-icon">');
+                extensions.fileTypeIcon.call(icon, baton);
+                this.append(icon);
+            }
+        },
+        {
+            id: 'filename',
+            index: 400,
             draw: function (baton) {
                 // use inner ellipsis for too long filenames
-                extensions.filename.call(this, baton, { max: 36, charpos: 'mid' });
+                extensions.filename.call(this, baton, { max: 36, charpos: 'middle', suppressExtension: true, optimizeWordbreak: true });
+
+                // additionally render a long version filename tooltip on hover
+                extensions.filenameTooltip.call(this, baton);
             }
         }
     );
@@ -220,12 +241,25 @@ define('io.ox/files/listview', [
         {
             id: 'thumbnail',
             index: 100,
-            draw: extensions.thumbnail
+            draw: function () {
+                extensions.thumbnail.apply(this, arguments);
+
+              //this.prepend($('<div class="thumbnail-effects-box"></div>')); // please do not remove.
+                this.prepend($('<div class="thumbnail-masking-box"></div>'));
+            }
         },
         {
             id: 'locked',
             index: 200,
             draw: extensions.locked
+        },
+        {
+            id: 'filename',
+            index: 400,
+            draw: function (baton) {
+                // render a long version filename tooltip on hover
+                extensions.filenameTooltip.call(this, baton);
+            }
         }
     );
 
