@@ -93,7 +93,7 @@ define('io.ox/files/share/view-options', [
         index: 200,
         draw: function (baton) {
             this.append(
-                $('<a href="#" role="button" class="toolbar-item">')
+                $('<a href="#" role="button" class="toolbar-item" data-action="open-folder-view">')
                 .attr('title', gt('Open folder view'))
                 .append($('<i class="fa fa-angle-double-right">'))
                 .on('click', { app: baton.app, state: true }, toggleFolderView)
