@@ -39,7 +39,7 @@ define('io.ox/mail/accounts/model', [
             primary_address: [
                 {
                     required: true,
-                    msg: gt('This field has to be filled')
+                    msg: gt('This field is mandatory')
                 }, {
                     fn: _.noI18n('isMailAddress')
                 }
@@ -47,27 +47,27 @@ define('io.ox/mail/accounts/model', [
             login: function (value) {
                 //for setups without any explicit login name for primary account
                 if (this.attributes.id !== 0 && $.trim(value) === '') {
-                    return gt('This field has to be filled');
+                    return gt('This field is mandatory');
                 }
             },
             password: function (value) {
                 //if we have an id we are in edit mode, not create new account mode. Here we don't get the password from the server, so this field may be empty.
                 if (this.attributes.id === undefined && (!value || value === '')) {
-                    return gt('This field has to be filled');
+                    return gt('This field is mandatory');
                 }
             },
             mail_server: {
                 required: function () {
                     return !this.isHidden();
                 },
-                msg: gt('This field has to be filled')
+                msg: gt('This field is mandatory')
             },
             mail_port: [
                 {
                     required: function () {
                         return !this.isHidden();
                     },
-                    msg: gt('This field has to be filled')
+                    msg: gt('This field is mandatory')
                 },
                 {
                     fn: function (val) {
@@ -84,14 +84,14 @@ define('io.ox/mail/accounts/model', [
                 required: function () {
                     return !this.isHidden();
                 },
-                msg: gt('This field has to be filled')
+                msg: gt('This field is mandatory')
             },
             transport_port: [
                 {
                     required: function () {
                         return !this.isHidden();
                     },
-                    msg: gt('This field has to be filled')
+                    msg: gt('This field is mandatory')
                 },
                 {
                     fn: function (val) {
@@ -145,7 +145,8 @@ define('io.ox/mail/accounts/model', [
 
         save: function (obj) {
 
-            var id = this.get('id');
+            var id = this.get('id'),
+                model = this;
 
             if (id !== undefined) {
 
@@ -155,35 +156,50 @@ define('io.ox/mail/accounts/model', [
                     var changes = { id: id },
                         // primary mail account only allows editing of display name, unified mail and default folders
                         keys = id === 0 ?
-                            ['personal', 'unified_inbox_enabled', 'sent_fullname', 'trash_fullname', 'drafts_fullname', 'spam_fullname', 'archive_fullname'] :
-                            this.keys();
+                            ['personal', 'name', 'unified_inbox_enabled', 'sent_fullname', 'trash_fullname', 'drafts_fullname', 'spam_fullname', 'archive_fullname'] :
+                            model.keys();
 
                     // compare all attributes
-                    _(this.pick(keys)).each(function (value, key) {
+                    _(model.pick(keys)).each(function (value, key) {
                         if (!_.isEqual(value, account[key])) changes[key] = value;
                     });
 
                     // don't send transport_login/password if transport_auth is mail
-                    if (this.get('transport_auth') === 'mail') {
+                    if (model.get('transport_auth') === 'mail') {
                         delete changes.transport_login;
                         delete changes.transport_password;
                     }
 
                     return AccountAPI.update(changes).done(function () {
                         folderAPI.pool.unfetch('default' + id);
-                        folderAPI.refresh();
+                        var def;
+                        if (id === 0) {
+                            // reload settings before folder refresh when the primary account is changed to get correct default folders (virtual standard relies on these settings)
+                            def = require(['settings!io.ox/mail']).then(function (settings) {
+                                // reload settings to fetch unifiedInboxIdentifier
+                                return settings.reload();
+                            });
+                        } else {
+                            def = $.when();
+                        }
+
+                        def.then(function () {
+                            folderAPI.refresh();
+                        });
                     });
 
-                }.bind(this));
+                }).then(function () {
+                    model.trigger('sync', model);
+                });
             }
 
             if (obj) {
                 obj = _.extend({ unified_inbox_enabled: false }, obj);
-                obj.name = obj.personal = obj.primary_address;
-                this.attributes = obj;
-                this.attributes.spam_handler = 'NoSpamHandler';
+                obj.name = obj.primary_address;
+                model.attributes = obj;
+                model.attributes.spam_handler = 'NoSpamHandler';
             }
-            return AccountAPI.create(this.attributes);
+            return AccountAPI.create(model.attributes);
         },
 
         destroy: function () {
