@@ -16,40 +16,48 @@ define('io.ox/mail/accounts/settings', [
     'io.ox/core/api/account',
     'io.ox/mail/accounts/model',
     'io.ox/mail/accounts/view-form',
-    'io.ox/core/tk/dialogs',
+    'io.ox/backbone/views/modal',
     'io.ox/core/notifications',
     'io.ox/core/a11y',
     'settings!io.ox/mail',
     'gettext!io.ox/mail/accounts/settings',
     'less!io.ox/settings/style'
-], function (ext, api, AccountModel, AccountDetailView, dialogs, notifications, a11y, mailSettings, gt) {
+], function (ext, api, AccountModel, AccountDetailView, ModalDialog, notifications, a11y, mailSettings, gt) {
 
     'use strict';
 
-    function renderDetailView(evt, data) {
-        var myView, myModel, myViewNode;
+    function renderDetailView(evt, data, apiModel) {
+        var myView, myModel, myViewNode, ignoreValidationErrors = true;
 
         myViewNode = $('<div>').addClass('accountDetail');
         myModel = new AccountModel(data);
         myView = new AccountDetailView({ model: myModel, node: myViewNode });
+        myView.listenTo(myModel, 'sync', function (model) {
+            apiModel.set(model.attributes);
+        });
 
-        myView.dialog = new dialogs.ModalDialog({
+        myView.dialog = new ModalDialog({
             width: 700,
-            async: true
+            maximize: 500,
+            async: true,
+            point: 'io.ox/settings/accounts/mail/settings/detail/dialog',
+            title: myModel.get('id') || myModel.get('id') === 0 ? gt('Edit mail account') : gt('Add mail account'),
+            view: myView
         });
-        //TOOD: hack to avoid horizontal scrollbar
-        myView.dialog.getBody().css('padding-right', '15px');
 
-        myView.dialog.header(
-            $('<h2>').text(myModel.get('id') || myModel.get('id') === 0 ? gt('Edit mail account') : gt('Add mail account'))
-        ).append(
-            myView.render().el
-        )
-        .addPrimaryButton('save', gt('Save'), 'save')
-        .addButton('cancel', gt('Cancel'), 'cancel')
-        .show(function () {
-            a11y.getTabbable(this).first().focus();
-        });
+        myView.dialog.extend({
+            text: function () {
+                this.$body.append(
+                    this.options.view.render().el
+                );
+            }
+        })
+        .addCancelButton()
+        .addButton({
+            action: 'save',
+            label: gt('Save')
+        })
+        .open();
 
         //show errors
         myModel.on('validated', function (valid, model, error) {
@@ -58,6 +66,7 @@ define('io.ox/mail/accounts/settings', [
             $form.find('.help-block').prev().removeAttr('aria-invalid aria-describedby');
             $form.find('.help-block').remove();
 
+            if (ignoreValidationErrors) return;
             _.each(error, function (message, key) {
                 var $field = myView.$el.find('#' + key).parent(),
                     $row = $field.closest('.form-group'),
@@ -72,17 +81,23 @@ define('io.ox/mail/accounts/settings', [
             });
         });
 
+        // validate on change, so errormessages and aria-invalid states are updated
+        myModel.on('change', function (model) {
+            model.validate();
+        });
+
         myView.dialog.on('save', function () {
+            ignoreValidationErrors = false;
             myModel.validate();
             if (myModel.isValid()) {
-                myView.dialog.getBody().find('.settings-detail-pane').trigger('save');
+                myView.dialog.$body.find('.settings-detail-pane').trigger('save');
             } else {
                 notifications.yell('error', gt('Account settings could not be saved. Please take a look at the annotations in the form. '));
                 myView.dialog.idle();
 
                 //disable fields for primary account again
                 if (myModel.get('id') === 0) {
-                    myView.$el.find('input, select').not('#personal, [data-property="unified_inbox_enabled"]').prop('disabled', true);
+                    myView.$el.find('input, select').not('#personal, #name, [data-property="unified_inbox_enabled"]').prop('disabled', true);
                 }
 
             }
@@ -93,100 +108,137 @@ define('io.ox/mail/accounts/settings', [
         return myView.node;
     }
 
+    function createUnifiedMailboxInput(data) {
+        if (!mailSettings.get('features/accounts/configureUnifiedInboxOnCreate', false)) return;
+
+        data = _.defaults({ unified_inbox_enabled: false }, data);
+        return $('<div class="form-group checkbox">').append(
+            $('<label for="unified_inbox_enabled">').append(
+                $('<input type="checkbox" name="unified_inbox_enabled">')
+                    .prop('checked', data.unified_inbox_enabled),
+                gt('Use unified mail for this account')
+            )
+        );
+    }
+
     ext.point('io.ox/settings/accounts/mail/settings/detail').extend({
         index: 200,
         id: 'emailaccountssettings',
         draw: function (evt) {
             if (evt.data.id >= 0) {
                 api.get(evt.data.id).done(function (obj) {
-                    renderDetailView(evt, obj);
+                    renderDetailView(evt, obj, evt.data.model);
                 });
             } else {
-                renderDetailView(evt, evt.data);
+                renderDetailView(evt, evt.data, evt.data.model);
             }
         }
     });
 
     ext.point('io.ox/mail/add-account/preselect').extend({
+        id: 'dsc',
+        before: 'oauth',
+        draw: function (baton) {
+            if (!mailSettings.get('dsc/enabled')) {
+                // normal mode for all setups not using DSC
+                return;
+            }
+            // show classic wizard for DSC setups, bypass oauth accounts
+            ext.point('io.ox/mail/add-account/wizard').invoke('draw', baton.popup.getContentNode().empty());
+            _.defer(function () {
+                baton.popup.getFooter().find('[data-action="add"]').show();
+            }, 1000);
+
+            baton.stopPropagation();
+        }
+
+    }, {
         id: 'oauth',
         index: 100,
         draw: function (baton) {
             var $el = this;
-            if (!mailSettings.get('dsc/enabled')) {
-                // normal mode for all setups not using DSC
-                require(['io.ox/oauth/keychain', 'io.ox/oauth/backbone']).then(function (oauthAPI, OAuth) {
-                    var mailServices = new Backbone.Collection(oauthAPI.services.filter(function (service) {
-                            console.log('services', service);
-                            return _(service.get('availableScopes')).contains('mail') &&
-                                oauthAPI.accounts.forService(service.id, { scope: 'mail' }).map(function (account) {
-                                    return account.id;
-                                }).reduce(function (acc, oauthId) {
-                                    // make sure, no mail account using this oauth-account exists
-                                    return acc && !_(api.cache).chain()
-                                        .values()
-                                        .map(function (account) {
-                                            return account.mail_oauth;
-                                        })
-                                        .any(oauthId)
-                                        .value();
-                                }, true);
-                        })), list = new OAuth.Views.ServicesListView({ collection: mailServices });
+            $el.empty().addClass('mail-account-dialog');
+            require(['io.ox/oauth/keychain', 'io.ox/oauth/backbone']).then(function (oauthAPI, OAuth) {
+                var mailServices = new Backbone.Collection(oauthAPI.services.filter(function (service) {
+                        return _(service.get('availableScopes')).contains('mail') &&
+                            oauthAPI.accounts.forService(service.id, { scope: 'mail' }).map(function (account) {
+                                return account.id;
+                            }).reduce(function (acc, oauthId) {
+                                // make sure, no mail account using this oauth-account exists
+                                return acc && !_(api.cache).chain()
+                                    .values()
+                                    .map(function (account) {
+                                        return account.mail_oauth;
+                                    })
+                                    .any(oauthId)
+                                    .value();
+                            }, true);
+                    })), list = new OAuth.Views.ServicesListView({ collection: mailServices, model: { mailService: true } });
 
-                    if (mailServices.length === 0) {
-                        baton.popup.getFooter().find('[data-action="add"]').show();
-                        // invoke wizard, there are no OAuth options to choose from
-                        ext.point('io.ox/mail/add-account/wizard').invoke('draw', baton.popup.getContentNode().empty());
-                        return;
-                    }
+                if (mailServices.length === 0) {
+                    baton.popup.getFooter().find('[data-action="add"]').show();
+                    // invoke wizard, there are no OAuth options to choose from
+                    ext.point('io.ox/mail/add-account/wizard').invoke('draw', baton.popup.getContentNode().empty());
+                    return;
+                }
+                mailServices.push({
+                    id: 'mailwizard',
+                    type: 'wizard',
+                    displayName: gt('Add other mail account')
+                });
 
-                    // only valid for non dsc setups
-                    mailServices.push({
-                        id: 'wizard',
-                        displayName: gt('Other')
+                $el.append(
+                    $('<label>').text(gt('Please choose your mail account provider.')),
+                    list.render().$el,
+                    createUnifiedMailboxInput()
+                );
+                // this code block runs deferred, need to focus the first element, again
+                a11y.getTabbable($el).first().focus();
+
+                list.listenTo(list, 'select', function (service) {
+                    if (service.id === 'mailwizard') return;
+
+                    var account = oauthAPI.accounts.forService(service.id).filter(function (account) {
+                        return !account.hasScopes('mail');
+                    })[0] || new OAuth.Account.Model({
+                        serviceId: service.id,
+                        //#. %1$s is the display name of the account
+                        //#. e.g. My Xing account
+                        displayName: gt('My %1$s account', service.get('displayName'))
                     });
 
-                    $el.append(
-                        $('<label>').text(gt('Please select your mail account provider')),
-                        list.render().$el
-                    );
+                    account.enableScopes('mail').save().then(function () {
+                        baton.popup.busy();
+                        var busyMessage = $('<div class="alert-placeholder">');
+                        $el.append(busyMessage);
+                        drawBusy(busyMessage);
 
-                    list.listenTo(list, 'select', function (service) {
-                        if (service.id === 'wizard') return;
+                        api.autoconfig({
+                            oauth: account.id
+                        }).then(function (data) {
+                            var def = $.Deferred();
+                            // hopefully, login contains a valid mail address
+                            data.primary_address = data.login;
+                            data.unified_inbox_enabled = $el.find('input[name="unified_inbox_enabled"]').prop('checked') === true;
 
-                        var account = new OAuth.Account.Model({
-                            serviceId: service.id,
-                            displayName: 'My ' + service.get('displayName') + ' account'
+                            validateMailaccount(data, baton.popup, def);
+                            return def;
+                        }).then(function () {
+                            oauthAPI.accounts.add(account, { merge: true });
+                        }, notifications.yell).always(function () {
+                            baton.popup.idle();
                         });
-
-                        account.enableScopes('mail').save().then(function () {
-                            api.autoconfig({
-                                oauth: account.id
-                            }).then(function (data) {
-                                var def = $.Deferred();
-                                // hopefully, login contains a valid mail address
-                                data.primary_address = data.login;
-
-                                validateMailaccount(data, baton.popup, def);
-                                return def;
-                            }).then(function () {
-                                oauthAPI.accounts.add(account, { merge: true });
-                            }, notifications.yell);
-                        });
-                    });
-
-                    list.listenTo(list, 'select:wizard', function () {
-                        baton.popup.getFooter().find('[data-action="add"]').show();
-                        // invoke wizard
-                        ext.point('io.ox/mail/add-account/wizard').invoke('draw', baton.popup.getContentNode().empty());
                     });
                 });
-            } else {
-                // show classic wizard for DSC setups, bypass oauth accounts
-                ext.point('io.ox/mail/add-account/wizard').invoke('draw', baton.popup.getContentNode().empty());
-                _.defer(function () {
+
+                list.listenTo(list, 'select:mailwizard', function () {
                     baton.popup.getFooter().find('[data-action="add"]').show();
-                }, 1000);
-            }
+                    // invoke wizard
+                    var data = {};
+                    data.unified_inbox_enabled = $el.find('input[name="unified_inbox_enabled"]').prop('checked') === true;
+                    ext.point('io.ox/mail/add-account/wizard').invoke('draw', baton.popup.getContentNode().empty(), data);
+                });
+            });
         }
     });
 
@@ -194,12 +246,20 @@ define('io.ox/mail/accounts/settings', [
         id: 'address',
         index: 100,
         draw: function () {
+            var input, self = this;
             this.append(
                 $('<div class="form-group">').append(
                     $('<label for="add-mail-account-address">').text(gt('Your mail address')),
-                    $('<input id="add-mail-account-address" type="text" class="form-control add-mail-account-address">')
+                    input = $('<input id="add-mail-account-address" type="text" class="form-control add-mail-account-address" autocomplete="section-addAccount username">')
                 )
             );
+
+            input.on('change', function () {
+                var alert = self.find('.alert');
+                if (alert.length && alert.attr('errorAttributes').indexOf('address') !== -1) {
+                    alert.remove();
+                }
+            });
         }
     });
 
@@ -207,12 +267,20 @@ define('io.ox/mail/accounts/settings', [
         id: 'password',
         index: 200,
         draw: function () {
+            var input, self = this;
             this.append(
                 $('<div class="form-group">').append(
                     $('<label for="add-mail-account-password">').text(gt('Your password')),
-                    $('<input id="add-mail-account-password" type="password" class="form-control add-mail-account-password">')
+                    input = $('<input id="add-mail-account-password" type="password" class="form-control add-mail-account-password" autocomplete="section-addAccount new-password">')
                 )
             );
+
+            input.on('change', function () {
+                var alert = self.find('.alert');
+                if (alert.length && alert.attr('errorAttributes').indexOf('password') !== -1) {
+                    alert.remove();
+                }
+            });
         }
     });
 
@@ -225,6 +293,14 @@ define('io.ox/mail/accounts/settings', [
         }
     });
 
+    ext.point('io.ox/mail/add-account/wizard').extend({
+        id: 'unified-mail',
+        index: 400,
+        draw: function (data) {
+            this.append(createUnifiedMailboxInput(data));
+        }
+    });
+
     ext.point('io.ox/mail/add-account/wizard').extend({
         id: 'feedback',
         index: 1000000000000,
@@ -247,11 +323,13 @@ define('io.ox/mail/accounts/settings', [
             return popup.getContentNode().find('.alert-placeholder');
         },
 
-        drawAlert = function (alertPlaceholder, message) {
+        drawAlert = function (alertPlaceholder, message, options) {
+            options = options || {};
             alertPlaceholder.find('.alert').remove();
             alertPlaceholder.find('.busynotice').remove();
             alertPlaceholder.append(
-                $.alert({ message: message, dismissable: true }).one('click', '.close', function () {
+                // errorAttributes is used to dynamically remove the errormessage on attribute change
+                $.alert({ message: message, dismissable: true }).attr('errorAttributes', options.errorAttributes || '').one('click', '.close', function () {
                     alertPlaceholder.empty();
                 })
             );
@@ -277,6 +355,11 @@ define('io.ox/mail/accounts/settings', [
         },
 
         validateMailaccount = function (data, popup, def, options) {
+            var node = popup.getContentNode().find('input[name="unified_inbox_enabled"]');
+
+            if (node.length > 0 && node.prop('checked')) {
+                data.unified_inbox_enabled = true;
+            }
             myModel.validationCheck(data, { ignoreInvalidTransport: true }).then(
                 function success(response, responseobject) {
                     if (response === true) {
@@ -305,7 +388,7 @@ define('io.ox/mail/accounts/settings', [
                         // this will not work if called from the "add account" autoconfig part, in this case
                         // the callback from the options will be called (see above)
                         var message = responseobject.error ? responseobject.error : gt('There was no suitable server found for this mail/password combination');
-                        drawAlert(getAlertPlaceholder(popup), message);
+                        drawAlert(getAlertPlaceholder(popup), message, { errorAttributes: 'address password' });
                         popup.idle();
                         popup.getBody().find('a.close').focus();
 
@@ -320,11 +403,10 @@ define('io.ox/mail/accounts/settings', [
         },
 
         configureManuallyDialog = function (args, newMailaddress) {
-            new dialogs.ModalDialog({ width: 400 })
-                .text(gt('Auto-configuration failed. Do you want to configure your account manually?'))
-                .addPrimaryButton('yes', gt('Yes'), 'yes')
-                .addButton('no', gt('No'), 'no')
-                .on('yes', function () {
+            new ModalDialog({ width: 400, title: gt('Error') })
+                .addCancelButton()
+                .addButton({ action: 'manual', label: gt('Manual') })
+                .on('manual', function () {
                     var data = {};
                     data.primary_address = newMailaddress;
                     if (args) {
@@ -332,7 +414,8 @@ define('io.ox/mail/accounts/settings', [
                         createExtpointForNewAccount(args);
                     }
                 })
-                .show();
+                .open()
+                .$body.text(gt('Auto-configuration failed. Do you want to configure your account manually?'));
         },
 
         autoconfigApiCall = function (args, newMailaddress, newPassword, popup, def, forceSecure) {
@@ -358,18 +441,19 @@ define('io.ox/mail/accounts/settings', [
                     } });
 
                 } else if (forceSecure) {
-                    new dialogs.ModalDialog({ async: true, width: 400 })
-                        .text(gt('Cannot establish secure connection. Do you want to proceed anyway?'))
-                        .addPrimaryButton('yes', gt('Yes'), 'yes')
-                        .addButton('no', gt('No'), 'no')
-                        .on('yes', function () {
+                    new ModalDialog({ async: true, width: 400, title: gt('Warning') })
+                        .addCancelButton()
+                        .addButton({ action: 'proceed', label: gt('Ignore Warnings') })
+                        .on('proceed', function () {
                             autoconfigApiCall(args, newMailaddress, newPassword, this, def, false);
                         })
-                        .on('no', function () {
+                        .on('cancel', function () {
                             def.reject();
                             this.close();
                         })
-                        .show();
+                        .open()
+                        .$body.append(gt('Cannot establish secure connection. Do you want to proceed anyway?'));
+
                     popup.close();
                 } else {
                     configureManuallyDialog(args, newMailaddress);
@@ -394,7 +478,7 @@ define('io.ox/mail/accounts/settings', [
                 var baton = ext.Baton({});
 
                 new dialogs.ModalDialog({
-                    width: 400,
+                    width: 432,
                     async: true,
                     enter: 'add'
                 })
@@ -421,7 +505,7 @@ define('io.ox/mail/accounts/settings', [
                         autoconfigApiCall(args, newMailaddress, newPassword, this, def, true);
                     } else {
                         var message = gt('This is not a valid mail address');
-                        drawAlert(alertPlaceholder, message);
+                        drawAlert(alertPlaceholder, message, { errorAttributes: 'address' });
                         content.find('.add-mail-account-password').focus();
                         this.idle();
                     }
@@ -429,6 +513,10 @@ define('io.ox/mail/accounts/settings', [
                 .on('skip', function () {
                     // primary address needs to be provided, why? fails without
                     args.data = { primary_address: this.getContentNode().find('.add-mail-account-address').val() };
+
+                    if (this.getContentNode().find('input[name="unified_inbox_enabled"]').length > 0) {
+                        args.data.unified_inbox_enabled = this.getContentNode().find('input[name="unified_inbox_enabled"]').prop('checked');
+                    }
                     // close
                     this.close();
                     def.reject();
