@@ -22,8 +22,9 @@ define('io.ox/mail/actions', [
     'io.ox/core/api/account',
     'io.ox/core/notifications',
     'settings!io.ox/mail',
-    'gettext!io.ox/mail'
-], function (ext, links, api, util, folderAPI, print, account, notifications, settings, gt) {
+    'gettext!io.ox/mail',
+    'io.ox/core/capabilities'
+], function (ext, links, api, util, folderAPI, print, account, notifications, settings, gt, capabilities) {
 
     'use strict';
 
@@ -65,8 +66,8 @@ define('io.ox/mail/actions', [
             if (!e.collection.has('toplevel', 'one')) return;
             // get first mail
             var data = e.baton.first();
-            // has sender? and not a draft mail
-            return util.hasFrom(data) && !isDraftMail(data);
+            // has sender? not a draft mail and not a decrypted mail
+            return util.hasFrom(data) && !isDraftMail(data) && !util.isDecrypted(data);
         },
         action: function (baton) {
 
@@ -78,9 +79,10 @@ define('io.ox/mail/actions', [
                 // hide inline link
                 link = view.$('[data-ref="io.ox/mail/actions/inplace-reply"]').hide();
 
+            if (!view.$el.hasClass('expanded')) view.toggle(cid);
             require(['io.ox/mail/inplace-reply'], function (InplaceReplyView) {
                 view.$('section.body').before(
-                    new InplaceReplyView({ tagName: 'section', cid: cid, numberOfRecipients: numberOfRecipients })
+                    new InplaceReplyView({ tagName: 'section', cid: cid, numberOfRecipients: numberOfRecipients, content_type: baton.data.content_type })
                     .on('send', function (cid) {
                         view.$el.closest('.thread-view-control').data('open', cid);
                     })
@@ -95,6 +97,17 @@ define('io.ox/mail/actions', [
         }
     });
 
+    function reply(mode) {
+        return function (baton) {
+            var data = baton.first();
+            require(['io.ox/mail/compose/checks'], function (checks) {
+                checks.replyToMailingList(_.cid(data), mode, data).then(function (mode) {
+                    ox.registry.call('mail-compose', mode, data);
+                });
+            });
+        };
+    }
+
     new Action('io.ox/mail/actions/reply-all', {
         requires: function (e) {
             // must be top-level
@@ -108,9 +121,7 @@ define('io.ox/mail/actions', [
             // has sender? and not a draft mail
             return util.hasFrom(data) && !isDraftMail(data);
         },
-        action: function (baton) {
-            ox.registry.call('mail-compose', 'replyall', baton.first());
-        }
+        action: reply('replyall')
     });
 
     new Action('io.ox/mail/actions/reply', {
@@ -126,9 +137,7 @@ define('io.ox/mail/actions', [
             // has sender? and not a draft mail
             return util.hasFrom(data) && !isDraftMail(data);
         },
-        action: function (baton) {
-            ox.registry.call('mail-compose', 'reply', baton.first());
-        }
+        action: reply('reply')
     });
 
     new Action('io.ox/mail/actions/forward', {
@@ -151,21 +160,33 @@ define('io.ox/mail/actions', [
         }
     });
 
-    new Action('io.ox/mail/actions/edit', {
-        requires: function (e) {
-            // must be top-level
-            if (!e.collection.has('toplevel')) return;
-            // multiple selection
-            if (e.baton.selection && e.baton.selection.length > 1) return;
-            // multiple and not a thread?
-            if (!e.collection.has('one') && !e.baton.isThread) return;
-            // get first mail
-            var data = e.baton.first();
-            // must be draft folder
-            return data && isDraftMail(data);
-        },
-        action: function (baton) {
+    var validDraft = function (e) {
+        // must be top-level
+        if (!e.collection.has('toplevel')) return;
+        // multiple selection
+        if (e.baton.selection && e.baton.selection.length > 1) return;
+        // multiple and not a thread?
+        if (!e.collection.has('one') && !e.baton.isThread) return;
+        // get first mail
+        var data = e.baton.first();
+        // Can't edit encrypted E-mail
+        if (data && data.security_info && data.security_info.encrypted) return;
+        // must be draft folder
+        return data && isDraftMail(data);
+    };
 
+    var setEditorMode = function (settings, data) {
+        // Open Drafts in HTML mode if content type is html even if text-editor is default
+        if (data.content_type === 'text/html' && settings.get('messageFormat', 'html') === 'text') {
+            data.preferredEditorMode = 'html';
+            data.editorMode = 'html';
+        }
+        return data;
+    };
+
+    new Action('io.ox/mail/actions/edit', {
+        requires: validDraft,
+        action: function (baton) {
             var data = baton.first(),
                 app = _(ox.ui.apps.models).find(function (model) {
                     return model.refId === data.id;
@@ -175,18 +196,33 @@ define('io.ox/mail/actions', [
             if (app) return app.launch();
 
             require(['settings!io.ox/mail'], function (settings) {
-
-                // Open Drafts in HTML mode if content type is html even if text-editor is default
-                if (data.content_type === 'text/html' && settings.get('messageFormat', 'html') === 'text') {
-                    data.preferredEditorMode = 'html';
-                    data.editorMode = 'html';
-                }
-
+                data = setEditorMode(settings, data);
                 ox.registry.call('mail-compose', 'edit', data);
             });
         }
     });
 
+    new Action('io.ox/mail/actions/edit-copy', {
+        requires: validDraft,
+        action: function (baton) {
+            var data = baton.first();
+
+            api.copy(data, data.folder_id).done(function (list) {
+                api.refresh();
+                require(['settings!io.ox/mail'], function (settings) {
+                    data = setEditorMode(settings, _.extend(data, list[0]));
+                    ox.registry.call('mail-compose', 'edit', data).done(function (window) {
+                        var model = window.app.model;
+                        //#. If the user selects 'copy of' in the drafts folder, the subject of the email is prefixed with [Copy].
+                        //#. Please make sure that this is a prefix in every translation since it will be removed when the mail is sent.
+                        //#. %1$s the original subject of the mail
+                        model.set('subject', gt('[Copy] %1$s', model.get('subject')));
+                    });
+                });
+            });
+        }
+    });
+
     new Action('io.ox/mail/actions/source', {
         requires: function (e) {
             // must be at least one message and top-level
@@ -206,7 +242,7 @@ define('io.ox/mail/actions', [
     });
 
     new Action('io.ox/mail/actions/filter', {
-        capabilities: 'mailfilter',
+        capabilities: 'mailfilter_v2',
         requires: function (e) {
             // must be at least one message and top-level
             if (!e.collection.has('some') || !e.collection.has('toplevel')) return;
@@ -225,8 +261,8 @@ define('io.ox/mail/actions', [
                         preparedTest = {
                             id: 'allof',
                             tests: [
-                                _.copy(opt.filterDefaults.tests.Subject),
-                                opt.filterDefaults.tests.address ? _.copy(opt.filterDefaults.tests.address) : _.copy(opt.filterDefaults.tests.From)
+                                _.copy(opt.filterDefaults.tests.subject),
+                                opt.filterDefaults.tests.address ? _.copy(opt.filterDefaults.tests.address) : _.copy(opt.filterDefaults.tests.from)
                             ]
                         };
 
@@ -235,7 +271,7 @@ define('io.ox/mail/actions', [
 
                     args.data.obj.set('test', preparedTest);
 
-                    ext.point('io.ox/settings/mailfilter/filter/settings/detail').invoke('draw', undefined, args, config[0]);
+                    ext.point('io.ox/settings/mailfilter/filter/settings/detail').invoke('draw', undefined, args, config);
                 });
             });
         }
@@ -253,6 +289,15 @@ define('io.ox/mail/actions', [
         }
     });
 
+    new Action('io.ox/mail/actions/flag', {
+        requires: function (e) {
+            return settings.get('features/flag/star') && e.collection.has('some');
+        },
+        action: function (baton) {
+            api.flag(baton.data);
+        }
+    });
+
     new Action('io.ox/mail/actions/archive', {
         capabilities: 'archive_emails',
         requires: function (e) {
@@ -346,12 +391,8 @@ define('io.ox/mail/actions', [
                 if (memo === false) return false;
                 // is not primary account?
                 if (!account.isPrimary(obj.folder_id)) return false;
-                // is spam folder?
-                if (account.is('spam', obj.folder_id)) return false;
-                // is sent folder?
-                if (account.is('sent', obj.folder_id)) return false;
-                // is drafts folder?
-                if (account.is('drafts', obj.folder_id)) return false;
+                // is spam/confirmed_spam/sent/drafts folder?
+                if (account.is('spam|confirmed_spam|sent|drafts', obj.folder_id)) return false;
                 // is marked as spam already?
                 if (util.isSpam(obj)) return false;
                 // else
@@ -378,7 +419,7 @@ define('io.ox/mail/actions', [
                 // is not primary account?
                 if (!account.isPrimary(obj.folder_id)) return false;
                 // else
-                return account.is('spam', obj.folder_id) || util.isSpam(obj);
+                return account.is('spam|confirmed_spam', obj.folder_id) || util.isSpam(obj);
             }, true);
         },
         multiple: function (list) {
@@ -406,10 +447,13 @@ define('io.ox/mail/actions', [
         requires: 'some',
         multiple: function (attachmentList, baton) {
             ox.load(['io.ox/mail/actions/viewer']).done(function (action) {
-                var options = { files: attachmentList };
+                var options = { files: attachmentList, restoreFocus: baton.restoreFocus };
                 if (baton.startItem) {
                     options.selection = baton.startItem;
                 }
+                if (baton.openedBy) {
+                    options.openedBy = baton.openedBy;
+                }
                 action(options);
             });
         }
@@ -507,8 +551,26 @@ define('io.ox/mail/actions', [
     new Action('io.ox/mail/actions/sendmail', {
         requires: 'some',
         action: function (baton) {
-            var data = baton.data;
-            ox.registry.call('mail-compose', 'compose', { folder_id: data.folder_id, to: data.to.concat(data.cc).concat(data.from) });
+            require(['io.ox/core/api/user'], function (userAPI) {
+                account.getAllSenderAddresses().done(function (senderAddresses) {
+                    userAPI.getCurrentUser().done(function (user) {
+                        var data = baton.data,
+                            toAdresses = data.to.concat(data.cc).concat(data.bcc).concat(data.from),
+                            ownAddresses = _.compact([user.get('email1'), user.get('email2'), user.get('email3')]);
+
+                        ownAddresses = ownAddresses.concat(_(senderAddresses).pluck(1));
+                        var filtered = _(toAdresses).filter(function (addr) {
+                            return ownAddresses.indexOf(addr[1]) < 0;
+                        });
+                        if (filtered.length === 0) filtered = toAdresses;
+                        filtered = _(filtered).uniq(false, function (addr) {
+                            return addr[1];
+                        });
+
+                        ox.registry.call('mail-compose', 'compose', { folder_id: data.folder_id, to: filtered });
+                    });
+                });
+            });
         }
     });
 
@@ -516,8 +578,8 @@ define('io.ox/mail/actions', [
         capabilities: 'contacts',
         requires: 'some',
         action: function (baton) {
-            require(['io.ox/mail/actions/createdistlist'], function (action) {
-                action(baton);
+            require(['io.ox/mail/actions/create'], function (action) {
+                action.createDistributionList(baton);
             });
         }
     });
@@ -526,8 +588,8 @@ define('io.ox/mail/actions', [
         capabilities: 'calendar',
         requires: 'some',
         action: function (baton) {
-            require(['io.ox/mail/actions/invite'], function (action) {
-                action(baton);
+            require(['io.ox/mail/actions/create'], function (action) {
+                action.createAppointment(baton);
             });
         }
     });
@@ -543,9 +605,10 @@ define('io.ox/mail/actions', [
     });
 
     new Action('io.ox/mail/premium/actions/synchronize', {
-        capabilities: 'active_sync client-onboarding',
+        capabilities: 'active_sync',
         requires: function () {
-            return _.device('!smartphone');
+            // use client onboarding here, since it is a setting and not a capability
+            return capabilities.has('client-onboarding');
         },
         action: function () {
             require(['io.ox/onboarding/clients/wizard'], function (wizard) {
@@ -583,7 +646,7 @@ define('io.ox/mail/actions', [
         prio: 'hi',
         id: 'reply-all',
         mobile: 'lo',
-        label: gt('Reply All'),
+        label: gt('Reply all'),
         ref: 'io.ox/mail/actions/reply-all',
         drawDisabled: true,
         section: 'standard'
