@@ -17,7 +17,7 @@ define('io.ox/mail/actions/reminder', [
     'io.ox/mail/util',
     'settings!io.ox/core',
     'io.ox/core/notifications'
-], function (gt, util, coreConfig, notifications) {
+], function (gt, util, coreSettings, notifications) {
 
     'use strict';
 
@@ -31,7 +31,7 @@ define('io.ox/mail/actions/reminder', [
                 dateSelector,
                 endDate = new Date(),
                 popup = new dialogs.ModalDialog({
-                    help: 'ox.appsuite.user.sect.email.manage.reminder.html#ox.appsuite.user.concept.email.reminder'
+                    help: 'ox.appsuite.user.sect.email.manage.reminder.html'
                 })
                     .addPrimaryButton('create', gt('Create reminder'), 'create')
                     .addButton('cancel', gt('Cancel'), 'cancel');
@@ -70,10 +70,10 @@ define('io.ox/mail/actions/reminder', [
                         note;
 
                     //add mail cid so the task can offer a link
-                    note = noteInput.val() + '\n--\nmail://' + _.cid(data);
+                    note = noteInput.val() + '\n--\nmail://' + _.ecid(data);
                     taskAPI.create({
                         title: titleInput.val(),
-                        folder_id: coreConfig.get('folder/tasks'),
+                        folder_id: coreSettings.get('folder/tasks'),
                         alarm: dates.alarmDate,
                         note: note,
                         status: 1,
