@@ -26,15 +26,25 @@ define('io.ox/mail/autoforward/settings/filter', [
         editAutoForward: function ($node, userMainEmail) {
             var deferred = $.Deferred();
 
-            api.getRules('autoforward').done(function (data) {
+            $.when(api.getRules('autoforward'), api.getConfig()).done(function (data, config) {
+                data = data[0];
 
-                var autoForwardData = { userMainEmail: userMainEmail },
+                var getIdList = function () {
+                    var list = {};
+                    _.each(config.actioncmds, function (val) {
+                        list[val.id] = val;
+                    });
+                    return list;
+                };
+
+                var autoForwardData = { userMainEmail: userMainEmail, processSub: true },
                     ForwardEdit = ViewForm.protectedMethods.createAutoForwardEdit('io.ox/core/autoforward'),
                     autoForward;
 
                 if (_.isEmpty(data)) {
 
                     autoForward = new ForwardEdit({ model: factory.create(autoForwardData) });
+                    autoForward.model.availableActions = getIdList();
 
                     $node
                         .append(autoForward.render().$el)
@@ -63,18 +73,29 @@ define('io.ox/mail/autoforward/settings/filter', [
                     _.extend(autoForwardData, {
                         id: data[0].id,
                         active: data[0].active,
-                        keep: false
+                        processSub: true
                     });
 
+                    if (getIdList().copy && data[0].actioncmds[0].copy) autoForwardData.keep = true;
+
                     _(data[0].actioncmds).each(function (value) {
-                        if (value.id === 'redirect') {
-                            autoForwardData.forwardmail = value.to;
-                        } else if (value.id === 'keep') {
-                            autoForwardData.keep = true;
+                        switch (value.id) {
+                            case 'redirect':
+                                autoForwardData.forwardmail = value.to;
+                                break;
+                            case 'keep':
+                                autoForwardData.keep = true;
+                                break;
+                            case 'stop':
+                                autoForwardData.processSub = false;
+                                break;
+                            default:
+                                if (ox.debug) console.log('wrong actioncmds');
                         }
                     });
 
                     autoForward = new ForwardEdit({ model: factory.create(autoForwardData) });
+                    autoForward.model.availableActions = getIdList();
 
                     $node
                         .append(autoForward.render().$el)
