@@ -23,7 +23,7 @@ define('io.ox/mail/categories/api', [
          // flag collections as expired
         var rCategory = new RegExp('categoryid=' + options.target);
         _.each(mailAPI.pool.getCollections(), function (collection, id) {
-            if (rCategory.test(id)) collection.expired = true;
+            if (rCategory.test(id)) collection.expire();
         });
         // TODO: investigate why we have to call gc manually to get it work
         mailAPI.pool.gc();
@@ -69,7 +69,7 @@ define('io.ox/mail/categories/api', [
 
         // we don't do this in initialize() since the feature might be unavailable
         initializeRefresh: function () {
-            mailAPI.on('after:refresh.unseen after:refresh.seen after:all-seen delete refresh.all', _.debounce(this.refresh.bind(this), 200));
+            mailAPI.on('after:refresh.unseen after:refresh.seen after:all-seen refresh.all delete move', _.debounce(this.refresh.bind(this), 200));
             this.refresh();
             this.initializeRefresh = _.noop;
         },
